@@ -1,6 +1,6 @@
 package OpenInteract2::Action::News;
 
-# $Id: News.pm,v 1.6 2003/07/01 05:36:03 lachoy Exp $
+# $Id: News.pm,v 1.7 2003/09/04 03:37:59 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonSearch
@@ -16,7 +16,7 @@ use OpenInteract2::Context     qw( CTX );
 use OpenInteract2::Util;
 use SPOPS::Secure              qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::News::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::News::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 sub home {
     my ( $self ) = @_;
@@ -54,21 +54,26 @@ sub latest {
 
 sub search {
     my ( $self ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $request = CTX->request;
 
     $self->param_from_request( qw( num_items option section ) );
+
+    # NOTE: We can't use $request->param_date( 'news' ) here because
+    # we allow the day to be blank
+
     unless ( $self->param( 'date' ) ) {
-        my %date    = ( day   => $request->param( 'news_day' ),
-                        month => $request->param( 'news_month' ),
-                        year  => $request->param( 'news_year' ) );
-        if ( $date{month} and $date{year} ) {
-            $self->param( date => join( '-', map { $date{ $_ } }
-                                                   sort keys %date ) );
+        my $p_day   = $request->param( 'news_day' );
+        my $p_month = $request->param( 'news_month' );
+        my $p_year  = $request->param( 'news_year' );
+        if ( $p_month and $p_year ) {
+            $self->param( date => join( '-', $p_day, $p_month, $p_year ) );
         }
     }
 
     my $now_string = OpenInteract2::Util->now;
-    my %params = ( section => $self->param( 'section') );
+    my %params = ();
     my $where = " active_on <= ? AND active = ? ";
     my @values = ( $now_string, 'yes' );
 
@@ -77,29 +82,47 @@ sub search {
                 : ' AND ( expires_on IS NULL OR expires_on > ? ) ';
     push @values, $now_string;
 
-    if ( $self->param( 'section' ) ) {
+    if ( my $section = $self->param( 'section' ) ) {
         $where .= ' AND ( section = ? )';
-        push @values, $self->param( 'section' );
+        push @values, $section;
+        $params{section} = $section;
+        $log->is_info &&
+            $log->info( "Given search section of '$section'" );
     }
 
-    if ( $self->param( 'date' ) ) {
-        $where .= 'AND ( posted_on >= ? AND posted_on < ? )';
-        my ( $dy, $mo, $yr ) = split /\-/, $self->param( 'date' );
-        if ( $mo > 0 ) {
-            my $search_date = strptime( $self->param( 'date' ),
-                                        '%d-%m-%Y' );
-            push @values, $search_date->clone
-                                      ->subtract( days => 1 )
-                                      ->strftime( '%Y-%m-%d' ),
-                          $search_date->add( days => 1 )
-                                      ->strftime( '%Y-%m-%d' );
+    if ( my $date_spec = $self->param( 'date' ) ) {
+        my ( $dy, $mo, $yr ) = split /\-/, $date_spec;
+        $log->is_debug &&
+            $log->debug( "Searching for date with [d: $dy] [m: $mo] ",
+                         "[y: $yr]" );
+        my ( $begin_date, $end_date );
+
+        # If day is specified we find everything on that day...
+
+        if ( $dy > 0 ) {
+            my $search_date = strptime( '%d-%m-%Y', $date_spec );
+            $begin_date = $search_date->clone
+                                      ->subtract( days => 1 );
+            $end_date   = $search_date->add( days => 1 );
+            $params{date} = $end_date->strftime( '%Y-%m-%d' );
         }
+
+        # ...otherwise we find everything in that month
+
         else {
-            my $begin_date = join( '-', $yr, $mo, 1 );
-            push @values, $begin_date;
-            my $end_date = (strptime( $begin_date ))->add_duration( months => 1 );
-            push @values, $end_date->strftime( '%Y-%m-%d' );
+            my $begin_date_spec = join( '-', $yr, $mo, 1 );
+            $begin_date = strptime( '%Y-%m-%d', $begin_date_spec );
+            $end_date   = $begin_date->clone->add( months => 1 );
+            $params{date} = join( ' to ', $begin_date->strftime( '%Y-%m-%d' ),
+                                          $end_date->strftime( '%Y-%m-%d' ) );
         }
+        $log->is_info &&
+            $log->info( "Given search begin/end dates of ",
+                        "'", $begin_date->strftime( '%Y-%m-%d' ), "'",
+                        "'", $end_date->strftime( '%Y-%m-%d' ), "'" );
+        $where .= 'AND ( posted_on >= ? AND posted_on < ? )';
+        push @values, $begin_date->strftime( '%Y-%m-%d' ),
+                      $end_date->strftime( '%Y-%m-%d' );
     }
 
     my $news_class = CTX->lookup_object( 'news' );
