@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Page;
 
-# $Id: Page.pm,v 1.10 2003/06/25 14:10:49 lachoy Exp $
+# $Id: Page.pm,v 1.12 2003/09/04 03:37:22 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonSearch
@@ -17,7 +17,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Secure            qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 # 52 weeks -- default expiration for page
 
@@ -595,8 +595,18 @@ sub display_remove_status {
 
 sub display_modify_status {
     my ( $self ) = @_;
-    my %params = ( directory => $self->param( 'page' )->{directory},
-                   location  => $self->param( 'page' )->{location} );
+    my $log = get_logger( LOG_APP );
+
+    my %params = ();
+    my $page = $self->param( 'c_object' );
+    if ( $page ) {
+        %params = ( directory => $page->{directory},
+                    location  => $page->{location} );
+    }
+    else {
+        $log->warn( "Weird: modification should have worked, but no ",
+                    "object found in 'c_object' key." );
+    }
     return $self->generate_content(
                     \%params,
                     { name => 'base_page::page_edit_status' } );
@@ -633,7 +643,7 @@ sub _show {
                      "[edit: ", $self->param( 'edit' ), "] ",
                      "[new object: ", $self->param( 'is_new_object' ), "]" );
     my $page_class = CTX->lookup_object( 'page' );
-    my $page = $self->param( 'page' );
+    my $page = $self->param( 'c_object' ) || $self->param( 'page' );
     if ( $self->param( 'is_new_object' ) ) {
         $page ||= $page_class->new();
     }
@@ -767,7 +777,7 @@ sub _show_editable_page {
 
     my $page = $self->param( 'page' )
                || CTX->lookup_object( 'page' )->new;
-    my %params = ();
+    my %params = ( page => $page );
 
     # If this is an editable doc, fetch the content, otherwise,
     # mark it as non-editable to the form
@@ -780,9 +790,9 @@ sub _show_editable_page {
         $params{non_editable} = 1;
     }
     $log->is_debug &&
-        $log->debug( "This page should be in an editable form;",
-                     "uneditable content status ",
-                     "[$params{non_editable}]" );
+        $log->debug( "This page should be in an editable form; ",
+                     "uneditable content status is ",
+                     "'$params{non_editable}'" );
 
     my $tmpl_name = 'page_form';
 
