@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Security;
 
-# $Id: Security.pm,v 1.7 2003/06/25 14:10:49 lachoy Exp $
+# $Id: Security.pm,v 1.8 2003/08/12 03:30:22 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -10,7 +10,7 @@ use OpenInteract2::Context   qw( CTX );
 use SPOPS::Secure            qw( :level :scope );
 use SPOPS::Secure::Hierarchy qw( $ROOT_OBJECT_NAME );
 
-$OpenInteract2::Action::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 my $SECURE_CLASS = 'SPOPS::Secure';
 
@@ -335,7 +335,7 @@ sub _get_user_scopes {
         my $level = $security->{ SEC_SCOPE_USER() }->{ $uid };
         push @s, { scope    => SEC_SCOPE_USER,
                    scope_id => $uid,
-                   name     => $user->{name},
+                   name     => $user->{login_name},
                    level    => $level };
     }
     return @s;
