@@ -1,6 +1,6 @@
 package OpenInteract2::Action::SiteSearch;
 
-# $Id: SiteSearch.pm,v 1.6 2003/06/25 14:10:50 lachoy Exp $
+# $Id: SiteSearch.pm,v 1.7 2003/09/03 13:40:10 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -12,21 +12,25 @@ use OpenInteract2::ResultsManage;
 BEGIN {
     eval {
         require OpenInteract2::FullText;
+        require OpenInteract2::FullTextIterator;
     };
 }
 
-$OpenInteract2::Action::SiteSearch::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::SiteSearch::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 sub search {
     my ( $self ) = @_;
     my $log = get_logger( LOG_APP );
 
     my $request = CTX->request;
+    my %params = ();
 
-    my %params = ( search_id => $request->param( 'search_id' ),
-                   keywords  => $request->param( 'keywords' ) );
+    my $search_id = $request->param( 'search_id' );
+    my $keywords  = $request->param( 'keywords' );
 
-    unless ( $params{keywords} or $params{search_id} ) {
+    unless ( $keywords or $search_id ) {
+        $log->is_info &&
+            $log->info( 'No keywords or search ID given, nothing to display' );
         my $nk_desc = 'You did not give me any keywords to search, ' .
                       'so I did not run a search. Please try again.';
         my %nk_params = ( title       => 'No Keywords',
@@ -40,17 +44,22 @@ sub search {
                         || $self->param( 'default_per_page' );
     my ( $min, $max ) = OpenInteract2::ResultsManage->find_page_boundaries(
                               $params{current_page}, $hits_per_page );
+    $log->is_info &&
+        $log->info( "[Page: $params{current_page}] [Hits per: $hits_per_page] ",
+                    "[Min: $min] [Max: $max]" );
 
     # Run the search for the first time and save the results
 
-    unless ( $params{search_id} ) {
-        my @terms = split /\s+/, $params{keywords};
+    unless ( $search_id ) {
+        $log->is_info &&
+            $log->info( 'No search ID given, running keyword search' );
+        my @terms = split /\s+/, $keywords;
         $params{search_type} = $request->param( 'search_type' )
                                || $self->param( 'default_search_type' );
         my @include_classes = $request->param( 'include_class' );
         $log->is_info &&
-            $log->info( "Searching for $params{search_type} of ",
-                        "[$params{keywords}]" );
+            $log->info( "Searching for '$params{search_type}' using ",
+                        "keys '$keywords'" );
         my $search_results = OpenInteract2::FullText->search_fulltext_index({
                                       search_terms => \@terms,
                                       search_type  => $params{search_type},
@@ -60,17 +69,29 @@ sub search {
 
         if ( scalar @{ $search_results } > 0 ) {
             my $results = OpenInteract2::ResultsManage->new();
-            $params{search_id} = eval {
+            eval {
                 $results->save( [ map { $_->[0] } @{ $search_results } ],
                                 { extra      => [ map { $_->[1] } @{ $search_results } ],
                                   extra_name => [ 'fulltext_score' ] } )
             };
+            if ( $@ ) {
+                $log->error( "Failed to save search results: $@" );
+                $self->param_add(
+                    error_msg => "Failed to save search results" );
+            }
+            else {
+                $params{search_id} = $results->search_id;
+            }
         }
+        $params{keywords} = $keywords;
     }
 
     # Retrieve the persisted results and pass off to the OpenInteract::FullTextIterator
 
     if ( $params{search_id} ) {
+        $log->is_info &&
+            $log->info( "Retrieving search results for ID ",
+                        "'$params{search_id}'" );
         my $results = OpenInteract2::ResultsManage->new(
                               { search_id => $params{search_id},
                                 min       => $min,
