@@ -1,6 +1,6 @@
 package OpenInteract2::Action::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.8 2003/06/25 14:10:49 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.9 2003/08/27 15:50:17 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use SPOPS::Secure            qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 sub list {
     my ( $self ) = @_;
@@ -19,7 +19,7 @@ sub list {
         $log->info( "Listing templates in system" );
     my $website_dir = CTX->server_config->{dir}{website};
     my $packages = CTX->repository->fetch_all_packages();
-    my $tmpl_class = CTX->template_class;
+    my $tmpl_class = CTX->lookup_class( 'template' );
     my %templates = ();
     foreach my $pkg ( @{ $packages } ) {
         eval {
@@ -62,7 +62,7 @@ sub display_form {
                    package_labels => [ 'Global Templates' ] );
     $self->_set_package_info( \%params );
 
-    my $tmpl_class = CTX->template_class;
+    my $tmpl_class = CTX->lookup_class( 'template' );
     my $request = CTX->request;
     my $template = $self->param( 'template' );
     unless ( $template ) {
@@ -89,7 +89,7 @@ sub display_form {
 
 sub display_add {
     my ( $self ) = @_;
-    my $tmpl_class = CTX->template_class;
+    my $tmpl_class = CTX->lookup_class( 'template' );
 
     # We might have one leftover from a failed 'add'...
     my $template = $self->param( 'template' ) || $tmpl_class->new;
@@ -116,7 +116,7 @@ sub update {
     my $package = $request->param( 'package_original' );
     my $name    = $request->param( 'name_original' );
 
-    my $tmpl_class = CTX->template_class;
+    my $tmpl_class = CTX->lookup_class( 'template' );
     my $fq_name = $tmpl_class->create_name( $package, $name );
     my $template = eval { $tmpl_class->fetch( $fq_name ) };
     if ( $@ or ! $template ) {
@@ -154,7 +154,7 @@ sub add {
 
     my $request = CTX->request;
 
-    my $tmpl_class = CTX->template_class;
+    my $tmpl_class = CTX->lookup_class( 'template' );
     my $template = $tmpl_class->new;
 
     my $package = $request->param( 'package' );
@@ -201,7 +201,7 @@ sub remove {
     else {
         my $package = $request->param( 'package' );
         my $name    = $request->param( 'name' );
-        my $tmpl_class = CTX->template_class;
+        my $tmpl_class = CTX->lookup_class( 'template' );
         $fq_name = $tmpl_class->create_name( $package, $name );
         $template = eval { $tmpl_class->fetch( $fq_name ) };
         if ( $@ ) {
