@@ -1,15 +1,16 @@
 package OpenInteract2::Action::SystemDoc;
 
-# $Id: SystemDoc.pm,v 1.7 2003/06/25 14:10:51 lachoy Exp $
+# $Id: SystemDoc.pm,v 1.8 2003/07/08 12:04:01 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
+use OpenInteract2::Package;
 use Pod::POM;
 
-$OpenInteract2::Action::SystemDoc::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::SystemDoc::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 my ( %POD_CACHE );
 
@@ -24,17 +25,20 @@ sub package_list {
     my ( $self ) = @_;
     my $log = get_logger( LOG_APP );
 
-    # Grab the repository for thiw website and fetch a list of all the
-    # packages so we can and find the 'doc/titles' document in each, or
-    # so we can read the files from 'doc/' directly
+    # Grab the repository for this website and fetch a list of all the
+    # packages, then ask each package for its doc files which we'll
+    # treat as POD and (inelegantly) find the TITLE
 
     my $parser   = Pod::POM->new;
     my $pkg_list = CTX->repository->fetch_all_packages();
     my %pkg_docs = ();
     foreach my $pkg ( @{ $pkg_list } ) {
-        my $pkg_id = join( '-', $pkg->name, $pkg->version );
+        my $pkg_id = $pkg->full_name;
         my $pkg_dir = $pkg->directory;
         my $doc_files = $pkg->get_doc_files;
+        $log->is_info &&
+            $log->info( "Found ", scalar @{ $doc_files }, " doc files ",
+                        "in $pkg_id" );
         my @doc_titles = ();
         foreach my $doc_file ( @{ $doc_files } ) {
             $doc_file =~ s/^$pkg_dir//;
@@ -47,11 +51,13 @@ sub package_list {
                 next;
             }
             my $pom = $parser->parse_text( $content );
-            my ( $title ); # = "Unknown doc from $pkg_id";
+
+            # assumes the first head1 is a title... reasonable, but
+            # still an assumption
+
+            my ( $title );
             foreach my $head1 ( $pom->head1 ) {
-#                if ( $head1->title eq 'NAME' ) {
-                    $title ||= $head1->content;
-#                }
+                $title ||= $head1->content;
             }
             $log->is_debug &&
                 $log->debug( "Doc [$doc_file] -> [$title]" );
@@ -128,7 +134,8 @@ sub display {
 
     my $package_spec = $request->param( 'package' );
     if ( $package_spec ) {
-        my ( $package_name, $ver ) = split /\-/, $package_spec;
+        my ( $package_name, $ver ) =
+            OpenInteract2::Package->parse_full_name( $package_spec );
         my $doc = $request->param( 'doc' );
         my $repos = CTX->repository;
         if ( $doc =~ /\.(html|txt|pod)$/ ) {
@@ -151,12 +158,14 @@ sub display {
         $pod_file = $POD_CACHE{ $module } || `perldoc -l $module`;
 
         chomp $pod_file;
-        $log->is_debug &&
-            $log->debug( "Found [$pod_file] from [$module]" );
-        unless ( $pod_file ) {
+        if ( $pod_file ) {
+            $log->is_info &&
+                $log->info( "Found [$pod_file] from [$module]" );
+        }
+        else {
             $pod_file = $INC{ _uncolonify( $module ) };
-            $log->is_debug &&
-                $log->debug( "Found [$pod_file] from %INC" );
+            $log->is_info &&
+                $log->info( "Found [$pod_file] from %INC" );
         }
         if ( -f $pod_file ) {
             $POD_CACHE{ $module } = $pod_file;
@@ -173,22 +182,37 @@ sub display {
         my $parser = Pod::POM->new();
         my $pom = $parser->parse( $pod_file );
         unless ( $pom ) {
+            $log->error( "Pod::POM did not return an object: ",
+                         $parser->error() );
             return '<p>Error parsing POD: ' . $parser->error() . '</p>';
         }
 
         eval { require OpenInteract2::PodView };
         if ( $@ ) {
-            return "<p>Error trying to load POD viewer: $@</p>";
+            my $msg = "Failed to load POD viewer: $@";
+            $log->error( $msg );
+            $self->param_add( error_msg => $msg );
+            $content = 'No content';
+        }
+        else {
+            $content = eval { OpenInteract2::PodView->print( $pom ) };
+            if ( $@ ) {
+                $log->error( "Failed to output html from pod: $@" );
+                $content = "Failed to display module: $@";
+            }
+            else {
+                $content =~ s/^.*<BODY>//sm;
+                $content =~ s|</BODY>.*$||sm;
+            }
         }
-        $content = OpenInteract2::PodView->print( $pom );
-        $content =~ s/^.*<BODY>//sm;
-        $content =~ s|</BODY>.*$||sm;
     }
 
     elsif ( -f $html_file ) {
         eval { open( HTML, $html_file ) || die $! };
         if ( $@ ) {
-            return "<p>Error opening HTML file: $@" ;
+            my $msg = "Error opening HTML file: $@";
+            $log->error( "(File: $html_file) $msg" );
+            return "<p>$msg</p>";
         }
         local $/ = undef;
         $content = <HTML>;
@@ -200,7 +224,9 @@ sub display {
     elsif ( -f $text_file ) {
         eval { open( TEXT, $text_file ) || die $! };
         if ( $@ ) {
-            return "<p>Error opening TEXT file: $@";
+            my $msg = "Error opening TEXT file: $@";
+            $log->error( "(File: $text_file) $msg" );
+            return "<p>$msg</p>";
         }
         local $/ = undef;
         $content = <TEXT>;
