@@ -1,12 +1,12 @@
 package OpenInteract2::Action::TemplatesUsedBox;
 
-# $Id: TemplatesUsedBox.pm,v 1.5 2003/06/25 14:10:49 lachoy Exp $
+# $Id: TemplatesUsedBox.pm,v 1.6 2003/08/27 15:50:17 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Action::TemplatesUsedBox::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::TemplatesUsedBox::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 # Simple handler to put the list of templates used into a more
 # manageable form -- note that we can handle template objects and
@@ -22,7 +22,7 @@ sub handler {
     my %tmpl_by_package = ();
     my %tmpl_used       = ();
     my $templates_used = $controller->get_templates_used;
-    my $template_class = CTX->template_class;
+    my $template_class = CTX->lookup_class( 'template' );
     foreach my $template ( @{ $templates_used } ) {
         my ( $package, $name, $full_name );
         if ( ref $template ) {
