@@ -1,20 +1,24 @@
 package OpenInteract2::Page::Database;
 
-# $Id: Database.pm,v 1.1 2003/03/25 02:40:21 lachoy Exp $
+# $Id: Database.pm,v 1.2 2003/06/25 14:10:49 lachoy Exp $
 
 use strict;
+use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
-use OpenInteract2::Context   qw( CTX DEBUG LOG );
+use OpenInteract2::Context   qw( CTX );
 
 sub load {
     my ( $class, $page ) = @_;
+    my $log = get_logger( LOG_APP );
+
     my $page_content = eval { $page->page_content };
     if ( $@ ) {
-        LOG( LERROR, "Error retrieving content from database: $@" );
+        $log->error( "Error retrieving content from database: $@" );
         return undef;
     }
-    DEBUG && LOG( LDEBUG, "Page content location fetched from DB ",
-                          "[$page_content->{location}]" );
+    $log->is_debug &&
+        $log->debug( "Page content location fetched from DB ",
+                     "[$page_content->{location}]" );
     return $page_content->{content};
 }
 
