@@ -1,6 +1,6 @@
 package OpenInteract2::Page::File;
 
-# $Id: File.pm,v 1.4 2003/06/25 14:10:49 lachoy Exp $
+# $Id: File.pm,v 1.5 2003/09/04 03:37:22 lachoy Exp $
 
 use strict;
 use File::Basename           qw();
@@ -27,17 +27,17 @@ sub load {
 
     my $full_location = $class->_create_file_location( $page );
     unless ( -f $full_location ) {
-        $log->error( "File [$full_location] does not exist! ",
+        $log->error( "File '$full_location' does not exist! ",
                      "Bailing on load()..." );
         return undef;
     }
 
     $log->is_debug &&
-        $log->debug( "File [$full_location] exists. Reading..." );
+        $log->debug( "File '$full_location' exists. Reading..." );
 
     eval { open( STATIC, $full_location ) || die $! };
     if ( $@ ) {
-        $log->error( "Failed to read file: $@" );
+        $log->error( "Failed to read file '$full_location': $@" );
         oi_error "Cannot access file: $@";
     }
     local $/ = undef;
@@ -73,7 +73,7 @@ sub save {
 
     my $full_location = $class->_create_file_location( $page );
     $log->is_debug &&
-        $log->debug( "Trying to save content to [$full_location]" );
+        $log->debug( "Trying to save content to '$full_location'" );
 
     my $tmp_location = $full_location;
     if ( -f $full_location ) {
@@ -102,8 +102,10 @@ sub save {
         oi_error "Cannot open temp file for writing: $!";
     }
 
-    $log->is_debug &&
-        $log->debug( "Content isa: ", ref( $content ) );
+    if ( $log->is_debug ) {
+        my $content_type = ref $content || 'plain text';
+        $log->debug( "Content is: $content_type" );
+    }
 
     if ( ! ref $content ) {
         print NEW $content;
@@ -156,8 +158,8 @@ sub rename_content {
     my $log = get_logger( LOG_APP );
 
     $log->is_debug &&
-        $log->debug( "Trying to rename file from [$old_location] ",
-                     "to [$page->{location}]" );
+        $log->debug( "Trying to rename file from '$old_location' ",
+                     "to '$page->{location}'" );
     my $full_old_location = $class->_create_file_location( $old_location );
     my $full_new_location = $class->_create_file_location( $page );
 
@@ -167,10 +169,10 @@ sub rename_content {
 
     eval {
         cp( $full_old_location, $full_new_location )
-                    || die "Cannot copy [$full_old_location] to ",
-                           "[$full_new_location]: $!";
+                    || die "Cannot copy '$full_old_location' to ",
+                           "'$full_new_location': $!";
         unlink( $full_old_location )
-                    || die "Cannot remove [$full_old_location]: $!";
+                    || die "Cannot remove '$full_old_location': $!";
     };
     if ( $@ ) {
         $log->error( "Failed to copy/rename: $@" );
@@ -217,7 +219,7 @@ sub remove {
 
     my $full_location = $class->_create_file_location( $page );
     $log->is_debug &&
-        $log->debug( "Trying to delete file [$full_location]" );
+        $log->debug( "Trying to delete file '$full_location'" );
     return 1 unless ( -f $full_location );
     eval {
         unlink( $full_location )
@@ -240,11 +242,15 @@ sub _create_file_location {
     my $log = get_logger( LOG_APP );
 
     my $location = ( ref $item ) ? $item->{location} : $item;
-    my $full_location = File::Spec->catfile( CTX->server_config->{dir}{html},
+
+    # remove the leading '/' since it's not necessary for files
+    $location =~ s|^/||;
+
+    my $full_location = File::Spec->catfile( CTX->lookup_directory( 'html' ),
                                              $location );
     $log->is_debug &&
-        $log->debug( "Given location [$location], created filesystem ",
-                     "location [$full_location]" );
+        $log->debug( "Given location '$location', created filesystem ",
+                     "location '$full_location'" );
     return $full_location;
 }
 
@@ -254,22 +260,23 @@ sub _create_location_path {
     my $log = get_logger( LOG_APP );
 
     $log->is_debug &&
-        $log->debug( "See if [$location] exists or needs created" );
+        $log->debug( "See if '$location' exists or needs created" );
 
     my $dirname = File::Basename::dirname( $location );
     if ( -d $dirname ) {
         $log->is_debug &&
-            $log->debug( "Path [$dirname] [$location] exists" );
+            $log->debug( "Path '$dirname' '$location' already exists, ",
+                         "no need to create" );
         return 1;
     }
 
     eval { File::Path::mkpath( $dirname, undef, 0775 ) };
     if ( $@ ) {
-        $log->error( "Cannot create path [$dirname]: $@" );
+        $log->error( "Cannot create path '$dirname': $@" );
         oi_error "Cannot create path: $@";
     }
     $log->is_debug &&
-        $log->debug( "Path [$dirname] for [$location] created ok" );
+        $log->debug( "Path '$dirname' for '$location' created ok" );
     return 1;
 }
 
