@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall::User;
 
-# $Id: User.pm,v 1.3 2003/06/25 14:10:50 lachoy Exp $
+# $Id: User.pm,v 1.4 2003/07/08 12:16:46 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
@@ -41,8 +41,8 @@ sub get_security_file {
     return 'install_security.dat';
 }
 
-# Create the admin user and give him (or her) a default password -- be
-# sure to let the user know what this password is!
+# Create the admin user and give him (or her) a random password --
+# users should change the password using oi2_manage
 
 sub install_data {
     my ( $self ) = @_;
@@ -74,9 +74,7 @@ sub install_data {
                            undef );
     }
     else {
-        my $msg_ok = join( '', 'Created administrator ok. ',
-                               '**WRITE THIS PASSWORD DOWN!** ',
-                           "Password: $password" );
+        my $msg_ok = 'Created administrator ok.';
         $self->_set_state( $action_name, 1, $msg_ok, undef );
     }
 
@@ -95,7 +93,7 @@ OpenInteract2::SQLInstall::User - SQL installer for the base_user package
 
 =head1 SYNOPSIS
 
- $ oi_manage install_sql --package=base_user
+ $ oi2_manage install_sql --package=base_user
 
 =head1 DESCRIPTION
 
