@@ -1,6 +1,6 @@
 package OpenInteract2::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.6 2003/06/25 14:10:49 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.8 2003/09/04 03:38:39 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor );
@@ -12,7 +12,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 my $NAME_SEPARATOR = '::';
 sub NAME_SEPARATOR { return $NAME_SEPARATOR }
@@ -170,8 +170,10 @@ sub _create_from_file {
     my ( $filename, $directory ) = File::Basename::fileparse( $full_filename );
     my $modified_on =
         DateTime->from_epoch( epoch => (stat( $full_filename ))[9] );
-    $log->is_debug &&
-        $log->debug( "File [$full_filename] has time [$modified_on]" );
+    if ( $log->is_debug ) {
+        my $human_time = $modified_on->strftime( '%Y-%m-%d %H:%M:%S' );
+        $log->debug( "Template '$full_filename' last modified '$human_time'" );
+    }
     return $class->new({ package     => $package_name,
                          name        => $class->name_from_file( $filename ),
                          directory   => $directory,
@@ -189,7 +191,7 @@ sub _get_all_templates_in_directory {
     return () unless ( -d $dir );
 
     opendir( TMPL, $dir )
-                    || oi_error "Error scanning [$dir] for templates: $!";
+                    || oi_error "Error scanning '$dir' for templates: $!";
     my @files = grep { -f "$dir/$_" } readdir( TMPL );
     closedir( TMPL );
 
@@ -211,7 +213,7 @@ sub save {
     unless ( $self->name ) {
         oi_error "Cannot save template - property 'name' must be defined";
     }
-    my $template_dir = CTX->server_config->{dir}{template};
+    my $template_dir = CTX->lookup_directory( 'template' );
     unless ( $self->filename ) {
         $self->filename( $self->name );
     }
@@ -245,7 +247,7 @@ sub remove {
     my ( $self, $params ) = @_;
     my $full_filename = $self->full_filename;
     unlink( $full_filename )
-                    || oi_error "Cannot remove [$full_filename]: $!";
+                    || oi_error "Cannot remove '$full_filename': $!";
 }
 
 
@@ -275,7 +277,7 @@ sub _load_contents {
     my ( $self ) = @_;
     my $full_filename = $self->full_filename;
     open( IN, '<', $full_filename )
-                    || oi_error "Cannot open template [$full_filename]: $!";
+                    || oi_error "Cannot open template '$full_filename': $!";
     local $/ = undef;
     $self->{_contents} = <IN>;
     close( IN );
@@ -297,17 +299,20 @@ sub _save_contents {
 
     File::Path::mkpath( $self->directory );
 
-    # Then open the relevant file
+    # Then open a temp version of the relevant file
 
     my $open_filename = ( -f $full_filename )
                           ? $full_filename . '_tmp' : $full_filename;
     open( OUT, '>', $open_filename )
-        || oi_error "Cannot open template for writing [$open_filename]: $!";
+        || oi_error "Cannot open template for writing '$open_filename': $!";
     print OUT $self->{_contents};
     close( OUT );
+
+    # ...and rename the temp version to the real thing
+
     if ( $full_filename ne $open_filename ) {
         rename( $open_filename, $full_filename )
-            || oi_error "Cannot rename [$open_filename] -> [$full_filename]: $!";
+            || oi_error "Cannot rename '$open_filename' -> '$full_filename': $!";
     }
 }
 
@@ -318,7 +323,7 @@ sub _save_contents {
 
 sub _lookup_site_template_dir {
     my ( $class, $package_name ) = @_;
-    my $template_dir = CTX->server_config->{dir}{template};
+    my $template_dir = CTX->lookup_directory( 'template' );
     if ( $package_name ) {
         return File::Spec->catfile( $template_dir, $package_name );
     }
@@ -346,15 +351,16 @@ OpenInteract2::SiteTemplate - Object to represent templates
 
  # Retreive a single template based on name
  
- my $tmpl = eval { CTX->template_class
+ my $tmpl = eval { CTX->lookup_class( 'template' )
                       ->fetch( 'base_box::user_info_box' ) };
  die "Cannot retrieve box: $@" if ( $@ );
  print "Template contents: ", $tmpl->contents, "\n";
  
- # Retrieve multiple templates from a package
+ # Retrieve multiple templates from a package, using the template class directly
  
- my $tmpl_list = eval { CTX->template_class
-                           ->fetch_by_package( 'base_box' ) };
+ my $tmpl_list = eval {
+     OpenInteract2::SiteTemplate->fetch_by_package( 'base_box' )
+ };
  die "Cannot retrieve templates from base_box: $@" if ( $@ );
  foreach my $tmpl ( @{ $tmpl_list } ) {
     print "Template contents: ", $tmpl->contents, "\n";
@@ -363,7 +369,8 @@ OpenInteract2::SiteTemplate - Object to represent templates
  # Parse the common 'package::name' format
  
  my $full_name = 'base_box::main_box_shell';
- my ( $pkg, $name ) = CTX->template_class->parse_name( $full_name );
+ my ( $pkg, $name ) = CTX->lookup_class( 'template' )
+                         ->parse_name( $full_name );
  
  # Template Toolkit usage
  
