@@ -1,6 +1,6 @@
 package Apache::OpenInteract2;
 
-# $Id: OpenInteract2.pm,v 1.10 2003/06/25 16:47:53 lachoy Exp $
+# $Id: OpenInteract2.pm,v 1.11 2003/08/21 03:45:01 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
@@ -22,7 +22,9 @@ sub handler($$) {
     my $response = OpenInteract2::Response->new({ apache => $r });
     my $request  = OpenInteract2::Request->new({ apache => $r });
 
-    OpenInteract2::Auth->login( $r->pnotes( 'login_user' ) );
+    my $http_auth_user = $r->pnotes( 'login_user' );
+    my $auth = OpenInteract2::Auth->new({ user => $http_auth_user });
+    $auth->login();
 
     my $controller = eval {
         OpenInteract2::Controller->new( $request, $response )
