@@ -1,6 +1,6 @@
 package OpenInteract2::Action;
 
-# $Id: Action.pm,v 1.32 2003/07/02 15:06:53 lachoy Exp $
+# $Id: Action.pm,v 1.39 2003/09/05 02:18:24 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor Class::Observable Class::Factory Exporter );
@@ -12,7 +12,7 @@ use OpenInteract2::Util;
 use Scalar::Util             qw( blessed );
 use SPOPS::Secure            qw( :level );
 
-$OpenInteract2::Action::VERSION  = sprintf("%d.%02d", q$Revision: 1.32 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::VERSION  = sprintf("%d.%02d", q$Revision: 1.39 $ =~ /(\d+)\.(\d+)/);
 
 use constant CACHE_CLASS_KEY => 'class_cache_track';
 
@@ -28,12 +28,16 @@ use constant DEFAULT_ACTION_SECURITY => SEC_LEVEL_WRITE;
 # See 'PROPERTIES' section below for other properties used.
 
 my %PROPS = map { $_ => 1 }
-            qw( request response controller
-                action_type class method task task_default
-                content_generator security_level security_required security
-                url_alt url_none template_source
+            qw(
+                request response controller content_generator
+                action_type class method message_name
+                task task_default task_valid task_invalid
+                security_level security_required security
+                url_alt url_none
+                template_source
                 cache_expire cache_param
-                task_valid task_invalid );
+            );
+
 __PACKAGE__->mk_accessors( keys %PROPS );
 
 # Used to track classes, types, methods and security info
@@ -42,6 +46,10 @@ my %CLASSES_USED        = ();
 my %ACTION_TASK_METHODS = ();
 my %ACTION_SECURITY     = ();
 
+# Class method, called when server starts up
+
+sub init_at_startup { return; }
+
 ########################################
 # CONSTRUCTOR
 
@@ -49,6 +57,7 @@ my %ACTION_SECURITY     = ();
 
 sub new {
     my ( $class, $item, $props ) = @_;
+    $props ||= {};
     my ( $self );
 
     my $log = get_logger( LOG_ACTION );
@@ -61,11 +70,6 @@ sub new {
         $self = bless( {}, ref( $item ) );
         $self->property_assign( $item->property );
         $self->param_assign( $item->param );
-
-        # these will override the previous assignments
-        $self->property_assign( $props );
-        $self->param_assign( $props );
-        return $self->init();
     }
 
     # ...or action info
@@ -73,7 +77,7 @@ sub new {
         $log->is_debug &&
             $log->debug( "Creating new action from action info with name ",
                          "[$item->{name}]" );
-        return $class->_create_from_config( $item, $props );
+        $self = $class->_create_from_config( $item, $props );
     }
 
     # ...or a name
@@ -83,19 +87,31 @@ sub new {
 
         # This will throw an error if the action cannot be found
         my $action_info = CTX->lookup_action_info( $item );
-
-        return $class->_create_from_config( $action_info, $props );
+        $self = $class->_create_from_config( $action_info, $props );
     }
 
     # ...or nothing.
     # TODO: get rid of this? do we ever need to create an action without a name?
     else {
         $self = bless( {}, $class );
-        $props ||= {};
-        $self->property_assign( $props );
-        $self->param_assign( $props );
-        return $self->init();
     }
+
+    # ...pickup messages deposited in the request...
+    my $action_msg_name = $self->message_name || $self->name;
+    if ( CTX and $action_msg_name ) {
+        my $request = CTX->request;
+        if ( $request and my $messages = $request->action_messages( $action_msg_name ) ) {
+            while ( my ( $msg_name, $msg ) = each %{ $messages } ) {
+                $self->add_view_message( $msg_name => $msg );
+            }
+        }
+    }
+
+    # ...these will override any previous assignments
+    $self->property_assign( $props );
+    $self->param_assign( $props );
+
+    return $self->init();
 }
 
 sub _create_from_config {
@@ -141,11 +157,7 @@ sub _create_from_config {
     $self->_set_url( $url );
     $self->property_assign( $action_info );
     $self->param_assign( $action_info );
-
-    # these will override the previous assignments
-    $self->property_assign( $props );
-    $self->param_assign( $props );
-    return $self->init();
+    return $self;
 }
 
 
@@ -171,16 +183,16 @@ sub execute {
     # methods will throw an exception if the action does not pass
 
     unless ( $self->task ) {
-        $self->task( $self->find_task );
+        $self->task( $self->_find_task );
     }
 
     # These checks will die if they fail -- let the error bubble up
 
-    $self->check_task_validity;
+    $self->_check_task_validity;
     $log->is_debug &&
         $log->debug( "Task is valid, continuing" );
 
-    $self->check_security;
+    $self->_check_security;
     $log->is_debug &&
         $log->debug( "Task security checked, continuing" );
 
@@ -190,7 +202,7 @@ sub execute {
     $log->is_debug &&
         $log->debug( "Cached data not found, continuing" );
 
-    my $method_ref = $self->find_task_method;
+    my $method_ref = $self->_find_task_method;
     $log->is_debug &&
         $log->debug( "Found task method ok, running" );
 
@@ -226,9 +238,7 @@ sub forward {
 ########################################
 # TASK
 
-# TODO: Should find_task() be internal-only?
-
-sub find_task {
+sub _find_task {
     my ( $self ) = @_;
 
     # NOTE: a defined 'method' in the action will ALWAYS override a
@@ -252,9 +262,7 @@ sub find_task {
 # Ensure that the task assigned is valid: if not throw an
 # exception. There must be a task defined by this point.
 
-# TODO: Should check_task_validity() be internal-only?
-
-sub check_task_validity {
+sub _check_task_validity {
     my ( $self ) = @_;
     my $check_task = lc $self->task;
     my $log = get_logger( LOG_ACTION );
@@ -291,9 +299,7 @@ sub check_task_validity {
 # calling and return that coderef; otherwise if the task method
 # actually exists return that coderef. If not, throw an exception.
 
-# TODO: Should find_task_method() be internal-only?
-
-sub find_task_method {
+sub _find_task_method {
     my ( $self ) = @_;
     my $task = $self->task;
     my $log = get_logger( LOG_ACTION );
@@ -326,25 +332,23 @@ sub find_task_method {
 ########################################
 # SECURITY
 
-# TODO: Should check_security() be internal-only?
-
-sub check_security {
+sub _check_security {
     my ( $self ) = @_;
     my $log = get_logger( LOG_ACTION );
 
-    unless ( $self->is_secure ) {
-        $log->is_info &&
-            $log->info( "Action not secured, assign default security and ",
-                        "skip security check" );
-        $self->security_level( DEFAULT_ACTION_SECURITY );
-        return;
+    unless ( $self->security_level ) {
+        $self->security_level( $self->_find_security_level );
     }
 
-    unless ( $self->security_level ) {
-        $self->find_security_level;
-    }
+    return $self->security_level unless ( $self->is_secure );
 
     my $action_security = $self->security;
+    unless ( ref $action_security eq 'HASH' ) {
+        $log->error( "Secure action, no security configuration" );
+        oi_error "Configuration error: action is secured but no ",
+                 "security requirements configured";
+    }
+
     my $task  = $self->task;
     my $required_level = $action_security->{ $task } ||
                          $action_security->{DEFAULT} ||
@@ -360,8 +364,6 @@ sub check_security {
 
     $self->security_required( $required_level );
 
-    # TODO: Dependency on object_id '0' sucks
-
     my $action_level = $self->security_level;
     if ( $required_level > $action_level ) {
         my $msg = join( '', "Security check for [", $self->name, "] ",
@@ -372,13 +374,12 @@ sub check_security {
                           { security_required => $required_level,
                             security_found    => $action_level };
     }
+    return $self->security_level;
 }
 
 # Find the level for this user/group and this action
 
-# TODO: Should find_security_level() be internal-only?
-
-sub find_security_level {
+sub _find_security_level {
     my ( $self ) = @_;
     my $log = get_logger( LOG_ACTION );
 
@@ -386,14 +387,11 @@ sub find_security_level {
         $log->is_debug &&
             $log->debug( "Action ", $self->name, " not secured, ",
                          "assigning default level." );
-        return $self->security_level( DEFAULT_ACTION_SECURITY );
-    }
-    my $action_security = $self->security;
-    unless ( ref $action_security eq 'HASH' ) {
-        $log->error( "Secure action, no security configuration" );
-        oi_error "Configuration error: action is secured but no ",
-                 "security requirements configured";
+        return DEFAULT_ACTION_SECURITY;
     }
+
+    # TODO: Dependency on object_id '0' sucks
+
     my $found_level = eval {
         CTX->check_security({ class     => ref $self,
                               object_id => '0' })
@@ -404,7 +402,7 @@ sub find_security_level {
     }
     $log->is_debug &&
         $log->debug( "Found security level $found_level" );
-    return $self->security_level( $found_level );
+    return $found_level;
 }
 
 
@@ -420,6 +418,7 @@ sub generate_content {
         $log->debug( "Generating content for [", $self->name, "]" );
 
     $content_params->{ACTION} = $self;
+    $content_params->{action_messages} = $self->view_messages;
 
     # If source wasn't specified see if it's found in
     # 'template_source'
@@ -765,6 +764,19 @@ sub param_from_request {
     }
 }
 
+sub view_messages {
+    my ( $self, $messages ) = @_;
+    if ( ref $messages eq 'HASH' ) {
+        $self->{_view_msg} = $messages
+    }
+    $self->{_view_msg} ||= {};
+    return $self->{_view_msg};
+}
+
+sub add_view_message {
+    my ( $self, $msg_name, $msg ) = @_;
+    return $self->{_view_msg}{ $msg_name } = $msg;
+}
 
 ########################################
 # URL
@@ -835,6 +847,20 @@ sub context  {
     die 'HEY! Change $action->context call at ', join( ' / ', caller );
 }
 
+########################################
+# FACTORY
+
+sub factory_log {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_ACTION )->info( @msg );
+}
+
+sub factory_error {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_ACTION )->error( @msg );
+    die @msg, "\n";
+}
+
 1;
 
 __END__
@@ -869,7 +895,7 @@ OpenInteract2::Action - Represent and dispatch actions
  latest            = num_items
  
  # You can declare security levels in the action configuration, or you
- # can override the method find_security_level()
+ # can override the method _find_security_level()
  
  [news security]
  default           = write
@@ -974,6 +1000,44 @@ action directly, constructed by passing parameters to a content
 generator, or passed off to another action for generation. (See
 L<GENERATING CONTENT FOR ACTION> below.)
 
+=head2 Action Class Initialization
+
+When OpenInteract starts up it will call C<init_at_startup()> on every
+configured action class. This is useful for reading static (or rarely
+changing) information once and caching the results. Since the
+L<OpenInteract2::Context|OpenInteract2::Context> object is guaranteed
+to have been created when this is called you can grab a database
+handle and slurp all the lookup entries from a table into a lexical
+data structure.
+
+Here's an example:
+
+ use Log::Log4perl            qw( get_logger );
+ use OpenInteract2::Context   qw( CTX );
+ 
+ # Publishers don't change very often, so keep them local so we don't
+ # have to fetch every time
+ 
+ my %publishers = ();
+ 
+ ...
+ 
+ sub init_at_startup {
+     my ( $class ) = @_;
+     my $log = get_logger( LOG_APP );
+     my $publisher_list = eval {
+         CTX->lookup_object( 'publisher' )->fetch_group()
+     };
+     if ( $@ ) {
+         $log->error( "Failed to fetch publishers at startup: $@" );
+     }
+     else {
+         foreach my $publisher ( @{ $publisher_list } ) {
+             $publishers{ $publisher->name } = $publisher;
+         }
+     }
+ }
+
 =head2 Action Tasks
 
 Each action can be viewed as an associated collection of
@@ -1080,7 +1144,7 @@ forbid the 'add' task from being executed with:
  class        = OpenInteract2::Action::News
  task_invalid = add
 
-See discussion of C<find_task()> and C<check_task_validity()> for more
+See discussion of C<_find_task()> and C<_check_task_validity()> for more
 information.
 
 =head2 Action Types
@@ -1313,6 +1377,9 @@ they're setup), so you could have:
 
 Most of the time you'll likely use 'class' since it's the easiest.
 
+See L<OpenInteract2::Filter|OpenInteract2::Filter> for more
+information.
+
 =head1 MAPPING URL TO ACTION
 
 In OI 1.x the name of an action determined what URL it responded
@@ -1441,12 +1508,12 @@ C<action_table()>. Whenever the action table is assigned to the
 context is iterates through the actions, asks each one which URLs it
 responds to and creates a mapping so the URL can be quickly looked up.
 
-One other thing to note about that context method: it also embeds
-B<primary> URL for each action in the action information stored in the
-action table. Since the information is stored in a key that's not a
-property or parameter the action itself doesn't care about this. But
-it's useful to note because when you generate URLs based on an action
-the B<first> URL is used, as discussed in the examples above.
+One other thing to note about that context method: it also embeds the
+B<primary> URL for each action in the information stored in the action
+table. Since the information is stored in a key that's not a property
+or parameter the action itself doesn't care about this. But it's
+useful to note because when you generate URLs based on an action the
+B<first> URL is used, as discussed in the examples above.
 
 So, to repeat the examples above, when you have:
 
@@ -1623,6 +1690,24 @@ Example:
  url_alt  = Nouvelles
  url_alt  = Noticias
 
+B<message_name> ($)
+
+Name used to find messages from the
+L<OpenInteract2::Request|OpenInteract2::Request> object. Normally you
+don't need to specify this and the action name is used. But if you
+have multiple actions pointing to the same code this can be useful
+
+Example:
+
+ [news]
+ class        = MyPackage::Action::News
+ task_default = latest
+ 
+ [latestnews]
+ class        = MyPackage::Action::News
+ method       = latest
+ message_name = news
+
 B<action_type> ($)
 
 The type of action this is. Action types can provide default tasks,
@@ -1661,7 +1746,7 @@ name of one.
 Example:
 
  if ( $action->content_generator eq 'TT' ) {
-     print "Content for this action will be generated by Template Toolkit.";
+     print "Content for this action will be generated by the Template Toolkit.";
  }
 
 The property is frequently inherited from the default action, so you
@@ -1676,8 +1761,9 @@ content generators can understand the specified template source. This
 will probably never happen given the sheer variety of templating
 systems on the planet.)
 
-This B<will not work> in place of required parameters for the common
-actions, see
+This B<will not work> when an action superclass requires different
+parameters to specify content templates. One set of examples are the
+subclasses
 L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>.
 
 Example, not using 'template_source'. First the action configuration:
@@ -1750,7 +1836,7 @@ Example:
      }
  }
 
-B<security_required> (bool)
+B<security_required> ($)
 
 If the action is using security, what level is required for the action
 to successfully execute.
@@ -1767,7 +1853,7 @@ Example:
  }
 
 (Note: you will never need to do this since the
-C<find_security_level()> method does this (and more) for you.)
+C<_find_security_level()> method does this (and more) for you.)
 
 B<security_level> ($)
 
@@ -1814,6 +1900,16 @@ Example:
  my $bad_tasks = $action->task_invalid;
  print "Tasks not allowed for action: ", join( ', ', @{ $bad_tasks } ), "\n";
 
+B<cache_expire> (\%)
+
+Mapping of task name to expiration time for cached data, in seconds.
+
+B<cache_param> (\%)
+
+Mapping of task name to zero or more parameters (action/request) used
+to identify the cached data. (See
+L<OpenInteract2::Manual::Caching|OpenInteract2::Manual::Caching>)
+
 =head1 METHODS
 
 =head2 Class Methods
@@ -2016,6 +2112,8 @@ The C<\%vars> argument will set properties and parameters (via
 C<property_assign()> and C<param_assign()>) before generating the
 content.
 
+TODO: fill in info about caching
+
 Returns: content generated by the action
 
 B<forward( $new_action )>
@@ -2055,123 +2153,6 @@ generated by this class.
 
 Returns: number of cache entries removed
 
-B<find_task()>
-
-Tries to find a task for the action. In order, the method looks:
-
-=over 4
-
-=item *
-
-In the 'method' property of the action. This means the action is
-hardwired to a particular method and cannot be changed, even if you
-set 'task' manually.
-
-TODO: This might change... why use 'method' when we could keep with
-the task terminology and use something like 'task_concrete' or
-'task_only'?
-
-=item *
-
-In the 'task' property of the action: it might already be defined!
-
-=item *
-
-In the 'task_default' property of the action.
-
-=back
-
-If a task is not found we throw an exception.
-
-Returns: name of task.
-
-B<check_task_validity()>
-
-Ensure that task assigned is valid. If it is not we throw an
-L<OpenInteract2::Exception|OpenInteract2::Exception>.
-
-A valid task:
-
-=over 4
-
-=item *
-
-Does not begin with an underscore.
-
-=item *
-
-Is not listed in the C<task_invalid> property.
-
-=item *
-
-Is listed in the C<task_valid> property, if that property is defined.
-
-=back
-
-Returns: nothing, throwing an exception if the check fails.
-
-B<find_task_method()>
-
-Finds a valid method to call for the action task. If the method
-C<handler()> is defined in the action class or any of its parents,
-that is called. Otherwise we check to see if the method C<$task()> --
-which should already have been checked for validity -- is defined in
-the action class or any of its parents. If neither is found we throw
-an exception.
-
-You are currently not allowed to have a task of the same name as one
-of the action properties. If you try to execute a task by this name
-you'll get a message in the error log to this effect.
-
-Note that we cache the returned code reference, so if you do something
-funky with the symbol table or the C<@ISA> for your class after a
-method has been called, everything will be mucked up.
-
-Returns: code reference to method for task.
-
-B<find_security_level()>
-
-If this action is secured, finds the security level for this
-combination of action, user and groups.
-
-=over 4
-
-=item *
-
-First it looks at the 'is_secure' action property -- if true we
-continue, otherwise we return C<SEC_LEVEL_WRITE> so the system will
-allow any user to perform the task.
-
-=item *
-
-Second, we call C<get_security_requirements()> to get a hashref of
-security required for the action. If one is not returned we throw an
-exception.
-
-=item *
-
-Third, we find the security level required for this particular
-task. If neither the task nor 'DEFAULT' is not defined in the hashref
-of security requirements, we assume that C<SEC_LEVEL_WRITE> security
-is required.
-
-=item *
-
-Fourth, we find the actual security level for this action and user.
-
-=item *
-
-Finally, we compare the required security with the actual security. If
-the actual is less than the required we throw an
-L<OpenInteract2::Exception::Security|OpenInteract2::Exception::Security>
-object. Otherwise we set the actual security level under the property
-'security_level'.
-
-=back
-
-Returns: valid security level found; if security level less than
-required an exception is thrown.
-
 =head2 Object Content Methods
 
 B<generate_content( \%content_params, [ \%template_source ], [ \%template_params ] )>
@@ -2182,7 +2163,11 @@ The information in C<\%template_source> is only optional if you've
 specified the source in your action configuration. See the docs for
 property B<template_source> for more information.
 
-TODO: fill this in
+Also, note that any view messages you've added via C<view_messages()>
+or C<add_view_message()> will be passed to the template in the key
+C<action_messages>.
+
+TODO: fill in more: how to id content
 
 =head2 Object Property and Parameter Methods
 
@@ -2306,6 +2291,162 @@ defined.
 
 Returns: nothing
 
+B<view_messages( [ \%messages ] )>
+
+Returns the message names and associated messages in this
+action. These may have been set directly or they may have been
+deposited in the request (see C<action_messages()> in
+L<OpenInteract2::Request|OpenInteract2::Request>) and picked up at
+action instantiation.
+
+Note that these get put in the template's content variable hashref
+under the key C<action_messages> as long as the content is generated
+using C<generate_content()>.
+
+Returns: hashref of view errors associated with this action; may be an
+empty hashref.
+
+B<add_view_message( $msg_name, $msg )>
+
+Assign the view messgate C<$msg_name> as C<$msg> in this action.
+
+=head2 Internal Object Execution Methods
+
+You should only need to know about these methods if you're creating
+your own action.
+
+B<_find_task()>
+
+Tries to find a task for the action. In order, the method looks:
+
+=over 4
+
+=item *
+
+In the 'method' property of the action. This means the action is
+hardwired to a particular method and cannot be changed, even if you
+set 'task' manually.
+
+TODO: This might change... why use 'method' when we could keep with
+the task terminology and use something like 'task_concrete' or
+'task_only'?
+
+=item *
+
+In the 'task' property of the action: it might already be defined!
+
+=item *
+
+In the 'task_default' property of the action.
+
+=back
+
+If a task is not found we throw an exception.
+
+Returns: name of task.
+
+B<_check_task_validity()>
+
+Ensure that task assigned is valid. If it is not we throw an
+L<OpenInteract2::Exception|OpenInteract2::Exception>.
+
+A valid task:
+
+=over 4
+
+=item *
+
+Does not begin with an underscore.
+
+=item *
+
+Is not listed in the C<task_invalid> property.
+
+=item *
+
+Is listed in the C<task_valid> property, if that property is defined.
+
+=back
+
+Returns: nothing, throwing an exception if the check fails.
+
+B<_find_task_method()>
+
+Finds a valid method to call for the action task. If the method
+C<handler()> is defined in the action class or any of its parents,
+that is called. Otherwise we check to see if the method C<$task()> --
+which should already have been checked for validity -- is defined in
+the action class or any of its parents. If neither is found we throw
+an exception.
+
+You are currently not allowed to have a task of the same name as one
+of the action properties. If you try to execute a task by this name
+you'll get a message in the error log to this effect.
+
+Note that we cache the returned code reference, so if you do something
+funky with the symbol table or the C<@ISA> for your class after a
+method has been called, everything will be mucked up.
+
+Returns: code reference to method for task.
+
+B<_check_security()>
+
+Checks security for this action. On failure throws a security
+exception, on success returns the security level found (also set in
+the action property C<security_level>). Here are the steps we go
+through:
+
+=over 4
+
+=item *
+
+First we get the security level for this action. If already set (in
+the C<security_level> property) we use that. Otherwise we call
+C<_find_security_level> to determine the level. This is set in the
+action property C<security_level>.
+
+=item *
+
+If the action isn't secured we short-circuit operations and return the
+security level.
+
+=item *
+
+Third, we ensure that the action property C<security> contains a
+hashref. If not we throw an exception.
+
+=item *
+
+Next, we determine the security level required for this particular
+task. If neither the task nor 'DEFAULT' is defined in the hashref of
+security requirements, we assume that C<SEC_LEVEL_WRITE> security is
+required.
+
+The level found is set in the action property C<security_required>.
+
+=item *
+
+Finally, we compare the C<security_level> with the
+C<security_required>. If the required level is greater we throw a
+security exception.
+
+=back
+
+Returns: security level for action if security check okay, exception
+if not.
+
+B<_find_security_level()>
+
+Returns the security level for this combination of action, user and
+groups. First it looks at the 'is_secure' action property -- if true we
+continue, otherwise we return C<SEC_LEVEL_WRITE> so the system will
+allow any user to perform the task.
+
+If the action is secured we find the actual security level for this
+action and user and return it.
+
+Returns: security level for action given current user and groups.
+
 =head1 TO DO
 
 B<URL handling>
