@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Common;
 
-# $Id: Common.pm,v 1.11 2003/06/26 14:11:02 lachoy Exp $
+# $Id: Common.pm,v 1.13 2003/09/05 02:21:36 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error oi_security_error );
 
-$OpenInteract2::Action::Common::VERSION   = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Common::VERSION   = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract2::Action::Common::AUTOLOAD  = '';
 
 my %COMMON_TASKS = (
@@ -138,20 +138,33 @@ sub _common_check_id {
     my ( $self ) = @_;
     my $log = get_logger( LOG_ACTION );
 
-    my $id_field = $self->param( 'c_id_field' );
+    # First see if the object itself has been defined; if so we don't
+    # care if the ID has been set
+
+    if ( my $object = $self->param( 'c_object' ) ) {
+        return 0 if ( $object->is_saved );
+    }
+
+    # Next, find the ID
+
     my $id = $self->param( 'c_id' );
+    if ( $id ) {
+        return 0;
+    }
+
+    my $id_field = $self->param( 'c_id_field' );
     if ( ! defined $id and $id_field ) {
         $id = $self->param( $id_field )
               || CTX->request->param( $id_field )
               || CTX->request->param( 'id' );
     }
-    if ( $id ) {
+    if ( defined $id ) {
         $self->param( c_id => $id );
     }
     else {
-        $log->warn( "No ID found in action/request [$id_field]" );
+        $log->warn( "No ID found in action/request '$id_field'" );
         my $msg = join( '', "No value found in action parameters or ",
-                            "request for ID field [$id_field]." );
+                            "request for ID field '$id_field'." );
         $self->param_add( error_msg => $msg );
         return 1;
     }
