@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonAdd;
 
-# $Id: CommonAdd.pm,v 1.9 2003/06/24 03:35:38 lachoy Exp $
+# $Id: CommonAdd.pm,v 1.13 2003/09/05 02:21:53 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -59,7 +59,7 @@ sub add {
           datetime_format => scalar $self->param( 'c_add_datetime_format' ), } );
 
     # If after customizing/inspecting the object you want to bail and
-    # go somewhere else, return content
+    # go somewhere else, die with content
 
     my %save_options = ();
     $self->_add_customize( $object, \%save_options );
@@ -72,9 +72,9 @@ sub add {
         return $self->execute({ task => $fail_task });
     }
     $self->param( c_object => $object );
+    $self->param( c_id => scalar $object->id );
     $self->param( status_msg => 'Object created properly' );
     $self->_add_post_action;
-    $self->param( c_id => scalar $object->id );
     my $success_task = $self->param( 'c_add_task' );
     return $self->execute({ task => $success_task });
 }
@@ -186,20 +186,25 @@ None
 B<_add_customize( $object, \%save_options )>
 
 Called just before the C<save()> operation which creates the object in
-your datastore. You have two opportunities to affect the operation:
+your datastore. You have three opportunities to affect the operation:
 
 =over 4
 
 =item *
 
-Return content from the method. This content will be sent on to the
-user. This gives you an opportunity to do any necessary validation,
-quota ceiling inspections, time of day checking, etc.
+Modify the object being saved by modifying or adding values to
+C<$object>.
 
 =item *
 
-Modify the options passed to C<save()> by setting values in
-C<\%save_options>.
+Modify the options passed to C<save()> by modifying or adding values
+to C<\%save_options>.
+
+=item *
+
+Throw a C<die> with content from the method. This content will be sent
+on to the user. This gives you an opportunity to do any necessary
+validation, quota ceiling inspections, time of day checking, etc.
 
 =back
 
@@ -211,8 +216,8 @@ Here's an example of a validation check:
 
          # First set an error message to tell the user what's wrong...
 
-         $self->param_add(
-             error_msg => "Only large widgets of type Frobozz are allowed' );
+         $self->add_view_message(
+             size => "Only large widgets of type Frobozz are allowed' );
 
          # Next, provide the object with its values to the form so we
          # can prepopulate it...
@@ -221,7 +226,7 @@ Here's an example of a validation check:
 
          # ...and display the editing form again
 
-         return $self->execute( task => 'display_add' );
+         die $self->execute({ task => 'display_add' });
      }
  }
 
@@ -229,8 +234,10 @@ B<_add_post_action>
 
 This method is called after the object has been successfully created
 -- you'll find the object in the C<c_object> action parameter. You can
-perform any action you like after this. If you return content it will
-be displayed to the user rather than the configured C<c_add_task>.
+perform any action you like in this method. Similar to
+C<_add_customize()>, if you throw a C<die> with content it will be
+displayed to the user rather than moving to the configured
+C<c_add_task>.
 
 =head1 CONFIGURATION FOR 'add'
 
