@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonRemove;
 
-# $Id: CommonRemove.pm,v 1.7 2003/06/25 14:11:57 lachoy Exp $
+# $Id: CommonRemove.pm,v 1.10 2003/08/20 13:32:22 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -15,7 +15,7 @@ sub remove {
     my $log = get_logger( LOG_ACTION );
 
     my $fail_task = $self->param( 'c_remove_fail_task' );
-    my $object = eval { $self->fetch_object };
+    my $object = eval { $self->_common_fetch_object };
     if ( $@ ) {
         return $self->execute({ task => $fail_task });
     }
@@ -38,8 +38,7 @@ sub remove {
         return $self->execute({ task => $sec_fail_task });
     }
 
-    my $bail_content = $self->_remove_customize;
-    return $bail_content if ( $bail_content );
+    $self->_remove_customize;
 
     eval { $object->remove };
     if ( $@ ) {
@@ -55,7 +54,7 @@ sub remove {
 }
 
 my %DEFAULTS = (
-    c_remove_fail_task       => 'common_error',
+    c_remove_fail_task => 'common_error',
 );
 
 sub _remove_init_param {
@@ -80,6 +79,8 @@ sub _remove_customize { return undef }
 
 1;
 
+__END__
+
 =head1 NAME
 
 OpenInteract2::Action::CommonRemove - Task to remove an object
@@ -124,10 +125,10 @@ Called before the object removal. You can record the object being
 removed (found in the action parameter C<c_object>) or any other
 action you like.
 
-This method is different from the other common C<_*_customize> methods
-in that you can short-circuit the operation. If you return content
-from this method the object will not be removed and the content
-displayed.
+You can short-circuit the operation by throwing a C<die> with content
+from the method. This content will be sent on to the user. This gives
+you an opportunity to do any necessary validation, quota ceiling
+inspections, time of day checking, etc.
 
 =head1 CONFIGURATION FOR 'remove'
 
