@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonSearch;
 
-# $Id: CommonSearch.pm,v 1.9 2003/06/25 14:11:57 lachoy Exp $
+# $Id: CommonSearch.pm,v 1.10 2003/07/11 05:11:15 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -10,7 +10,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::ResultsManage;
 
-$OpenInteract2::Action::CommonSearch::VERSION   = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::CommonSearch::VERSION   = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 ########################################
 # SEARCH FORM
@@ -111,6 +111,7 @@ sub search {
         $self->_search_catch_errors( "$@" );
     }
 
+    $tmpl_params{search_criteria} = $self->param( 'c_search_criteria' );
     my $results_template = $self->param( 'c_search_results_template' );
     $self->_search_customize( \%tmpl_params );
     return $self->generate_content(
@@ -538,10 +539,7 @@ B<c_search_results_template>
 Fully qualified template name for your search results. If undefined
 you'll get the standard error page.
 
-The parameters passed to your template are different depending on the
-value of C<c_search_results_paged> (see below).
-
-If it is set to 'yes', you'll get the following::
+These paramters are available to your template:
 
 =over 4
 
@@ -552,6 +550,21 @@ results.
 
 =item *
 
+B<search_criteria>: A hashref of the criteria we used to run the
+search. Note that the search strings does not contain any wildcards
+(e.g., '%') and that the keys are fully-qualified fieldnames (e.g.,
+'book.title'). If you plan to display the results you may want to
+modify the fieldnames in C<_search_customize()>.
+
+=back
+
+And if you've set C<c_search_results_paged> (see below) to 'yes'
+you'll also get:
+
+=over 4
+
+=item *
+
 B<page_num>: Page of the results we're currently on.
 
 =item *
@@ -568,16 +581,11 @@ B<search_id>: The ID of this search.
 
 =back
 
-If it is set to no, you'll get:
-
-=over 4
-
-=item *
-
-B<iterator>: An L<SPOPS::Iterator|SPOPS::Iterator> with your search
-results.
-
-=back
+If C<c_search_results_paged> is set to 'no', you'll get nothing beyond
+the default. The only difference is that 'iterator' will contain all
+of your search results. If you'd like to get all the results in a list
+so you can see how many there are, call 'get_all()' on the iterator
+and ask the returned arrayref how many members it contains.
 
 =head1 METHODS FOR 'search'
 
