@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonUpdate;
 
-# $Id: CommonUpdate.pm,v 1.9 2003/06/24 03:35:38 lachoy Exp $
+# $Id: CommonUpdate.pm,v 1.12 2003/08/30 21:47:36 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -233,23 +233,46 @@ None
 
 B<_update_customize( $object, \%old_data, \%save_options )>
 
-You can make any necessary customizations to C<$object> before it's
-updated. You even have access to its previous values in the
-C<\%old_data> mapping.
+You can validate the data in C<$object> and ensure that invalid data
+don't get saved. You can also make any necessary customizations (such
+as setting defaults) to C<$object> before it's updated. You even have
+access to its previous values in the C<\%old_data> mapping.
 
-If you've encountered an error condition return the necessary
-content. The update will not happen and the user will see whatever
-you've generated.
+If you've encountered an error condition (including invalid data),
+throw a C<die> with the necessary content. The update will not happen
+and the user will see whatever you've generated.
 
 You can also specify keys and values in C<\%save_options> which get
 passed along to the C<save()> call.
 
+Here's an example of validating your data using the 'view messages'
+found in the L<OpenInteract2::Action|OpenInteract2::Action>
+object. Here we'll assume that we have a database of books and
+someone is updating a particular book record:
+
+ sub _update_customize {
+     my ( $self, $book, $old_book, $save_options ) = @_;
+     my $validation_errors = 0;
+     unless ( $book->{title} ) {
+         $self->add_view_message( title => 'Book must have a title' );
+         $validation_errors++;
+     }
+     unless ( $book->{author_last} ) {
+         $self->add_view_message( author_last => 'Book author must have a last name' );
+         $validation_errors++;
+     }
+     if ( $validation_errors ) {
+         die $self->execute({ task => 'display_form' });
+     }
+ }
+
 B<_update_post_action>
 
 This method is called after the object has been successfully updated
 -- you'll find the object in the C<c_object> action parameter. You can
-perform any action you like after this. If you return content it will
-be displayed to the user rather than the configured C<c_update_task>.
+perform any action you like after this. If you throw a C<die> with
+content it will be displayed to the user rather than moving to the
+configured C<c_update_task>.
 
 =head1 CONFIGURATION FOR 'update'
 
@@ -268,7 +291,24 @@ this is not defined we'll just use C<c_update_fail_task>.
 
 B<c_update_task> ($)
 
-Task to execute when the update succeeds.
+Task to execute when the update succeeds. You can get at the object
+just updated in the C<c_object> paramter:
+
+ [book]
+ class = OpenInteract2::Action::Book
+ ...
+ c_update_task = display_modify_status
+ 
+ package OpenInteract2::Action::Book;
+ ...
+ sub display_modify_status {
+     my ( $self ) = @_;
+     my $book = $self->param( 'c_object' );
+     my $output = 'Updated [% title %] properly';
+     return $self->generate_content(
+                     { title => $book->title },
+                     { text => $output } );
+ }
 
 Default: 'display_form'
 
