@@ -1,13 +1,13 @@
 package OpenInteract2::Action::TemplateOnly;
 
-# $Id: TemplateOnly.pm,v 1.2 2003/06/11 02:43:31 lachoy Exp $
+# $Id: TemplateOnly.pm,v 1.3 2003/07/27 18:21:18 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
 
-$OpenInteract2::Action::TemplateOnly::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::TemplateOnly::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
-sub find_task {
+sub _find_task {
     return 'execute_template';
 }
 
