@@ -1,40 +1,41 @@
 package OpenInteract2::Auth::AdminCheck;
 
-# $Id: AdminCheck.pm,v 1.5 2003/06/24 03:35:38 lachoy Exp $
+# $Id: AdminCheck.pm,v 1.9 2003/09/05 13:30:29 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Auth::AdminCheck::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Auth::AdminCheck::VERSION  = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 sub is_admin {
-    my ( $class, $user, $is_logged_in, $groups ) = @_;
+    my ( $class, $auth ) = @_;
     my $log = get_logger( LOG_AUTH );
-    unless ( $is_logged_in ) {
+    unless ( $auth->is_logged_in ) {
         $log->is_debug &&
             $log->debug( "User not logged in: NOT admin" );
-        return 0;
+        return $auth->is_admin( 'no' );
     }
-    my $server_config = CTX->server_config;
-    if ( $user->id eq $server_config->{default_objects}{superuser} ) {
+    if ( $auth->user->id eq CTX->default_object_id( 'superuser' ) ) {
         $log->is_debug &&
             $log->debug( "User is superuser: IS admin" );
-        return 1;
+        return $auth->is_admin( 'yes' );
     }
 
-    my $site_admin_id = $server_config->{default_objects}{site_admin_group};
-    my $supergroup_id = $server_config->{default_objects}{supergroup};
+    my $site_admin_id = CTX->default_object_id( 'site_admin_group' );
+    my $supergroup_id = CTX->default_object_id( 'supergroup' );
+
+    my $groups = $auth->groups;
     foreach my $group ( @{ $groups } ) {
         my $group_id = $group->id;
         if ( $group_id eq $site_admin_id or $group_id eq $supergroup_id ) {
             $log->is_debug &&
                 $log->debug( "User in group [$group_id]: IS admin" );
-            return 1;
+            return $auth->is_admin( 'yes' );
         }
     }
-    return 0;
+    return $auth->is_admin( 'no' );
 }
 
 1;
@@ -48,6 +49,7 @@ OpenInteract2::Auth::AdminCheck - See whether user is admin
 =head1 SYNOPSIS
 
  # Set admin users/groups in server config
+ 
  [default_objects]
  superuser        = 1
  supergroup       = 1
@@ -55,10 +57,15 @@ OpenInteract2::Auth::AdminCheck - See whether user is admin
 
 =head1 DESCRIPTION
 
-B<is_admin( $user, $is_logged_in, \@groups )>
+B<is_admin( $auth )>
 
-Returns true if C<$user> is superuser or if an admin group is passed
-in C<\@groups>.
+Returns true if 'user' from C<$auth> (an
+L<OpenInteract2::Auth|OpenInteract2::Auth> object) is superuser or if
+an admin group is available in the 'groups' property of
+C<$auth>. Normally called only by
+L<OpenInteract2::Auth|OpenInteract2::Auth>
+
+Returns: 'yes' if admin, 'no' if not. Also set in C<$auth>.
 
 =head1 COPYRIGHT
 
