@@ -1,48 +1,54 @@
 package OpenInteract2::Auth::Group;
 
-# $Id: Group.pm,v 1.7 2003/06/24 03:35:38 lachoy Exp $
+# $Id: Group.pm,v 1.14 2003/09/05 13:30:28 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Auth::Group::VERSION  = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Auth::Group::VERSION  = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
 
 sub get_groups {
-    my ( $class, $user, $is_logged_in ) = @_;
+    my ( $class, $auth ) = @_;
     my $log = get_logger( LOG_AUTH );
-    unless ( $is_logged_in ) {
-        $log->is_debug &&
-            $log->debug( "No logged-in user found, not retrieving groups." );
-        return;
+    unless ( $auth->is_logged_in ) {
+        $log->is_info &&
+            $log->info( "No logged-in user found, not retrieving groups." );
+        return $auth->groups( [] );
     }
-    $log->is_debug &&
-        $log->debug( "Authenticated user exists; getting groups." );
+    $log->is_info &&
+        $log->info( "Authenticated user exists; getting groups." );
 
     # is group in the session?
 
-    my $group_refresh = CTX->server_config->{session_info}{cache_group};
-    my $groups = $class->get_cached_groups( $group_refresh );
-
-    return $groups if ( $groups );
+    my $groups = $class->_get_cached_groups;
+    if ( $groups ) {
+        return $auth->groups( $groups );
+    }
 
     # no, fetch from user record
 
+    my $user = $auth->user;
     $groups = eval { $user->group({ skip_security => 'yes' }) };
     if ( $@ ) {
         $log->error( "Failed to fetch groups from ",
                      "[User: $user->{login_name}]: $@" );
+        $groups = [];
     }
 
-    # set group in session (as necessary)
-    $class->set_cached_groups( $groups, $group_refresh );
-    return $groups;
+    # set group in session if configured
+
+    else {
+        $class->_set_cached_groups( $groups );
+    }
+    return $auth->groups( $groups );
 }
 
 
-sub get_cached_groups {
-    my ( $class, $group_refresh ) = @_;
+sub _get_cached_groups {
+    my ( $class ) = @_;
+    my $group_refresh = CTX->lookup_session_config->{cache_group};
     return unless ( $group_refresh > 0 );
     my $log = get_logger( LOG_AUTH );
     my $groups = [];
@@ -62,8 +68,9 @@ sub get_cached_groups {
     return $groups;
 }
 
-sub set_cached_groups {
-    my ( $class, $groups, $group_refresh ) = @_;
+sub _set_cached_groups {
+    my ( $class, $groups ) = @_;
+    my $group_refresh = CTX->lookup_session_config->{cache_group};
     unless ( ref $groups eq 'ARRAY'
                  and scalar @{ $groups } > 0
                  and $group_refresh > 0 ) {
@@ -88,19 +95,32 @@ OpenInteract2::Auth::Group - Retreive groups into OpenInteract
 
 =head1 SYNOPSIS
 
+ # Called by OI2::Auth
+ 
+ my $groups = OpenInteract2::Group->get_groups( $auth );
+ print "User ", $auth->user->login_name, " member of groups: \n";
+ foreach my $group ( @{ $groups } ) {
+     print "  * ", $group->name, "\n";
+ }
+ print "User ", $auth->user->login_name, " member of groups: \n";
+ foreach my $group ( @{ $auth->groups } ) {
+     print "  * ", $group->name, "\n";
+ }
+
 =head1 DESCRIPTION
 
+Retrieve groups given a user.
+
 =head1 METHODS
 
-=head1 BUGS
+B<get_groups( $auth )>
 
-None known.
+Pulls a 'user' object from C<$auth> (an
+L<OpenInteract2::Auth|OpenInteract2::Auth> object) and Returns all
+groups to which it belongs, as long as the C<is_logged_in> property of
+C<$auth> is true. If not then we immediately return an empty arrayref.
 
-=head1 TO DO
-
-Nothing known.
-
-=head1 SEE ALSO
+Returns: arrayref of groups found; also set into C<$auth>
 
 =head1 COPYRIGHT
 
