@@ -1,6 +1,6 @@
 package OpenInteract2::Config;
 
-# $Id: Config.pm,v 1.7 2003/06/24 03:35:37 lachoy Exp $
+# $Id: Config.pm,v 1.10 2003/09/05 02:19:22 lachoy Exp $
 
 use strict;
 use base qw( Class::Factory );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Config::VERSION   = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::VERSION   = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 ##############################
 # CLASS METHODS
@@ -62,14 +62,17 @@ sub translate_dirs {
         return;
     }
     my $site_dir = $self->{dir}{website};
-    $site_dir =~ s/(\\|\/)$//;
+    if ( $site_dir =~ s#(\\|/)$## ) {
+        $self->{dir}{website} = $site_dir;
+    }
     unless ( $site_dir ) {
         $log->error( "The config key 'dir.website' must be defined" );
-        oi_error "Define 'dir->website' before continuing";
+        oi_error "Define 'dir.website' before continuing";
     }
 
     while ( my ( $dir_type, $dir_spec ) = each %{ $self->{dir} } ) {
         next unless ( $dir_spec );
+        next if ( $dir_spec eq 'website' );
         my @pieces = split /\//, $dir_spec;
         if ( $pieces[0] eq '$WEBSITE' ) {
             $pieces[0] = $site_dir;
@@ -99,6 +102,17 @@ sub save_config {
 ########################################
 # FACTORY
 
+sub factory_log {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_CONFIG )->info( @msg );
+}
+
+sub factory_error {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_CONFIG )->error( @msg );
+    die @msg, "\n";
+}
+
 # Initialize built-in configuration types
 
 __PACKAGE__->register_factory_type(
