@@ -1,6 +1,6 @@
 package OpenInteract2::Config::Base;
 
-# $Id: Base.pm,v 1.7 2003/06/24 03:35:38 lachoy Exp $
+# $Id: Base.pm,v 1.8 2003/09/05 02:22:34 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor );
@@ -11,7 +11,7 @@ use OpenInteract2::Constants qw( :log BASE_CONF_DIR BASE_CONF_FILE );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Config::Base::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::Base::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 my @CONFIG_FIELDS = qw( website_dir temp_lib_dir package_dir
                         config_type config_class config_dir config_file );
@@ -104,8 +104,12 @@ sub create_filename {
 sub initialize {
     my ( $self, $params ) = @_;
     foreach my $field ( @CONFIG_FIELDS ) {
-        next unless ( $params->{ $field } );
-        $self->$field( $params->{ $field } );
+        if ( $params->{ $field } ) {
+            $self->$field( $params->{ $field } );
+        }
+        if ( $field =~ /dir$/ ) {
+            $self->clean_dir( $field );
+        }
     }
     return $self;
 }
@@ -114,8 +118,11 @@ sub initialize {
 sub clean_dir {
     my ( $self, $prop ) = @_;
     my $dir = $self->$prop();
-    $dir =~ s|/$||;
-    return $self->$prop( $dir );
+    if ( $dir ) {
+        $dir =~ s|/$||;
+        $self->$prop( $dir );
+    }
+    return $dir;
 }
 
 
