@@ -1,6 +1,6 @@
 package OpenInteract2::Config::Package;
 
-# $Id: Package.pm,v 1.10 2003/07/01 19:04:57 lachoy Exp $
+# $Id: Package.pm,v 1.11 2003/07/12 15:21:39 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor );
@@ -8,7 +8,7 @@ use File::Basename ();
 use File::Spec;
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Config::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_FILENAME => 'package.conf';
 
@@ -18,7 +18,7 @@ use constant DEFAULT_FILENAME => 'package.conf';
 my @SERIAL_FIELDS = qw( name version author url
                         spops_file action_file module
                         sql_installer template_plugin
-                        filter description );
+                        filter config_watcher description );
 my @OBJECT_FIELDS = qw( filename package_dir );
 
 my @REQUIRED_FIELDS = qw( name version );
@@ -30,7 +30,8 @@ sub get_required_fields { return [ @REQUIRED_FIELDS ] }
 #  author  Larry Wall <larry@wall.org>
 #  author  Chris Winters E<lt>chris@cwinters.comE<gt>
 
-my %LIST_FIELDS = map { $_ => 1 } qw( author module spops_file action_file );
+my %LIST_FIELDS = map { $_ => 1 }
+                  qw( author module spops_file action_file config_watcher );
 
 # Define the keys in 'package.conf' that can be a hash, meaning that
 # you can have items defined as multiple key-value pairs
@@ -457,61 +458,72 @@ Returns: Filename where the configuration was written.
 Both of these will be set automatically if you pass in either
 C<filename> or C<directory> to C<new()>
 
-C<filename>: File where the configuration is written.
+B<filename>: File where the configuration is written.
 
-C<package_dir>: Directory in which the configuration is written.
+B<package_dir>: Directory in which the configuration is written.
 
 =head2 Configuration Properties
 
 These are all read from and written to the configuration file.
 
-C<name> ($) (mandatory)
+B<name> ($) (mandatory)
 
 Name of the package
 
-C<version> ($) (mandatory)
+B<version> ($) (mandatory)
 
 Package version
 
-C<author> (\@)
+B<author> (\@)
 
 Author(s) of the package
 
-C<url> ($)
+B<url> ($)
 
 URL where you can find out more information
 
-C<spops_file> (\@)
+B<spops_file> (\@)
 
 File with SPOPS objects defined in this package. If you do not specify
 these you must store all object configuration information in a single
 file C<conf/spops.perl>. Both perl- and INI-formatted configurations
 are acceptable.
 
-C<action_file> (\@)
+B<action_file> (\@)
 
 File with the actions defined in this package. If you do not specify
 these you must store all action information in a single file
 C<conf/action.perl>. Both perl- and INI-formatted configurations are
 acceptable.
 
-C<module> (\@)
+B<module> (\@)
 
 Module(s) required by this package.
 
-C<sql_installer> ($)
+B<sql_installer> ($)
 
 SQL installer class to use for this package.
 
-C<template_plugin> (\%)
+B<template_plugin> (\%)
 
 Template Toolkit plugins defined by this package.
 
-C<filter> (\%)
+B<filter> (\%)
 
 Filters defined by this package. It should be in a 'name class' format
 simiilar to C<template_plugin>.
 
+B<config_watcher> (\@)
+
+Classes defined by this package that will observe
+L<OpenInteract2::Config::Initializer|OpenInteract2::Config::Initializer>
+events at server startup. You can use this to create custom, concise
+directives for your SPOPS and/or Action configurations that get
+expanded into either more meaningful information or into data that can
+only be found at runtime. That's a little abstract: see
+L<OpenInteract2::Config::Initializer|OpenInteract2::Config::Initializer>
+for examples.
+
 C<description> ($*)
 
 Description of this package. Instead of reading a single line we read
