@@ -1,6 +1,6 @@
 package OpenInteract2::ContentGenerator::TT2Plugin;
 
-# $Id: TT2Plugin.pm,v 1.6 2003/07/02 05:13:51 lachoy Exp $
+# $Id: TT2Plugin.pm,v 1.10 2003/08/30 15:46:20 lachoy Exp $
 
 use strict;
 use base qw( Template::Plugin );
@@ -14,7 +14,7 @@ use OpenInteract2::Context     qw( CTX );
 use SPOPS::Secure              qw( :level :scope );
 use SPOPS::Utility;
 
-$OpenInteract2::ContentGenerator::TT2Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ContentGenerator::TT2Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 my %SECURITY_CONSTANTS  = (
   level => {
@@ -169,6 +169,22 @@ sub class_isa {
 }
 
 
+sub can_read {
+    my ( $self, $spops_object ) = @_;
+    return undef unless ( $spops_object );
+    return ( $spops_object->{tmp_security_level} >= SEC_LEVEL_READ );
+}
+
+sub can_write {
+    my ( $self, $spops_object ) = @_;
+    return undef unless ( $spops_object );
+    return ( $spops_object->{tmp_security_level} >= SEC_LEVEL_WRITE );
+}
+
+
+
+
+
 ########################################
 # DATES
 ########################################
@@ -398,8 +414,6 @@ sub content_template {
 }
 
 
-
-
 ########################################
 # PLUGIN PROPERTIES
 ########################################
@@ -486,15 +500,59 @@ sub theme_properties {
     return $values;
 }
 
+
+# Don't return undef when things go sour or the caller will get a
+# nasty surprise when he tries to use it
+
+sub theme_fetch {
+    my ( $self, $theme_spec, $params ) = @_;
+    my $log = get_logger( LOG_TEMPLATE );
+    unless ( $theme_spec ) {
+        $log->warn( "No theme spec given to fetch" );
+        return $self->theme_properties;
+    }
+    my ( $theme_id );
+    if ( $theme_spec =~ /^[\d\s]+$/ ) {
+        $theme_id = $theme_spec;
+    }
+    else {
+        $theme_id = CTX->default_object_id( $theme_spec );
+    }
+    unless ( $theme_id ) {
+        $log->error( "Could not fetch theme given spec of '$theme_spec': ",
+                     "it doesn't look like an object ID and no matching ",
+                     "no matching name found in 'default_objects' server ",
+                     "configuration" );
+        return $self->theme_properties;
+    }
+    my $new_theme = eval {
+        CTX->lookup_object( 'theme' )->fetch( $theme_id )
+    };
+    if ( $@ ) {
+        $log->error( "Error fetching theme with ID '$theme_id': $@" );
+        return $self->theme_properties;
+    }
+    unless ( $new_theme ) {
+        $log->warn( "No theme with ID '$theme_id' exists" );
+        return $self->theme_properties;
+    }
+
+    # New theme looks good, fill it up...
+    my $new_props = $new_theme->all_values;
+
+    # ... and set for rest of request if specified
+    if ( $params->{set_for_request} eq 'yes' ) {
+        CTX->request->theme( $new_theme );
+    }
+
+    return $new_props;
+}
+
+
 sub theme {
     return theme_properties( @_ );
 }
 
-# XXX: Remove permanently?
-#sub error_hold {
-#    return CTX->response->error_hold;
-#}
-
 
 sub session {
     my ( $self ) = @_;
@@ -537,6 +595,9 @@ OpenInteract2::ContentGenerator::TT2Plugin - Custom OpenInteract functionality i
  Is the object in the class?
     [% OI.class_isa( object, 'SPOPS::DBI' ) ? 'yes' : 'no' %]
  
+ Is the SPOPS object writable?
+    [% IF OI.can_write( object ) %]You're special![% END %]
+ 
  [% action = OI.action %]
  Action that called this template: [% action.name %]
  Security for action:
@@ -601,6 +662,9 @@ OpenInteract2::ContentGenerator::TT2Plugin - Custom OpenInteract functionality i
  [% theme = OI.theme_properties %]
  Background color of page: [% theme.bgcolor %]
  
+ [% new_theme = OI.theme_fetch( 5 ) %]
+ Background color of page from other theme: [% new_theme.bgcolor %]
+ 
  [% IF OI.logged_in -%]
  Hello [% OI.login.full_name %]. 
    Your groups are: [% OI.login_group.join( ', ' ) -%]
@@ -611,12 +675,7 @@ OpenInteract2::ContentGenerator::TT2Plugin - Custom OpenInteract functionality i
  Your last search: [% OI.session.latest_search %]
  
  <a href="[% OI.return_url %]">Refresh</a>
- 
- [% IF OI.error_hold.myapp.field_out_of_bounds %]
-   The entry you made is out of bounds:
-        [% OI.error_hold.myapp.field_out_of_bounds %]
- [% END %]
- 
+  
  [% IF object.tmp_security_level >= OI.security_level.write -%]
    you can edit this object!
  [% END %]
@@ -752,6 +811,11 @@ Example:
 (Of course, this is a bad example since you would deal with this
 through your normal OO methods.)
 
+B<can_write( $spops_object )>
+
+Returns true if the object is writeable by the current user, false if
+not.
+
 B<action()>
 
 Returns the L<OpenInteract2::Action|OpenInteract2::Action> object that
@@ -1154,6 +1218,28 @@ Example:
 
   [% OI.use_main_template( 'mypkg::main' ) -%]
 
+B<theme_fetch( $new_theme_spec, \%params )>
+
+Retrieves the properties for theme C<$new_theme_spec>, which can be an
+ID (normal) or a name listed in the 'default_objects' of your server
+configuration. If the latter we'll use the ID associated with that
+name.
+
+If the key C<set_for_request> is set to 'yes' in C<\%params> then this
+new theme will be used for the remainder of the request. This includes
+the main template along with all graphical elements.
+
+Returns: hashref with all properties of the given theme.
+
+Examples:
+
+ [% new_theme = OI.theme_fetch( 5 ) %]
+ Background color of page from other theme: [% new_theme.bgcolor %]
+ 
+ [% new_theme = OI.theme_fetch( 5, set_for_request = 'yes' ) %]
+ Background color of page from other theme: [% new_theme.bgcolor %]
+ Hey, the new theme is now set for the rest of the request!
+
 =head2 PROPERTIES
 
 B<theme_properties()>
@@ -1245,22 +1331,6 @@ come back to if we have to do something like logout.
 Note that this should be an B<absolute URL> -- you should be able to
 plug it directly into a tag without worrying about the server context.
 
-B<error_hold()>
-
-A hashref representing a container with all error messages as
-generated by error handlers. The error handler and the template need
-to coordinate on a naming scheme so you know where to find your
-messages.
-
-Note that future work may restrict this to the errors for your
-template only.
-
-Example:
-
- [% error_messages = OI.error_hold %]
- <p>User [% error_messages.loginbox.login_name %] does not exist in
- the system.</p>
-
 B<security_level()>
 
 A hashref with keys of 'none', 'read', and 'write' which gives you the
