@@ -1,6 +1,6 @@
 package OpenInteract2::ContentGenerator::TT2Process;
 
-# $Id: TT2Process.pm,v 1.7 2003/07/02 05:09:45 lachoy Exp $
+# $Id: TT2Process.pm,v 1.8 2003/08/27 15:49:32 lachoy Exp $
 
 use strict;
 use Data::Dumper             qw( Dumper );
@@ -14,7 +14,7 @@ use OpenInteract2::ContentGenerator::TT2Plugin;
 use OpenInteract2::ContentGenerator::TT2Provider;
 use Template;
 
-$OpenInteract2::ContentGenerator::TT2Process::VERSION  = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ContentGenerator::TT2Process::VERSION  = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_COMPILE_EXT => '.ttc';
 use constant DEFAULT_CACHE_SIZE  => 75;
@@ -269,7 +269,7 @@ OpenInteract2::ContentGenerator::TT2Process - Process Template Toolkit templates
  
  # Pass the already-created object for parsing (rare)
  
- my $site_template_obj = CTX->template_class->fetch( 'base_main' );
+ my $site_template_obj = CTX->lookup_class( 'template' )->fetch( 'base_main' );
  my $html = $proc_class->process( {}, { key => 'value' },
                                   { object => $site_template_obj } );
 
