@@ -1,6 +1,6 @@
 package OpenInteract2::ContentGenerator::TT2Provider;
 
-# $Id: TT2Provider.pm,v 1.4 2003/06/24 03:35:38 lachoy Exp $
+# $Id: TT2Provider.pm,v 1.5 2003/08/27 15:50:18 lachoy Exp $
 
 use strict;
 use base qw( Template::Provider );
@@ -10,7 +10,7 @@ use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::ContentGenerator::TT2Provider::VERSION  = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ContentGenerator::TT2Provider::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_MAX_CACHE_TIME       => 60 * 30;
 use constant DEFAULT_TEMPLATE_EXTENSION   => 'template';
@@ -187,7 +187,8 @@ sub _load {
 
     my ( $content_template, $data );
     eval {
-        $content_template = CTX->template_class->fetch( $name );
+        $content_template =
+            CTX->lookup_class( 'template' )->fetch( $name );
         unless ( $content_template ) {
             die "Template with name [$name] not found.\n";
         }
