@@ -1,6 +1,6 @@
 package OpenInteract2::ContentGenerator::TemplateSource;
 
-# $Id: TemplateSource.pm,v 1.6 2003/07/01 05:28:51 lachoy Exp $
+# $Id: TemplateSource.pm,v 1.7 2003/08/27 15:50:18 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
@@ -8,7 +8,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::ContentGenerator::TemplateSource::VERSION  = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ContentGenerator::TemplateSource::VERSION  = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 sub identify {
     my ( $class, $template_source ) = @_;
@@ -85,7 +85,7 @@ sub identify {
 
 sub load_source {
     my ( $class, $name ) = @_;
-    my $content_template = CTX->template_class->fetch( $name );
+    my $content_template = CTX->lookup_class( 'template' )->fetch( $name );
     unless ( $content_template ) {
        oi_error "Template with name [$name] not found.";
     }
