@@ -1,6 +1,6 @@
 package OpenInteract2::Context;
 
-# $Id: Context.pm,v 1.35 2003/07/02 15:47:00 lachoy Exp $
+# $Id: Context.pm,v 1.45 2003/09/05 02:20:11 lachoy Exp $
 
 use strict;
 use base                     qw( Exporter Class::Accessor );
@@ -10,9 +10,11 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Log;
 
-$OpenInteract2::Context::VERSION   = sprintf("%d.%02d", q$Revision: 1.35 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Context::VERSION   = sprintf("%d.%02d", q$Revision: 1.45 $ =~ /(\d+)\.(\d+)/);
 
-sub version { return '1.99_01' }
+use constant DEFAULT_TEMP_LIB_DIR => 'templib';
+
+sub version { return '1.99_03' }
 
 # Exportable deployment URL call -- main, images, static
 
@@ -172,40 +174,32 @@ sub setup {
         $setup->create_temp_lib( $params );
     }
 
-    unless ( $skip{ 'initialize alias' } ) {
-        my @alias_classes = ();
-        my $aliases = $setup->read_aliases;
-        foreach my $type ( keys %{ $aliases } ) {
-            while ( my ( $alias, $alias_to ) = each %{ $aliases->{ $type } } ) {
-                $self->alias( $type, $alias, $alias_to );
-                push @alias_classes, $alias_to;
-            }
-        }
-        $setup->require_module({ class => \@alias_classes });
-        $log->is_info && $log->info( "Required alias classes ok" );
-    }
-
     unless ( $skip{ 'initialize datasource' } ) {
         my $ds_manager_class = $server_config->{datasource_config}{manager};
         eval "require $ds_manager_class";
         $self->datasource_manager( $ds_manager_class );
-        $log->is_info && $log->info( "Assigned aliases ok" );
+        $log->is_info && $log->info( "Assigned datasource manager ok" );
         $setup->check_datasources();
     }
 
+    unless ( $skip{ 'initialize observer' } ) {
+        $setup->initialize_observers;
+        $log->is_info &&
+            $log->info( "Initialized observers ok" );
+    }
+
     if ( $skip{ 'initialize action' } ) {
         $skip{ 'initialze controller' }++;
     }
     else {
         my $action_table = $setup->read_action_table;
         $log->is_info && $log->info( "Read action table ok" );
-        $setup->require_action_classes( $action_table );
+        my $action_classes = $setup->require_action_classes( $action_table );
+        $setup->initialize_action_classes( $action_classes );
         $setup->register_action_types;
         $log->is_info && $log->info( "Required action classes ok" );
         $self->action_table( $action_table );
         $log->is_info && $log->info( "Assigned action table ok" );
-        $setup->initialize_action_filters;
-        $log->is_info && $log->info( "Assigned filters (if any) ok" );
     }
 
     unless ( $skip{ 'initialize spops' } ) {
@@ -219,6 +213,13 @@ sub setup {
         $log->is_info && $log->info( "Assigned SPOPS table ok" );
     }
 
+    # Not optional...
+
+    my $system_classes = $setup->read_system_classes;
+    $log->is_info &&
+        $log->info( "Required system classes ok: ",
+                    join( ', ', @{ $system_classes } ) );
+
     unless ( $skip{ 'initialize session' } ) {
         $setup->require_session_classes( $server_config->{session_info} );
     }
@@ -268,7 +269,7 @@ sub assign_deploy_url {
     $url ||= $self->server_config->{context_info}{deployed_under};
     $url = $self->_clean_deploy_url( $url );
     if ( $url and $url !~ m|^/| ) {
-        oi_error "Deployment URL *MUST* begin with a '/'. It may not ",
+        oi_error "Deployment URL must begin with a '/'. It may not ",
                  "be a fully-qualified URL (e.g., 'http://foo.com/') ",
                  "and it may not be a purely relative URL (e.g., 'oi')";
     }
@@ -442,6 +443,12 @@ sub lookup_action_not_found {
 }
 
 
+sub lookup_default_action_info {
+    my ( $self ) = @_;
+    return $self->server_config->{action_info}{default};
+}
+
+
 ########################################
 # OBJECT CLASS LOOKUP
 
@@ -487,6 +494,9 @@ sub lookup_content_generator {
     return $self->server_config->{content_generator};
 }
 
+########################################
+# FILTERS
+
 sub lookup_filter {
     my ( $self, $name ) = @_;
     if ( $name ) {
@@ -518,40 +528,56 @@ sub lookup_directory {
     return $self->server_config->{dir};
 }
 
-########################################
-# GLOBAL SETTINGS/ALIASES
+# TODO: What happens if someone specifies a fully-qualified directory?
 
-# These are generally temporary
-# TODO: Get rid of these?
-
-sub global_attribute {
-    my ( $self, $name, $value ) = @_;
-    return undef unless ( $name );
-    if ( $value ) { $self->{attrib}{ $name } = $value }
-    return $self->{attrib}{ $name };
-}
-
-
-sub clear_global_attributes {
+sub lookup_temp_lib_directory {
     my ( $self ) = @_;
-    return $self->{attrib} = {};
+    my $base_config = $self->base_config;
+    my $lib_dir = $base_config->temp_lib_dir || DEFAULT_TEMP_LIB_DIR;
+    return File::Spec->catdir( $base_config->website_dir, $lib_dir );
 }
 
+sub lookup_temp_lib_refresh_filename {
+    return 'refresh.txt';
+}
+
+sub lookup_override_action_filename {
+    return 'action_override.ini';
+}
+
+sub lookup_override_spops_filename {
+    return 'spops_override.ini';
+}
+
+########################################
+# SESSION CONFIG LOOKUP
+
+sub lookup_session_config {
+    my ( $self ) = @_;
+    return $self->server_config->{session_info};
+}
+
+########################################
+# LOGIN CONFIG LOOKUP
+
+sub lookup_login_config {
+    my ( $self ) = @_;
+    return $self->server_config->{login};
+}
+
+########################################
+# CLASS LOOKUP
+
 # TODO: Could this closure be a potential memory leak? Test!
 
-sub alias {
-    my ( $self, $type, $name, $value ) = @_;
-    return unless ( $type and $name );
-    if ( $value ) {
-        $self->{alias}{ $type }{ $name } = $value;
-        my $class = ref $self;
-        no strict 'refs';
-        *{ $class . '::' . $name } = sub { return $value };
+sub lookup_class {
+    my ( $self, $name ) = @_;
+    if ( $name ) {
+        return $self->server_config->{system_class}{ $name };
     }
-    return $self->{alias}{ $type }{ $name };
+    return $self->server_config->{system_class};
 }
 
-
 # Config shortcut
 
 # NOTE: Coupling to OI2::URL->create_from_action with the
@@ -593,11 +619,37 @@ sub spops_config {
 
 # Config shortcut
 
-sub datasource_config {
-    my ( $self ) = @_;
+sub lookup_datasource_config {
+    my ( $self, $name ) = @_;
+    if ( $name ) {
+        return $self->server_config->{datasource}{ $name };
+    }
     return $self->server_config->{datasource};
 }
 
+sub lookup_system_datasource_name {
+    my ( $self ) = @_;
+    return $self->server_config->{datasource_config}{system};
+}
+
+sub lookup_default_datasource_name {
+    my ( $self ) = @_;
+    return $self->server_config->{datasource_config}{spops};
+}
+
+sub lookup_default_ldap_datasource_name {
+    my ( $self ) = @_;
+    return $self->server_config->{datasource_config}{ldap};
+}
+
+sub default_object_id {
+    my ( $self, $name ) = @_;
+    if ( $name ) {
+        return $self->server_config->{default_objects}{ $name };
+    }
+    return $self->server_config->{default_objects};
+}
+
 
 ########################################
 # GLOBAL RESOURCES
@@ -607,6 +659,8 @@ sub datasource_config {
 
 sub datasource {
     my ( $self, $name ) = @_;
+
+    # TODO: Why choose the 'system' default here?
     $name ||= $self->server_config->{datasource_config}{system};
     return OpenInteract2::DatasourceManager->datasource( $name );
 }
@@ -631,10 +685,11 @@ sub template {
     return $self->{template};
 }
 
-
 sub cleanup_request {
     my ( $self ) = @_;
     $self->set( $_, undef )  for ( @REQUEST_FIELDS );
+
+    # TODO: These two methods Needed?
     $self->clear_global_attributes;
     $self->clear_exceptions;
 }
@@ -672,7 +727,8 @@ sub check_security {
 ########################################
 # EXCEPTIONS
 
-# Exception shortcuts (may remove?)
+# Exception shortcuts
+# TODO: remove?
 
 sub throw            { shift; goto &OpenInteract2::Exception::throw( @_ ) }
 
@@ -778,12 +834,6 @@ C<lookup_action_not_found()>)
 The context provides a shortcut to lookup controller information from
 the server configuration.
 
-=item B<other aliases>
-
-Other classes are stored on an alias basis as well; currently this is
-limited to the items under the configuration key C<system_alias>. (See
-C<alias()>)
-
 =item B<security checking>
 
 You can check the security for any object or class from one
@@ -903,13 +953,6 @@ location. (Setup: C<create_temp_lib>) (Skip: 'initialize temp lib')
 
 =item *
 
-Create aliases from the server configuration. These are stored under
-the configuration key C<system_alias>. (Setup: C<read_aliases()>) We
-also ensure that the classes aliased are brought into the system via
-C<require>. (Skip: 'initialize alias')
-
-=item *
-
 Require modules specified in the C<session_info> server configuration
 key under 'class' and 'impl_class'. (Skip: 'initialize session')
 
@@ -1095,6 +1138,58 @@ to hold the class name, the second does not.
 Returns: SPOPS class name; throws an exception if C<$object_name> is
 not found.
 
+B<spops_config( [ $name ] )>
+
+Returns the raw SPOPS configuration for C<$name>. If C<$name> not
+provided returns the full SPOPS configuration hashref.
+
+=head2 Object Methods: Datasource
+
+B<datasource( [ $name ] )>
+
+Returns the datasource mapped to C<$name>. If C<$name> is not
+provided, the method looks up the default datasource in the server
+configuration (under C<datasource_info.default_connection>) and uses
+that.
+
+Returns: the result of looking up the datasource using
+L<OpenInteract2::DatasourceManager|OpenInteract2::DatasourceManager>
+
+B<lookup_datasource_config( [ $name ] )>
+
+Returns the datasource configuration hashref for C<$name>. If C<$name>
+not provided returns the full datasource configuration hashref.
+
+B<lookup_system_datasource_name()>
+
+Returns the datasource name in 'datasource_config.system'.
+
+B<lookup_default_datasource_name()>
+
+Returns the datasource name in 'datasource_config.spops'.
+
+B<lookup_default_ldap_datasource_name()>
+
+Returns the datasource name in 'datasource_config.ldap'.
+
+=head2 Object Methods: Filters
+
+B<lookup_filter( [ $name ] )>
+
+Returns filter mapped to C<$name>, or returns hashref of all
+name-to-filter pairs
+
+B<set_filter_registry( \%registry )>
+
+Assigns a full filter registry to the context. The registry is a
+hashref of name-to-filter pairs.
+
+B<add_filter( $name, \%info )>
+
+Shortcut to C<register_filter> method of
+L<OpenInteract2::Filter|OpenInteract2::Filter> that passes the
+context's filter registry as the last argument.
+
 =head2 Object Methods: Controller
 
 B<lookup_controller( [ $controller_name ] )>
@@ -1127,47 +1222,6 @@ L<OpenInteract2::ContentGenerator|OpenInteract2::ContentGenerator>
 object. Generally you'd only call C<execute()> on it with the
 appropriate parameters to get the generated content.
 
-=head2 Object Methods: Attributes and Aliases
-
-B<global_attribute( $name, [ $value ] )>
-
-This is preliminary and may go away.
-
-Get/set method for global attributes. Global attributes are a simple
-way of passing temporary information to various routines or actions
-without setting them in the server configuration.
-
-These may get removed at the end of a request cycle or folded into
-something else.
-
-Returns: Current value for attribute C<$name>
-
-B<alias( $type, $name, [ $value ] )>
-
-Get/set method for aliases. Setting an alias also dynamically creates
-a subroutine that returns C<$value>. Note that resetting the alias
-after it has already been created will cause Perl to warn you about
-redefining a subroutine.
-
-Example:
-
-Create an alias for 'argle_bargle', which returns a class name for the
-'nonsense' object class:
-
- my $nonsense = fetch_nonsense({ where => 'speaker = "native"' });
- print "Nonsense: ", $nonsense->spew, "\n";
- my $nonsense_class = ref $nonsense;
- CTX->alias( 'object', 'argle_bargle', $nonsense_class );
-
- ... later ...
-
- print CTX->argle_bargle->fetch_nonsense()->spew;
-
-The best strategy for setting aliases would probably be to create them
-at server startup so they will always be available.
-
-Returns: the currently set value for the alias C<$name>.
-
 =head2 Object Methods: Deployment Context
 
 There are three separate deployment contexts used in OpenInteract2:
@@ -1250,15 +1304,84 @@ Returns: new deployment URL for static resources.
 
 =head2 Object Methods: Other Resources
 
-B<datasource( [ $name ] )>
+B<lookup_class( $name )>
 
-Returns the datasource mapped to C<$name>. If C<$name> is not
-provided, the method looks up the default datasource in the server
-configuration (under C<datasource_info.default_connection>) and uses
-that.
+The server configuration key C<system_class> holds a number of
+name-to-class mappings for some system resources. This is a way to
+lookup a class based on the name. For example, if you want to
+manipulate the page template objects you'd use:
 
-Returns: the result of looking up the datasource using
-L<OpenInteract2::DatasourceManager|OpenInteract2::DatasourceManager>
+ # Server configuration
+ [system_class]
+ template_class = OpenInteract2::SiteTemplate
+ 
+ # Usage
+ my $template_class = CTX->lookup_class( 'template' );
+ my $template = $template_class->fetch( ... );
+
+I<NOTE>: This replaces the aliasing feature found in early betas of
+OI2 and in OI 1.x. The aliasing feature would create methods for each
+name found in the server configuration key C<server_alias> so you'd
+previously have:
+
+ # Server configuration
+ [system_alias]
+ template_class = OpenInteract2::SiteTemplate
+ 
+ # Usage
+ my $template_class = CTX->template_class;
+ my $template = $template_class->fetch( ... );
+
+B<This will fail> with a message that the C<template_class> subroutine
+is not found in C<OpenInteract2::Context>.
+
+B<lookup_directory( $dir_tag )>
+
+Finds fully-qualified directory matching C<dir.$dir_tag> in the server
+configuration. For example:
+
+ my $full_html_dir = CTX->lookup_directory( 'html' );
+
+This is preferred to poking about in the server configuration data
+structure yourself.
+
+Returns: fully-qualified directory
+
+B<lookup_temp_lib_directory()>
+
+Creates the fully-qualified name for the temporary library
+directory. This can be specified in the base configuration
+(C<conf/base.conf>) or a default (C<tmplib/>) is provided. Both are
+relative to the website directory.
+
+This method doesn't care of the directory exists or not, it just
+creates the name.
+
+Returns: fully-qualified directory
+
+B<lookup_temp_lib_refresh_filename()>
+
+Relative name of file in the temporary library directory that's used
+(by L<OpenInteract2::Setup|OpenInteract2::Setup>) to identify whether
+the directory needs refreshed. Normally this is 'refresh.txt'.
+
+Returns: relative filename
+
+B<lookup_override_action_filename()>
+
+Returns name of action global override file ('action_override.ini').
+
+B<lookup_override_spops_filename()>
+
+Returns name of SPOPS global override file ('spops_override.ini').
+
+B<lookup_session_config()>
+
+Returns 'session_info' section of server configuration (hashref).
+
+B<lookup_login_config()>
+
+Returns 'login' section of server configuration (hashref).
 
 B<template( [ $template ] )>
 
@@ -1271,6 +1394,11 @@ L<HTML::Template|HTML::Template> for a self-contained piece of it.
 
 Returns: Currently available template object
 
+B<default_object_id( [ $name ] )>
+
+Returns the default object ID mapped to C<$name>. If C<$name> not
+given returns a hashref of all default object IDs.
+
 =head1 PROPERTIES
 
 The following are simple get/set properties of the context object.
