@@ -1,6 +1,6 @@
 package OpenInteract2::Controller;
 
-# $Id: Controller.pm,v 1.13 2003/07/02 15:17:43 lachoy Exp $
+# $Id: Controller.pm,v 1.15 2003/08/21 11:37:22 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor Class::Factory );
@@ -9,7 +9,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Controller::VERSION  = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Controller::VERSION  = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( type generator_type return_url initial_action request response );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -152,6 +152,17 @@ sub _get_controller_implementation_class {
     return $impl_class;
 }
 
+sub factory_log {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_ACTION )->info( @msg );
+}
+
+sub factory_error {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_ACTION )->error( @msg );
+    die @msg, "\n";
+}
+
 1;
 
 __END__
