@@ -1,6 +1,6 @@
 package OpenInteract2::File;
 
-# $Id: File.pm,v 1.5 2003/06/24 03:35:38 lachoy Exp $
+# $Id: File.pm,v 1.7 2003/08/26 13:29:43 lachoy Exp $
 
 use strict;
 use File::Path;
@@ -8,12 +8,12 @@ use File::Spec;
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::File::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::File::VERSION  = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 # If $filename exists in the website, return the full path; otherwise
 # undef
 
-sub check_file {
+sub check_filename {
     my ( $class, $filename ) = @_;
     my $full_filename = $class->create_filename( $filename );
     return ( -f $full_filename ) ? $full_filename : undef;
@@ -139,16 +139,17 @@ sub get_mime_type {
     }
     my $filename = $params->{filename};
     unless ( $filename ) {
-        oi_error "Pass either 'content' or 'filename' to get MIME type";
+        oi_error "Pass 'content', 'filehandle' or 'filename' to get MIME type";
     }
     my ( $extension ) = $filename =~ /\.(\w+)$/;
     if ( $SIMPLE_TYPES{ lc $extension } ) {
         return $SIMPLE_TYPES{ lc $extension };
     }
-    unless ( -f $filename ) {
-        oi_error "File [$filename] does not exist.";
+    my $full_filename = $class->check_filename( $filename );
+    unless ( $full_filename ) {
+        oi_error "File '$filename' does not exist.";
     }
-    return $MAGIC->checktype_filename( $filename );
+    return $MAGIC->checktype_filename( $full_filename );
 }
 
 1;
@@ -178,9 +179,20 @@ OpenInteract2::File - Safe filesystem operations for OpenInteract
  
  # See if a particular file already exists
  
- if ( OpenInteract2::File->check_file( 'uploads/myfile.exe' ) ) {
+ if ( OpenInteract2::File->check_filename( 'uploads/myfile.exe' ) ) {
      print "That file already exists!";
  }
+ 
+ # Get the MIME type of content...
+ 
+ # ...read in from a file
+ my $type = OpenInteract2::File->get_mime_type({ content => $content });
+ 
+ # ...in a filehandle
+ my $type = OpenInteract2::File->get_mime_type({ filehandle => $fh });
+ 
+ # ...specified by a filename
+ my $type = OpenInteract2::File->get_mime_type({ filename => 'uploads
 
 =head1 DESCRIPTION
 
@@ -220,7 +232,7 @@ Here are some examples from the test suite:
  html/images/sharpie.gif /home/httpd/mysite/html/images/sharpie.gif
  /dingdong/myfile.txt    /home/httpd/mysite/uploads/dingdong/myfile.txt
 
-B<check_file( $filename )>
+B<check_filename( $filename )>
 
 Retrieves a full path to C<$filename>, or C<undef> if the file does
 not exist. The C<$filename> is assumed to be under the website
@@ -232,13 +244,14 @@ named the same with a successive call to C<save_file()>. For instance,
 in the following snippet C<$filename> is not guaranteed to be named
 C<.../uploads/myfile.exe>:
 
- if ( OpenInteract2::File->check_file( 'uploads/myfile.exe' ) ) {
+ if ( OpenInteract2::File->check_filename( 'uploads/myfile.exe' ) ) {
      my $filename = OpenInteract2::File->save_file( $fh, 'uploads/myfile.exe' );
  }
 
 Why not? Another process could have written the file
-'uploads/myfile.exe' in between the call to C<check_file()> and the
-call to C<save_file()>.
+'uploads/myfile.exe' in between the call to C<check_filename()> and
+the call to C<save_file()>. Therefore you should B<always> check the
+return value.
 
 Returns: true if C<$filename> exists under the website directory,
 false if not.
@@ -288,14 +301,6 @@ If none of these parameters are specified an exception is thrown.
 
 Returns: a valid MIME type if one can be discerned.
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 SEE ALSO
 
 L<File::MMagic|File::MMagic>
