@@ -1,12 +1,12 @@
 package OpenInteract2::Manage::Package;
 
-# $Id: Package.pm,v 1.11 2003/06/24 03:35:39 lachoy Exp $
+# $Id: Package.pm,v 1.13 2003/07/16 12:22:02 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Manage::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 ########################################
 # INTERFACE
@@ -18,29 +18,20 @@ sub tear_down_task   {}
 ########################################
 # PACKAGE PARAMETER CHECKS
 
-sub get_validate_sub {
-    my ( $self, $name ) = @_;
-    return \&_check_package      if ( $name eq 'package' );
-    return \&_check_package_dir  if ( $name eq 'package_dir' );
-    return $self->SUPER::get_validate_sub( $name );
-}
-
-
-sub _check_package_dir {
-    my ( $self, $package_dir ) = @_;
-    unless ( -d $package_dir ) {
-        return "Value 'package_dir' must be valid directory";
+sub validate_param {
+    my ( $self, $name, $value ) = @_;
+    if ( $name eq 'package' ) {
+        unless ( ref $value eq 'ARRAY' and scalar @{ $value } ) {
+            return "Value 'package' must contain one or more values";
+        }
     }
-    return $self->_package_in_dir( $package_dir );
-}
-
-
-sub _check_package {
-    my ( $self, $package ) = @_;
-    unless ( ref $package eq 'ARRAY' and scalar @{ $package } ) {
-        return "Value 'package' must contain one or more values";
+    if ( $name eq 'package_dir' ) {
+        unless ( -d $value ) {
+            return "Value 'package_dir' must be valid directory";
+        }
+        return $self->_package_in_dir( $value );
     }
-    return;
+    return $self->SUPER::validate_param( $name, $value );
 }
 
 
@@ -62,26 +53,6 @@ sub _package_in_dir {
     return;
 }
 
-
-########################################
-# PACKAGE TASK REGISTRATION
-
-# Register all of our known subclasses
-
-my %CHILDREN = (
-  check_package         => 'OpenInteract2::Manage::Package::Check',
-  create_package        => 'OpenInteract2::Manage::Package::CreatePackage',
-  export_package        => 'OpenInteract2::Manage::Package::Export',
-);
-
-sub register {
-    while ( my ( $name, $class ) = each %CHILDREN ) {
-        OpenInteract2::Manage->register_factory_type( $name, $class );
-    }
-}
-
-OpenInteract2::Manage::Package->register();
-
 1;
 
 __END__
@@ -107,16 +78,6 @@ Reads in package names from the file C<$filename>.
 
 Returns: arrayref of package names.
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
-=head1 SEE ALSO
-
 =head1 COPYRIGHT
 
 Copyright (c) 2002-2003 Chris Winters. All rights reserved.
