@@ -1,45 +1,53 @@
 package OpenInteract2::Manage::Package::CreatePackage;
 
-# $Id: CreatePackage.pm,v 1.10 2003/06/24 03:35:39 lachoy Exp $
+# $Id: CreatePackage.pm,v 1.11 2003/07/14 13:08:38 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Package );
 
-$OpenInteract2::Manage::Package::CreatePackage::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Package::CreatePackage::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
-sub brief_description {
+# METADATA
+
+sub get_name {
+    return 'create_package';
+}
+
+sub get_brief_description {
     return 'Create a new package, with most of the pieces filled in for you';
 }
 
-sub list_param_require  { return [ 'package', 'source_dir' ] }
-sub list_param_optional { return [ 'package_dir' ] }
-sub list_param_validate { return [ 'package', 'source_dir', 'package_dir' ] }
-
-sub get_validate_sub {
-    my ( $self, $param_name ) = @_;
-    if ( $param_name eq 'package_dir' ) {
-        return \&_validate_package_dir;
-    }
-    return $self->SUPER::get_validate_sub( $param_name );
+sub get_parameters {
+    my ( $self ) = @_;
+    return {
+      package => {
+           description => 'Name of the package to create',
+           is_required => 'yes',
+      },
+      package_dir => {
+           description => 'Directory to create package in',
+           do_validate => 'yes',
+      },
+      source_dir => {
+           description => $self->get_param_description( 'source_dir' ),
+           is_required => 'yes',
+      },
+    };
 }
 
-sub _validate_package_dir {
-    my ( $self, $package_dir ) = @_;
-    return () unless ( $package_dir );
-    return () if ( -d $package_dir );
-    return "If specified 'package_dir' must be a valid directory";
+# VALIDATION
+
+sub validate_param {
+    my ( $self, $name, $value ) = @_;
+    if ( $name eq 'package_dir' ) {
+        return undef unless ( $value );
+        return undef if ( -d $value );
+        return "If specified 'package_dir' must be a valid directory";
+    }
+    return $self->SUPER::validate_param( $name, $value );
 }
 
-sub get_param_description {
-    my ( $self, $param_name ) = @_;
-    if ( $param_name eq 'package' ) {
-        return "Name of the package to create";
-    }
-    elsif ( $param_name eq 'package_dir' ) {
-        return "Directory to create package in";
-    }
-    return $self->SUPER::get_param_description( $param_name );
-}
+# TASK
 
 sub setup_task {
     my ( $self ) = @_;
@@ -65,6 +73,8 @@ sub run_task {
     return;
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
@@ -112,14 +122,6 @@ File installed/modified (if applicable)
 
 =back
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2002-2003 Chris Winters. All rights reserved.
