@@ -1,40 +1,42 @@
 package OpenInteract2::Manage::Package::Export;
 
-# $Id: Export.pm,v 1.8 2003/06/24 03:35:39 lachoy Exp $
+# $Id: Export.pm,v 1.10 2003/07/16 12:22:02 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Package );
+use Cwd qw( cwd );
 use File::Spec;
 
-$OpenInteract2::Manage::Package::Export::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Package::Export::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
-sub brief_description {
+# METADATA
+
+sub get_name {
+    return 'export_package';
+}
+
+sub get_brief_description {
     return 'Export a package to a distributable format';
 }
 
-sub list_param_require  { return [ 'package_dir' ] }
-sub list_param_validate { return [ 'package_dir' ] }
-
-sub get_param_description {
-    my ( $self, $param_name ) = @_;
-    if ( $param_name eq 'package_dir' ) {
-        return "Directory of package to export";
-    }
-    return $self->SUPER::get_param_description( $param_name );
-}
-
-sub param_initialize {
+sub get_parameters {
     my ( $self ) = @_;
-    unless ( $self->param( 'package_dir' ) ) {
-        $self->param(
-            package_dir => File::Spec->rel2abs( File::Spec->curdir ) );
-    }
-    return $self->SUPER::param_initialize();
+    return {
+       package_dir => {
+         description => 'Directory of package to export',
+         default     => cwd(),
+         is_required => 'yes',
+       },
+    };
 }
 
-sub get_validate_sub {
-    my ( $self, $name ) = @_;
-    return \&_check_package_dir if ( $name eq 'package_dir' );
+# VALIDATE
+
+sub validate_param {
+    my ( $self, $name, $value ) = @_;
+    if ( $name eq 'package_dir' ) {
+        return $self->_check_package_dir( $value );
+    }
     return $self->SUPER::get_validate_sub( $name );
 }
 
@@ -120,6 +122,8 @@ PACKAGE:
     return @export_dirs;
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
@@ -131,10 +135,10 @@ OpenInteract2::Manage::Package::Export - Export a package into a portable format
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
-
+ 
  use strict;
  use OpenInteract2::Manage;
-
+ 
  my $package_dir = '/home/me/work/pkg/mypkg';
  my $task = OpenInteract2::Manage->new(
                       'export_package', { package_dir => $package_dir } );
@@ -151,7 +155,7 @@ This task simply wraps up a package for portable transport. Note that
 this version of OpenInteract uses C<.zip> files instead of C<.tar.gz>
 files. (This is mainly because of the older and slightly
 interface-incompatible version of L<Archive::Tar|Archive::Tar> shipped
-with Win32 system.)
+with common Win32 distributions.)
 
 =head1 STATUS MESSAGES
 
@@ -174,14 +178,6 @@ File created by the export
 
 =back
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2002-2003 Chris Winters. All rights reserved.
