@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website;
 
-# $Id: Website.pm,v 1.12 2003/06/24 03:35:39 lachoy Exp $
+# $Id: Website.pm,v 1.14 2003/07/16 12:22:02 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage );
@@ -9,20 +9,40 @@ use OpenInteract2::Config::Readonly;
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Package   qw( DISTRIBUTION_EXTENSION );
 
-$OpenInteract2::Manage::Website::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
-
-sub list_param_require  { return [ 'website_dir' ] }
-sub list_param_validate { return [ 'website_dir' ] }
+$OpenInteract2::Manage::Website::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
 
 sub setup_task {
     my ( $self ) = @_;
-    $self->setup_context;
+    $self->_setup_context;
 }
 
-
 ########################################
 # COMMON METHODS
 
+# This is just for the actions that only take 'website_dir'
+
+sub get_parameters {
+    my ( $self ) = @_;
+    return {
+        website_dir => $self->_get_website_dir_param,
+    };
+}
+
+sub _get_website_dir_param {
+    return {
+        description => 'Directory of an installed OpenInteract website',
+        is_required => 'yes',
+    };
+}
+
+sub _get_package_param {
+    return {
+        description => 'Package to work with',
+        is_required => 'yes',
+        is_multivalued => 'yes',
+    };
+}
+
 # Install all packages from a particular directory
 
 sub _install_packages {
@@ -90,40 +110,6 @@ sub _match_system_packages {
     return \%package_match;
 }
 
-
-########################################
-# WEBSITE TASK REGISTRATION
-
-# Register all of our known subclasses - we do this here rather than
-# in the classes themselves to prevent a bootstrapping problem
-
-my %CHILDREN = (
-  create_password       => 'OpenInteract2::Manage::Website::CreateSuperuserPassword',
-  create_website        => 'OpenInteract2::Manage::Website::Create',
-  upgrade_website       => 'OpenInteract2::Manage::Website::Upgrade',
-  list_actions          => 'OpenInteract2::Manage::Website::ListActions',
-  list_objects          => 'OpenInteract2::Manage::Website::ListObjects',
-  list_packages         => 'OpenInteract2::Manage::Website::ListPackages',
-  test_db               => 'OpenInteract2::Manage::Website::TestDB',
-  test_ldap             => 'OpenInteract2::Manage::Website::TestLDAP',
-  dump_theme            => 'OpenInteract2::Manage::Website::ThemeDump',
-  install_theme         => 'OpenInteract2::Manage::Website::ThemeInstall',
-  install_package       => 'OpenInteract2::Manage::Website::InstallPackage',
-  install_sql           => 'OpenInteract2::Manage::Website::InstallPackageSql',
-  install_sql_structure => 'OpenInteract2::Manage::Website::InstallPackageStructure',
-  install_sql_data      => 'OpenInteract2::Manage::Website::InstallPackageData',
-  install_sql_security  => 'OpenInteract2::Manage::Website::InstallPackageSecurity',
-  remove_package        => 'OpenInteract2::Manage::Website::RemovePackage',
-);
-
-sub register {
-    while ( my ( $name, $class ) = each %CHILDREN ) {
-        OpenInteract2::Manage->register_factory_type( $name, $class );
-    }
-}
-
-OpenInteract2::Manage::Website->register();
-
 1;
 
 __END__
@@ -170,18 +156,18 @@ L<OpenInteract2::Manage|OpenInteract2::Manage>. If your subclass has
 additional parameters to be validated, you should override the method
 and either include 'website_dir' as one of the entries or call
 C<SUPER> and capture the return. You should also implement the method
-C<get_validate_sub()> as discussed in
+C<validate_param()> as discussed in
 L<OpenInteract2::Manage|OpenInteract2::Manage>.
 
 B<setup_task()>
 
-Call C<setup_context()> from
+Call C<_setup_context()> from
 L<OpenInteract2::Manage|OpenInteract2::Manage> which sets up a
-L<OpenInteract2::Context|OpenInteract2::Context> object you can examine
-the website.
+L<OpenInteract2::Context|OpenInteract2::Context> object you can
+examine the website.
 
 If your task does not need this, override C<setup_task()> with an
-empty method.
+empty method or to do whatever you need.
 
 =head2 Common Functionality
 
@@ -189,14 +175,6 @@ B<_install_packages( $dir, \@package_names )>
 
 B<_match_system_packages( $dir )>
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 SEE ALSO
 
 L<OpenInteract2::Manage|OpenInteract2::Manage>
