@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::Create;
 
-# $Id: Create.pm,v 1.14 2003/06/12 00:05:37 lachoy Exp $
+# $Id: Create.pm,v 1.16 2003/07/16 12:22:02 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -12,7 +12,7 @@ use OpenInteract2::Manage    qw( SYSTEM_PACKAGES );
 use OpenInteract2::Package;
 use OpenInteract2::Repository;
 
-$OpenInteract2::Manage::Website::Create::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::Create::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 # think about merging this with info from OI2::Manage::Website::SetDirectoryPermissions
 
@@ -33,40 +33,47 @@ my @WEBSITE_SUBDIR = (
    [ 0777, 'uploads' ],
 );
 
-sub brief_description {
+# METADATA
+
+sub get_name {
+    return 'create_website';
+}
+
+sub get_brief_description {
     return 'Create a new website from sample files shipped with OI2';
 }
 
-sub list_param_require  { return [ 'website_dir', 'source_dir' ] }
-sub list_param_validate { return [ 'website_dir', 'source_dir' ] }
-
-sub get_param_description {
-    my ( $self, $param_name ) = @_;
-    if ( $param_name eq 'website_dir' ) {
-        return "Directory where website will be created. It must " .
-               "not already exist when you run the task.";;
-    }
-    return $self->SUPER::get_param_description( $param_name );
+sub get_parameters {
+    my ( $self ) = @_;
+    return {
+        source_dir  => $self->_get_source_dir_param,
+        website_dir => {
+               description =>
+                        "Directory where website will be created. It must " .
+                        "not already exist when you run the task.",
+               is_required => 'yes',
+        },
+    };
 }
 
+# VALIDATE
+
 # Use a different check for 'website_dir' than our parent, since we
 # want to ensure it DOES NOT exist
 
-sub get_validate_sub {
-    my ( $self, $param_name ) = @_;
-    return \&_check_website_dir if ( $param_name eq 'website_dir' );
-    return $self->SUPER::get_validate_sub( $param_name );
-}
-
-sub _check_website_dir {
-    my ( $self, $website_dir ) = @_;
-    if ( -d $website_dir ) {
-        return "Website directory [$website_dir] already " .
-               "exists; cannot create website over an " .
-               "existing site";
+sub validate_param {
+    my ( $self, $name, $value ) = @_;
+    if ( $name eq 'website_dir' ) {
+        if ( -d $value ) {
+            return "Website directory [$value] already exists; cannot " .
+                   "create website over an existing site";
+        }
+        return;
     }
+    return $self->SUPER::validate_param( $name, $value );
 }
 
+# RUN
 
 # Define empty method so parent doesn't create context
 
@@ -81,9 +88,11 @@ sub tear_down_task {
     my $website_dir = $self->param( 'website_dir' );
     $self->notify_observers(
         progress => 'Some part of the task failed, cleaning up directory' );
-    eval { rmtree( $website_dir ) || die $! };
-    if ( $@ ) {
-        oi_error "Cannot cleanup website directory [$website_dir]: $@";
+    if ( -d $website_dir ) {
+        eval { rmtree( $website_dir ) || die $! };
+        if ( $@ ) {
+            oi_error "Cannot cleanup website directory [$website_dir]: $@";
+        }
     }
 }
 
@@ -92,22 +101,28 @@ sub run_task {
     my ( $self ) = @_;
     my $website_dir = $self->param( 'website_dir' );
     my $source_dir  = $self->param( 'source_dir' );
+
     $self->_create_directories( $website_dir );
     $self->notify_observers( progress => 'Directories created' );
+
     $self->_copy_widgets( $website_dir, $source_dir );
     $self->notify_observers(
         progress => 'Global templates copied' );
+
     $self->_copy_cgi( $website_dir, $source_dir );
     $self->notify_observers(
         progress => 'CGI interface copied' );
+
     $self->_copy_server_conf( $website_dir, $source_dir );
+
     $self->_copy_apache_conf( $website_dir, $source_dir );
+
     $self->_copy_daemon_conf( $website_dir, $source_dir );
     $self->notify_observers(
         progress => 'OI2 and web server configuration copied' );
 
     # This will initialize the context to our new website...
-    $self->setup_context({ skip => 'initialize repository' });
+    $self->_setup_context({ skip => 'initialize repository' });
 
     my $repository = OpenInteract2::Repository->new();
     $repository->website_dir( $website_dir );
@@ -117,6 +132,7 @@ sub run_task {
                              { long => 'yes' } );
     $self->_install_packages( $source_dir, SYSTEM_PACKAGES );
     $self->notify_observers( progress => 'Packages installed' );
+
     $self->_set_nowrite_files( $website_dir, $source_dir );
     $self->_add_status_head(
             { action  => 'create website',
@@ -281,6 +297,8 @@ sub _set_nowrite_files {
     }
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
@@ -292,10 +310,10 @@ OpenInteract2::Manage::Website::Create - Create a new website
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
-
+ 
  use strict;
  use OpenInteract2::Manage;
-
+ 
  my $website_dir = '/home/httpd/mysite';
  my $source_dir  = '/usr/local/src/OpenInteract-2.01';
  my $task = OpenInteract2::Manage->new(
