@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::CreateSuperuserPassword;
 
-# $Id: CreateSuperuserPassword.pm,v 1.4 2003/06/25 16:47:53 lachoy Exp $
+# $Id: CreateSuperuserPassword.pm,v 1.6 2003/07/16 12:22:02 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -8,49 +8,48 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Utility;
 
-$OpenInteract2::Manage::Website::CreateSuperuserPassword::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::CreateSuperuserPassword::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
+# METADATA
 
-sub brief_description {
+sub get_name {
+    return 'create_password';
+}
+
+sub get_brief_description {
     return 'Change the superuser password';
 }
 
-sub get_param_description {
-    my ( $self, $param_name ) = @_;
+sub get_parameters {
+    my ( $self ) = @_;
+    return {
+        password => {
+            description => "New password for superuser",
+            is_required => 'yes',
+        },
+        website_dir => $self->_get_website_dir_param,
+    };
+}
+
+# VALIDATE
+
+sub validate_param {
+    my ( $self, $param_name, $value ) = @_;
     if ( $param_name eq 'password' ) {
-        return "New password for superuser";
+        unless ( $value ) {
+            return ( "Parameter 'password' must be defined" );
+        }
     }
-    return $self->SUPER::get_param_description( $param_name );
+    return $self->SUPER::validate_param( $param_name, $value );
 }
 
-
-sub list_param_required {
-    return [ 'website_dir', 'password' ];
-}
-
-sub list_param_validate {
-    return [ 'website_dir', 'password' ];
-}
-
-sub get_validate_sub {
-    my ( $self, $param_name ) = @_;
-    return \&_validate_password if ( $param_name eq 'password' );
-    return $self->SUPER::get_validate_sub( $param_name );
-}
-
-sub _validate_password {
-    my ( $self, $password ) = @_;
-    unless ( $password ) {
-        return ( "Parameter 'password' must be defined" );
-    }
-    return ();
-}
+# RUN
 
 sub run_task {
     my ( $self ) = @_;
     my %status = ();
     my $password = $self->param( 'password' );
-    my $root_id = CTX->server_config->{default_objects}{superuser};
+    my $root_id = CTX->default_object_id( 'superuser' );
     my $root = eval {
         CTX->lookup_object( 'user' )
            ->fetch( $root_id, { skip_security => 1 } )
@@ -79,6 +78,8 @@ sub run_task {
     return;
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
