@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::InstallPackageSql;
 
-# $Id: InstallPackageSql.pm,v 1.7 2003/06/25 16:47:53 lachoy Exp $
+# $Id: InstallPackageSql.pm,v 1.9 2003/07/16 12:22:02 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -8,28 +8,38 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Setup;
 
-$OpenInteract2::Manage::Website::InstallPackageSql::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::InstallPackageSql::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
-sub brief_description {
+sub get_name {
+    return 'install_sql';
+}
+
+sub get_brief_description {
     return "Run the 'install_sql_structure', 'install_sql_data' and " .
            "'install_sql_security' tasks in that order.";
 }
 
-sub list_param_require { return [ 'website_dir', 'package' ] }
+sub get_parameters {
+    my ( $self ) = @_;
+    return {
+        website_dir => $self->_get_website_dir_param,
+        package     => $self->_get_package_param,
+    };
+}
 
 sub setup_task {
     my ( $self ) = @_;
-    $self->setup_context( { skip => 'activate spops' } );
+    $self->_setup_context( { skip => 'activate spops' } );
 }
 
 sub run_task {
     my ( $self ) = @_;
     my $struct = OpenInteract2::Manage->new( 'install_sql_structure' );
-    $struct->param_copy( $self );
+    $struct->param_copy_from( $self );
     my $data = OpenInteract2::Manage->new( 'install_sql_data' );
-    $data->param_copy( $self );
+    $data->param_copy_from( $self );
     my $security = OpenInteract2::Manage->new( 'install_sql_security' );
-    $security->param_copy( $self );
+    $security->param_copy_from( $self );
     eval {
         $struct->execute;
         $self->_add_status( $struct->get_status );
@@ -53,6 +63,8 @@ sub run_task {
                                message => 'SQL installation successful' } );
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
@@ -107,16 +119,6 @@ Name of package this action spawmed from.
 
 =back
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
-=head1 SEE ALSO
-
 =head1 COPYRIGHT
 
 Copyright (C) 2003 Chris Winters. All rights reserved.
