@@ -1,21 +1,27 @@
 package OpenInteract2::Manage::Website::TestDB;
 
-# $Id: TestDB.pm,v 1.8 2003/06/25 16:47:53 lachoy Exp $
+# $Id: TestDB.pm,v 1.10 2003/07/14 13:08:38 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Manage::Website::TestDB::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::TestDB::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
-sub brief_description {
+sub get_name {
+    return 'test_db';
+}
+
+sub get_brief_description {
     return 'Test all configured database connections in a website';
 }
 
+# get_parameters() is inherited from parent
+
 sub run_task {
     my ( $self ) = @_;
-    my $datasource_config = CTX->datasource_config;
+    my $datasource_config = CTX->lookup_datasource_config;
     my ( $error_msg );
 
     # Perform initial sanity checks
@@ -29,7 +35,7 @@ sub run_task {
 
     my $dbi_ds = 0;
     my @status = ();
-    my $default_dbi = CTX->server_config->{datasource_info}{default_connection_db};
+    my $default_dbi = CTX->lookup_default_datasource_name;
 
 DATASOURCE:
     while ( my ( $name, $ds_conf ) = each %{ $datasource_config } ) {
@@ -86,6 +92,8 @@ DATASOURCE:
     }
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
@@ -139,14 +147,6 @@ not.
 
 =back
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2002-2003 Chris Winters. All rights reserved.
