@@ -1,21 +1,27 @@
 package OpenInteract2::Manage::Website::TestLDAP;
 
-# $Id: TestLDAP.pm,v 1.7 2003/06/25 16:47:53 lachoy Exp $
+# $Id: TestLDAP.pm,v 1.9 2003/07/14 13:08:38 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Manage::Website::TestLDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::TestLDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
-sub brief_description {
+sub get_name {
+    return 'test_ldap';
+}
+
+sub get_brief_description {
     return 'Test all configured LDAP connections in a website';
 }
 
+# get_parameters() is inherited from parent
+
 sub run_task {
     my ( $self ) = @_;
-    my $datasource_config = CTX->datasource_config;
+    my $datasource_config = CTX->lookup_datasource_config;
     my ( $error_msg );
 
     # Perform initial sanity checks
@@ -28,9 +34,7 @@ sub run_task {
         return;
     }
 
-    my $ldap_ds = 0;
-    my @status = ();
-    my $default_ldap = CTX->server_config->{datasource_info}{default_connection_ldap};
+    my $default_ldap = CTX->lookup_default_ldap_datasource_name;
 
     # Initial checks are done, now scroll through each of the
     # connection hashrefs and try to make a connection
@@ -38,7 +42,6 @@ sub run_task {
 DATASOURCE:
     while ( my ( $name, $ds_conf ) = each %{ $datasource_config } ) {
         next unless ( $ds_conf->{type} eq 'LDAP' );
-        $ldap_ds++;
         my %s = ( name => $name, is_ok => 'no' );
         $s{is_default} = ( $default_ldap eq $name ) ? 'yes' : 'no';
         unless ( $ds_conf->{host} ) {
@@ -69,9 +72,11 @@ DATASOURCE:
         $s{message} = "Connected and bound to directory ok";
         $self->_add_status( \%s );
     }
-    return @status;
+    return;
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
@@ -124,14 +129,6 @@ not.
 
 =back
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2002-2003 Chris Winters. All rights reserved.
