@@ -1,10 +1,11 @@
 package OpenInteract2::Package;
 
-# $Id: Package.pm,v 1.20 2003/06/26 11:16:25 lachoy Exp $
+# $Id: Package.pm,v 1.26 2003/08/22 02:18:21 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor );
 use Archive::Zip             qw( :ERROR_CODES );
+use Cwd                      qw( cwd );
 use Data::Dumper             qw( Dumper );
 use Digest::MD5              qw();
 use ExtUtils::Manifest       ();
@@ -24,7 +25,7 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Repository;
 use OpenInteract2::Util;
 
-$OpenInteract2::Package::VERSION   = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Package::VERSION   = sprintf("%d.%02d", q$Revision: 1.26 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract2::Package::EXPORT_OK = qw( DISTRIBUTION_EXTENSION );
 
 use constant DISTRIBUTION_EXTENSION => 'zip';
@@ -45,6 +46,8 @@ OpenInteract2::Package->mk_accessors( @FIELDS );
 
 sub new {
     my ( $class, $params ) = @_;
+    my $log = get_logger( LOG_OI );
+
     my $self = bless( {}, $class );
     my ( $to_read );
     if ( ref $params->{package_config} eq 'OpenInteract2::Config::Package' ) {
@@ -56,6 +59,8 @@ sub new {
                      "file. (Given [$params->{package_file}])";
         }
         my $full_path = File::Spec->rel2abs( $params->{package_file} );
+        $log->is_debug &&
+            $log->debug( "Setting full path for package file [$full_path]" );
         $self->package_file( $full_path );
         $to_read++;
     }
@@ -93,13 +98,18 @@ sub _read_package_data {
 
 sub _read_info_from_file {
     my ( $self ) = @_;
-    my $tmp_dir = tempdir();
+    my $log = get_logger( LOG_OI );
+
+    my $tmp_dir = tempdir( 'OIPKGXXXX', TMPDIR => 1, CLEANUP => 1 );
     unless ( -d $tmp_dir and -w $tmp_dir ) {
         oi_error "Cannot find writeable temp dir";
     }
-    my $pwd = File::Spec->rel2abs( File::Spec->curdir );
+    my $pwd = cwd();
     chdir( $tmp_dir );
 
+    my $package_file = $self->package_file;
+    $log->is_debug &&
+        $log->debug( "Reading package info from [$package_file]" );
     eval {
         my $filename = basename( $self->package_file );
         my $ext = '.' . DISTRIBUTION_EXTENSION;
@@ -114,7 +124,7 @@ sub _read_info_from_file {
         # OI2::Config::PackageChanges) rely on the package being able
         # to report SOME sort of directory.
 
-        $self->directory( $tmp_dir );
+        $self->directory( $extracted_dir );
     };
     my $error = $@;
     chdir( $pwd );
@@ -127,11 +137,16 @@ sub _read_info_from_file {
 
 sub _read_info_from_dir {
     my ( $self, $dir ) = @_;
+    my $log = get_logger( LOG_OI );
+
     $dir ||= $self->directory;
     unless ( -d $dir ) {
         oi_error "Cannot read package information from invalid ",
                  "directory [$dir]";
     }
+
+    $log->is_debug &&
+        $log->debug( "Reading package info from [$dir]" );
     $self->config( OpenInteract2::Config::Package->new({ directory => $dir }) );
     $self->name( $self->config->name );
     $self->version( $self->config->version );
@@ -147,6 +162,15 @@ sub full_name {
     return join( '-', $self->name, $self->version );
 }
 
+# don't use split here since the package name might have a '-' in it
+# (shouldn't happen, but still)
+
+sub parse_full_name {
+    my ( $class, $full_name ) = @_;
+    my ( $name, $version ) = $full_name =~ /^(.*)\-(.*)$/;
+    return ( $name, $version );
+}
+
 # Get the changelog
 
 sub get_changes {
@@ -177,7 +201,7 @@ sub _read_manifest {
         oi_error "Cannot read files from MANIFEST in [$manifest_dir]: ",
                  "the directory is invalid";
     }
-    my $pwd = File::Spec->rel2abs( File::Spec->curdir );
+    my $pwd = cwd();
     chdir( $manifest_dir );
     my $file_map = ExtUtils::Manifest::maniread;
     chdir( $pwd );
@@ -261,7 +285,7 @@ sub install {
     my $log = get_logger( LOG_OI );
 
     my $repository = $class->_install_get_repository( $params );
-    my $package_file = $params->{package_file};
+    my $package_file = File::Spec->rel2abs( $params->{package_file} );
     unless ( -f $package_file ) {
         oi_error "Valid package file must be specified in 'package_file'";
     }
@@ -269,7 +293,7 @@ sub install {
         $log->debug( "Install info - [File: $package_file] ",
                      "[Website dir: ", $repository->website_dir, "]" );
 
-    my $pwd = File::Spec->rel2abs( File::Spec->curdir );
+    my $pwd = cwd();
 
     # This should unpack the package into a temp dir, and deleting the
     # object (at the end of the method) should run DESTROY which
@@ -347,14 +371,14 @@ sub create_skeleton {
 
     my $full_skeleton_dir = File::Spec->rel2abs( $name );
     if ( -d $full_skeleton_dir ) {
-        oi_error "Cannot create package: destination directory ",
-                 "[$full_skeleton_dir] already exists";
+        oi_error "Cannot create package destination directory ",
+                 "'$full_skeleton_dir' already exists";
     }
 
     eval { mkdir( $full_skeleton_dir, 0777 ) || die $! };
     if ( $@ ) {
         oi_error "Failed to create package directory ",
-                 "[$full_skeleton_dir]: $@";
+                 "'$full_skeleton_dir': $@";
     }
 
     eval {
@@ -406,7 +430,7 @@ sub check {
     unless ( -d $self->directory ) {
         oi_error "Package must have valid directory set for 'check'";
     }
-    my $pwd = File::Spec->rel2abs( File::Spec->curdir );
+    my $pwd = cwd();
     chdir( $self->directory );
 
     my @status = ();
@@ -544,22 +568,6 @@ sub _remove_directory_tree {
 }
 
 
-# Create a manifest file in the current directory. (Note that the
-# 'Quiet' and 'Verbose' parameters won't work properly until
-# ExtUtils::Manifest is patched which won't likely be until 5.6.1)
-
-sub _skel_create_manifest {
-    my ( $class, $package_dir ) = @_;
-    my $pwd = File::Spec->rel2abs( File::Spec->curdir );
-    chdir( $package_dir );
-    local $SIG{__WARN__} = sub { return undef };
-    $ExtUtils::Manifest::Quiet   = 1;
-    $ExtUtils::Manifest::Verbose = 0;
-    ExtUtils::Manifest::mkmanifest();
-    chdir( $pwd );
-}
-
-
 ########################################
 # INSTALL PACKAGE HELPERS
 
@@ -573,7 +581,7 @@ sub _skel_create_manifest {
 sub _install_get_repository {
     my ( $class, $params ) = @_;
     my ( $repository );
-    if ( -d $params->{website_dir} ) {
+    if ( $params->{website_dir} and -d $params->{website_dir} ) {
         $repository = OpenInteract2::Repository->new(
                          { website_dir => $params->{website_dir} });
     }
@@ -747,16 +755,16 @@ sub _skel_clean_package_name {
     my ( @failures );
 
     $name =~ s/ /_/g 
-        && push @failures, "Name should not have spaces";
+        && push @failures, "Name must not have spaces";
     $name =~ s/\-/_/g
-        && push @failures, "Name should not have dashes";
+        && push @failures, "Name must not have dashes";
     $name =~ /^\d/
         && push @failures, "Name must not start with a number";
     $name =~ /\W/
         && push @failures, "Name must not have non-word characters";
 
     if ( scalar @failures ) {
-        oi_error "Package name [$name] unacceptable: \n",
+        oi_error "Package name '$name' unacceptable: \n",
                  join( "\n", @failures ), "\n";
     }
     return $name;
@@ -826,13 +834,28 @@ INIT
     close( CHANGES );
 }
 
+# Create a manifest file in the current directory. (Note that the
+# 'Quiet' and 'Verbose' parameters won't work properly until
+# ExtUtils::Manifest is patched which won't likely be until 5.6.1)
+
+sub _skel_create_manifest {
+    my ( $class, $package_dir ) = @_;
+    my $pwd = cwd();
+    chdir( $package_dir );
+    local $SIG{__WARN__} = sub { return undef };
+    $ExtUtils::Manifest::Quiet   = 1;
+    $ExtUtils::Manifest::Verbose = 0;
+    ExtUtils::Manifest::mkmanifest();
+    chdir( $pwd );
+}
+
 
 ########################################
 # EXPORT PACKAGE HELPERS
 
 sub _export_check_manifest {
     my ( $self  ) = @_;
-    my $pwd = File::Spec->rel2abs( File::Spec->curdir );
+    my $pwd = cwd();
     chdir( $self->directory );
     local $ExtUtils::Manifest::Quiet = 1;
     my @missing = ExtUtils::Manifest::manicheck();
@@ -866,7 +889,7 @@ sub _export_archive_package {
     # 'get_files' method here (manicopy() wants a hashref for the
     # first argument...)
 
-    my $pwd = File::Spec->rel2abs( File::Spec->curdir );
+    my $pwd = cwd();
     chdir( $self->directory );
     my $package_files = ExtUtils::Manifest::maniread();
     local $ExtUtils::Manifest::Quiet = 1;
@@ -924,7 +947,7 @@ sub _create_archive {
 
 
 sub _extract_archive {
-    my ( $self, $filename ) = @_;
+    my ( $class, $filename ) = @_;
     unless ( -f $filename ) {
         oi_error "Cannot extract archive from [$filename]: invalid file";
     }
@@ -1055,23 +1078,29 @@ sub _check_templates {
     my @status = ();
     foreach my $template_file ( sort @{ $files } ) {
         my $s = { action => 'Template check', filename => $template_file };
-        eval {
-            $template->process( $template_file, undef, \$out )
+        if ( -f $template_file ) {
+            eval {
+                $template->process( $template_file, undef, \$out )
                     || die $template->error(), "\n"
-        };
-        if ( $@ ) {
-            if ( $@ =~ /$template_errors_re/ ) {
-                $s->{is_ok}   = 'yes';
-                $s->{message} = 'Template syntax seems to be ok';
+                };
+            if ( $@ ) {
+                if ( $@ =~ /$template_errors_re/ ) {
+                    $s->{is_ok}   = 'yes';
+                    $s->{message} = 'Template syntax seems to be ok';
+                }
+                else {
+                    $s->{is_ok}   = 'no';
+                    $s->{message} = $@;
+                }
             }
             else {
-                $s->{is_ok}   = 'no';
-                $s->{message} = $@;
+                $s->{is_ok}   = 'yes';
+                $s->{message} = 'Template syntax ok';
             }
         }
         else {
-            $s->{is_ok}   = 'yes';
-            $s->{message} = 'Template syntax ok';
+            $s->{is_ok}       = 'no';
+            $s->{message}     = 'File does not exist';
         }
         push @status, $s;
     }
@@ -1186,7 +1215,8 @@ sub _check_manifest {
 
 sub DESTROY {
     my ( $self ) = @_;
-    if ( -d $self->{_tmp_package_extract_dir} ) {
+    if ( $self->{_tmp_package_extract_dir} and
+             -d $self->{_tmp_package_extract_dir} ) {
         $self->_remove_directory_tree( $self->{_tmp_package_extract_dir} );
     }
 }
@@ -1392,6 +1422,11 @@ B<generate_distribution_digest( $package_file )>
 Creates an MD5 digest of the contents in C<$package_file>. (See
 L<Digest::MD5|Digest::MD5> for what this means.)
 
+B<parse_full_name( $full_name )>
+
+Returns a two-item list of the package name and version found in
+C<$full_name>.
+
 =head2 Object Methods
 
 B<full_name()>
