@@ -1,6 +1,6 @@
 package OpenInteract2::Repository;
 
-# $Id: Repository.pm,v 1.11 2003/06/24 03:35:38 lachoy Exp $
+# $Id: Repository.pm,v 1.13 2003/08/22 02:18:22 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor );
@@ -11,8 +11,9 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Package;
+#use Scalar::Util             qw( blessed );
 
-$OpenInteract2::Repository::VERSION   = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Repository::VERSION   = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract2::Repository::EXPORT_OK = qw( REPOSITORY_FILE );
 
 use constant REPOSITORY_FILE => 'repository.ini';
@@ -32,7 +33,8 @@ __PACKAGE__->mk_accessors( @FIELDS );
 
 sub new {
     my ( $class, $item ) = @_;
-    my $self = bless( { _package_info => [] }, $class );
+    my $self = bless( { _package_info  => [],
+                        _package_cache => {} }, $class );
 
     my $repository_file = REPOSITORY_FILE;
     my $typeof = ref $item;
@@ -109,11 +111,15 @@ sub fetch_package {
     unless ( $name ) {
         oi_error "Must pass in package name to fetch a package from the repository";
     }
+    if ( my $pkg = $self->_package_cache->{ $name } ) {
+        return $pkg;
+    }
     foreach my $pkg_info ( @{ $self->_package_info } ) {
         if ( $pkg_info->{name} eq $name ) {
             my $package_dir = $pkg_info->{directory};
             my $pkg = OpenInteract2::Package->new({ directory => $package_dir });
             $pkg->installed_date( $pkg_info->{installed} );;
+            $self->_add_package_cache( $pkg );
             return $pkg;
         }
     }
@@ -125,9 +131,7 @@ sub fetch_all_packages {
     my ( $self ) = @_;
     my @packages = ();
     foreach my $pkg_info ( @{ $self->_package_info } ) {
-        my $package_dir = $pkg_info->{directory};
-        my $pkg = OpenInteract2::Package->new({ directory => $package_dir });
-        $pkg->installed_date( $pkg_info->{installed} );
+        my $pkg = $self->fetch_package( $pkg_info->{name} );
         push @packages, $pkg;
     }
     return \@packages;
@@ -136,9 +140,10 @@ sub fetch_all_packages {
 
 sub add_package {
     my ( $self, $package, $options ) = @_;
-    unless ( ref $package eq 'OpenInteract2::Package' ) {
-        oi_error "Must pass in a package object to add";
-    }
+# TODO: Re-enable this when we can test (when Test::MockObject supports isa()
+#    unless ( blessed $package and $package->isa( 'OpenInteract2::Package' ) ) {
+#        oi_error "Must pass in a package object to add";
+#    }
 
     if ( my $old_package = $self->fetch_package( $package->name ) ) {
         eval {
@@ -155,13 +160,14 @@ sub add_package {
                      directory => $package->directory,
                      installed => $package->installed_date || scalar localtime );
     $self->_add_package_info( \%new_info );
-    unless ( $options->{transient} eq 'yes' ) {
+    unless ( $options->{transient} and $options->{transient} eq 'yes' ) {
         eval { $self->_save_repository };
         if ( $@ ) {
             $self->_remove_package_info( $package->name );
             oi_error "Could not save repository with new information: $@";
         }
     }
+    $self->_add_package_cache( $package );
     return $self;
 }
 
@@ -176,10 +182,31 @@ sub remove_package {
             oi_error "Could not save repository with new information: $@";
         }
     }
+    $self->_remove_package_cache( $package->name );
     return $self;
 }
 
 
+sub _package_cache {
+    my ( $self ) = @_;
+    return $self->{_package_cache};
+}
+
+sub _clear_package_cache {
+    my ( $self ) = @_;
+    $self->{_package_cache} = {};
+}
+
+sub _add_package_cache {
+    my ( $self, $pkg ) = @_;
+    $self->{_package_cache}{ $pkg->name } = $pkg;
+}
+
+sub _remove_package_cache {
+    my ( $self, $name ) = @_;
+    delete $self->{_package_cache}{ $name };
+}
+
 sub _package_info {
     my ( $self ) = @_;
     return $self->{_package_info};
@@ -336,9 +363,7 @@ OpenInteract2::Repository - Operations to manipulate package repositories.
  
  # Install to website (apply package)
  
- my $info = eval { $repository->fetch_package_by_name({
-                                        name    => 'MyPackage',
-                                        version => 3.12 }) };
+ my $info = eval { $repository->fetch_package( 'mypackage' ) };
  my $site_repository = OpenInteract2::Package->fetch(
                                       undef,
                                       { directory => "/home/MyWebsiteDir" } );
@@ -437,8 +462,8 @@ Returns: full path to the package directory
 
 B<fetch_package( $package_name )>
 
-Retrieves a package from the repository by C<$package_name>. If one
-does not exist returns C<undef>.
+Retrieves a package from the repository by C<$package_name>. If no
+package matches C<$package_name> returns C<undef>.
 
 Example:
 
