@@ -1,20 +1,20 @@
 package OpenInteract2::Request;
 
-# $Id: Request.pm,v 1.20 2003/06/27 17:11:43 lachoy Exp $
+# $Id: Request.pm,v 1.34 2003/08/30 15:47:15 lachoy Exp $
 
 use strict;
 use base qw( Class::Factory Class::Accessor );
 use Log::Log4perl            qw( get_logger );
 use DateTime;
-use DateTime::Format::Strptime qw( strptime );
+use DateTime::Format::Strptime;
 use OpenInteract2::Constants qw( :log SESSION_COOKIE );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Cookie;
 use OpenInteract2::Exception qw( oi_error );
-use OpenInteract2::Session;
+use OpenInteract2::SessionManager;
 use OpenInteract2::URL;
 
-$OpenInteract2::Request::VERSION = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::VERSION = sprintf("%d.%02d", q$Revision: 1.34 $ =~ /(\d+)\.(\d+)/);
 
 ########################################
 # ACCESSORS
@@ -22,8 +22,7 @@ $OpenInteract2::Request::VERSION = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d
 my @FIELDS = qw(
     server_name remote_host user_agent referer cookie_header
     url_absolute url_relative url_initial action_name task_name
-    theme theme_values session
-    auth_user auth_group auth_is_admin auth_is_logged_in
+    session auth_user auth_group auth_is_admin auth_is_logged_in
 );
 __PACKAGE__->mk_accessors( @FIELDS );
 
@@ -38,13 +37,21 @@ sub set_implementation_type {
     return $impl_class;
 }
 
+sub get_implementation_type {
+    return $REQUEST_TYPE;
+}
+
 # Retrieve the current object
 
-# XXX: This has the potential of an endless loop if 'get_current()'
-# not defined in impl; maybe check whether it's defined in
-# set_implementation_type()?
-
-sub get_current { return $REQUEST_CLASS->get_current }
+sub get_current {
+    if ( $REQUEST_CLASS ) {
+        return $REQUEST_CLASS->get_current;
+    }
+    else {
+        oi_error "No request class defined -- run 'set_implementation_type()' ",
+                 "to set the type of requests we'll be processing.";
+    }
+}
 
 
 sub new {
@@ -98,8 +105,7 @@ sub param_toggled {
 sub param_date {
     my ( $self, $name, $format ) = @_;
     if ( $format ) {
-        return _parse_date_with_format( $self->param( $name ),
-                                        $format );
+        return $self->_parse_date_with_format( $name, $format );
     }
     my ( $y, $m, $d ) = ( $self->param( $name . '_year' ),
                           $self->param( $name . '_month' ),
@@ -113,23 +119,35 @@ sub param_date {
 sub param_datetime {
     my ( $self, $name, $format ) = @_;
     if ( $format ) {
-        return _parse_date_with_format( $self->param( $name ),
-                                        $format );
+        return $self->_parse_date_with_format( $name, $format );
     }
     my $date = $self->param_date( $name );
+    return undef unless ( defined $date );
     my ( $hour, $minute, $am_pm ) =
         ( $self->param( $name . '_hour' ),
           $self->param( $name . '_minute' ),
           $self->param( $name . '_am_pm' ) );
-    $hour += 12 if ( lc $am_pm eq 'pm' );
+    if ( lc $am_pm eq 'pm' and $hour < 12 ) {
+        $hour += 12;
+    }
     $date->set( hour   => $hour,
                 minute => $minute );
     return $date;
 }
 
 sub _parse_date_with_format {
-    my ( $value, $format ) = @_;
-    return strptime( $value, $format );
+    my ( $self, $name, $format ) = @_;
+    my $date_value = $self->param( $name );
+    unless ( $date_value ) {
+        return undef;
+    }
+    my $parser = DateTime::Format::Strptime->new( pattern  => $format,
+                                                  on_error => 'croak' );
+    my $dt = eval { $parser->parse_datetime( $date_value ) };
+    if ( $@ ) {
+        oi_error "Failed to parse date '$date_value' with format '$format': $@";
+    }
+    return $dt;
 }
 
 
@@ -143,14 +161,14 @@ sub auth_user_id {
 }
 
 
-sub _set_url {
-    my ( $self, $url ) = @_;
+sub assign_request_url {
+    my ( $self, $full_url_path ) = @_;
     my $log = get_logger( LOG_REQUEST );
     $log->is_info &&
-        $log->info( "Setting absolute URL [$url]" );
-    $self->url_absolute( $url );
+        $log->info( "Setting absolute URL [$full_url_path]" );
+    $self->url_absolute( $full_url_path );
     my $relative_url =
-        OpenInteract2::URL->parse_absolute_to_relative( $url );
+        OpenInteract2::URL->parse_absolute_to_relative( $full_url_path );
     $log->is_debug &&
         $log->debug( "Setting relative URL [$relative_url]" );
     $self->url_relative( $relative_url );
@@ -169,6 +187,8 @@ sub _set_url {
         my $action_none = CTX->lookup_action_none();
         $action_name = $action_none->name;
     }
+    $action_name ||= '';
+    $task        ||= '';
     $self->action_name( $action_name );
     $self->task_name( $task );
     $log->is_info &&
@@ -176,6 +196,21 @@ sub _set_url {
     return $relative_url;
 }
 
+sub action_messages {
+    my ( $self, $name, $messages ) = @_;
+    return {} unless ( $name );
+
+    if ( ref $messages eq 'HASH' ) {
+        $self->{_action_msg}{ lc $name } = $messages;
+    }
+    return $self->{_action_msg}{ lc $name };
+}
+
+sub add_action_message {
+    my ( $self, $action_name, $error_name, $error ) = @_;
+    return $self->{_action_msg}{ lc $action_name }{ $error_name } = $error;
+}
+
 ########################################
 # UPLOADS
 
@@ -237,7 +272,9 @@ sub clean_uploads {
     $log->is_info &&
         $log->info( "Cleaning all uploads: ", scalar @uploads );
     foreach my $item ( @uploads ) {
-        unlink( $item->tmp_name ) if ( -f $item->tmp_name );
+        my $filename = eval { $item->tmp_name };
+        next unless ( $filename );
+        unlink( $item->tmp_name ) if ( -f $filename );
     }
 }
 
@@ -276,7 +313,8 @@ sub _parse_cookies {
 sub create_session {
     my ( $self ) = @_;
     my $session_id = $self->cookie( SESSION_COOKIE );
-    my $oi_session_class = CTX->server_config->{session_info}{class};
+    my $session_info = CTX->lookup_session_config;
+    my $oi_session_class = $session_info->{class};
     my $session = $oi_session_class->create( $session_id );
     return $self->session( $session );
 }
@@ -284,6 +322,22 @@ sub create_session {
 ########################################
 # THEME
 
+sub theme {
+    my ( $self, $theme ) = @_;
+    if ( $theme ) {
+        $self->{theme} = $theme;
+        $self->{theme_values} = $theme->all_values;
+    }
+    return $self->{theme};
+}
+
+# 'theme_values' are only settable by setting 'theme'
+
+sub theme_values {
+    my ( $self ) = @_;
+    return $self->{theme_values};
+}
+
 # This should be called only after you've authenticated
 # TODO: Modify to also lookup in session cache...
 
@@ -297,24 +351,34 @@ sub create_theme {
         oi_error "Must authenticate before trying to fetch/create theme";
     }
     my $theme_id = $user->{theme_id}
-                   || CTX->server_config->{default_objects}{theme};
+                   || CTX->default_object_id( 'theme' );
     my $theme = eval {
         CTX->lookup_object( 'theme' )->fetch( $theme_id )
     };
     if ( $@ ) {
-        $log->error( "Failed to fetch theme [$theme_id]: $@" );
+        $log->error( "Failed to fetch theme '$theme_id': $@" );
         oi_error "Failed to fetch requested theme";
     }
     $self->theme( $theme );
     $log->is_info &&
-        $log->info( "Loaded theme $theme_id ok, getting values" );
-    $self->theme_values( $theme->all_values );
+        $log->info( "Loaded theme '$theme_id' ok, getting values" );
 }
 
 
 ########################################
 # FACTORY INFO
 
+sub factory_log {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_REQUEST )->info( @msg );
+}
+
+sub factory_error {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_REQUEST )->error( @msg );
+    die @msg, "\n";
+}
+
 OpenInteract2::Request->register_factory_type(
                     apache     => 'OpenInteract2::Request::Apache' );
 OpenInteract2::Request->register_factory_type(
@@ -377,6 +441,16 @@ object.
 
 =head1 METHODS
 
+=head2 Class Methods
+
+B<set_implementation_type( $type )>
+
+B<get_implementation_type()>
+
+B<new( @params )>
+
+=head2 Parameters
+
 B<param( [ $name, $value ] )>
 
 With no arguments, this returns a list -- not an arrayref! -- of
@@ -423,12 +497,15 @@ For example:
 
  # mydate = '2003-04-01'
  my $datetime = $request->param_date( 'mydate', '%Y-%m-%d' );
-
+ 
  # mydate_year  = '2003'
  # mydate_month = '04'
  # mydate_day   = '01'
  my $datetime = $request->param_date( 'mydate' );
 
+If you specify a format and the parser cannot parse the date you give
+with that format an exception will be thrown.
+
 B<param_datetime( $name, [ $format ] )>
 
 Similar to C<param_date> in that it reads parameter information and
@@ -464,6 +541,31 @@ For example:
  # mytime_am_pm  = 'PM'
  my $datetime = $request->param_datetime( 'mytime' );
 
+If you specify a format and the parser cannot parse the date you give
+with that format an exception will be thrown.
+
+=head2 Request URL
+
+B<assign_request_url( $full_url_path )>
+
+This method is normally only called by the implementing subclass. The
+subclass should pass the full, absolute URL path (no protocol, host or
+port) so the C<url_absolute> and C<url_relative> properties are
+properly set. This also sets the action name and task for use by the
+controller.
+
+If you want to do any behind-the-scenes redirection before the
+L<OpenInteract2::Controller|OpenInteract2::Controller> is
+instantiated, you can pass a path to this and the correct action will
+be processed. For instance, you can configure your site to force users
+to login, so no matter what URL is requested by a user who isn't
+logged in they'll always get your login page. This is done in the
+L<OpenInteract2::Auth|OpenInteract2::Auth> class -- if the user isn't
+logged in it assigns a new request URL which changes the action
+processed by the controller.
+
+=head2 Incoming Cookies
+
 B<cookie( [ $name, $value ] )>
 
 With no arguments it returns a list -- not an arrayref! -- of cookie
@@ -483,6 +585,8 @@ the server) see L<OpenInteract2::Response|OpenInteract2::Response>.
 Returns: list of cookie names (no argument), the value associated with
 the first argument (one argument, two arguments).
 
+=head2 Incoming Uploads
+
 B<upload( [ $name ] )>
 
 With no arguments, this returns a list -- B<not> an arrayref! -- of
@@ -499,7 +603,7 @@ B<clean_uploads()>
 
 Deletes all uploads associated with the request.
 
-=head1 PROPERTIES
+=head2 Properties
 
 B<url_absolute>
 
@@ -515,37 +619,100 @@ B<url_initial>
 
 This is the URL we used to lookup the action.
 
-B<server_name>
-
-B<remote_host>
-
-B<user_agent>
-
-B<referer>
-
 B<theme>
 
-B<theme_values>
+Theme object associated with this request. May change if user is
+logged in and has different theme.
+
+B<theme_values> (read-only)
+
+Hashref (not an object) of flattened theme properties. This is set
+automatically when C<theme> property is set.
 
 B<session>
 
+The current user's stateful session.
+
 B<action_name>
 
+Name of the action as gleaned from the URL. (May be empty, may change
+as a result of lookups.)
+
 B<task_name>
 
+Task of the action as gleaned from the URL. (May be empty, may change
+as a result of lookups.)
+
 B<auth_user>
 
+User logged in (or not) for this request. This should B<always> be
+filled with a user object, even if it's the 'not-logged-in' user.
+
 B<auth_group>
 
+Groups current user belongs to. May be empty.
+
 B<auth_is_admin>
 
+True if current user is an administrator, false if not. (You can
+customize this: see
+L<OpenInteract2::Auth::AdminCheck|OpenInteract2::Auth::AdminCheck>).
+
 B<auth_is_logged_in>
 
+True if current user is a legitimate user, false if it's the
+'not-logged-in' user.
+
 B<auth_user_id>
 
 Shortcut so you do not have to test whether the user is logged in to
 get an ID. If the user is not logged in, you get a '0' back.
 
+B<server_name>
+
+Hostname of our server.
+
+B<remote_host>
+
+Client IP address or hostname connecting to us.
+
+B<user_agent>
+
+The browser identification string. (May be empty, forged, etc.)
+
+B<referer>
+
+URL (string) where the user came from. (May be empty, forged, etc.)
+
+=head2 Action Messages
+
+Actions or other code can leave messages for other actions. These
+messages are typically tagged errors so the action and/or view knows
+how to sort through them, but it's not required. For instance, if a
+login fails we want to be able to indicate this so that the login box
+can display the right type of error message. Normally you'd set the
+messages directly in the action (via C<add_view_message()>), but in
+the (fairly rare) case where the two are disconnected you can deposit
+error messages in the request and the relevant action will know where
+to pick them up when it's later instantiated.
+
+B<action_messages( $action_name, [ \%messages ] )>
+
+Retrieve hashref of messages for action C<$action_name>,
+case-insensitive. Overwrite all existing messages with C<\%messages>
+if it's provided.
+
+Returns: hashref of action messages for action C<$action_name>; empty
+hashref if C<$action_name> not provided.
+
+B<add_action_message( $action_name, $msg_name, $msg )>
+
+Adds an individual message C<$msg_name> with message C<$msg> to
+C<$action_name>. The C<$msg_name> may be whatever you like, but
+frequently it's an object field name.
+
+Returns: C<$msg> set
+
 =head1 SUBCLASSING
 
 If you're extending OpenInteract to a new architecture and need to
@@ -572,14 +739,6 @@ may be the path of least resistance.
 
 =head2 Methods
 
-B<_set_url( $full_url )>
-
-This method is implemented in this class but is called by the
-implementing subclass. The subclass should pass the full, absolute URL
-in so the C<url_absolute> and C<url_relative> properties are properly
-set. This also sets the action name and task for use by the
-controller.
-
 B<_set_upload( $name, $upload )>
 
 Associates the
@@ -595,14 +754,6 @@ string will be parsed and the name/value pairs assigned to the request
 object. If C<$cookie_header_string> not passed in we look in the
 C<cookie_header> property.
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 SEE ALSO
 
 L<Class::Factory|Class::Factory>
