@@ -1,6 +1,6 @@
 package OpenInteract2::Request::Apache;
 
-# $Id: Apache.pm,v 1.10 2003/06/25 16:47:53 lachoy Exp $
+# $Id: Apache.pm,v 1.11 2003/08/27 15:03:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -12,7 +12,7 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Upload;
 use OpenInteract2::URL;
 
-$OpenInteract2::Request::Apache::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::Apache::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( apache );
 OpenInteract2::Request::Apache->mk_accessors( @FIELDS );
@@ -35,7 +35,7 @@ sub init {
 
     # Set the URI and parse it
 
-    $self->_set_url( $apache->uri );
+    $self->assign_request_url( $apache->uri );
 
     # Setup the GET/SET params
 
