@@ -1,6 +1,6 @@
 package OpenInteract2::Request::CGI;
 
-# $Id: CGI.pm,v 1.12 2003/06/25 16:47:53 lachoy Exp $
+# $Id: CGI.pm,v 1.13 2003/08/27 15:03:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -11,7 +11,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Upload;
 use OpenInteract2::URL;
 
-$OpenInteract2::Request::CGI::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::CGI::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( cgi );
 OpenInteract2::Request::CGI->mk_accessors( @FIELDS );
@@ -40,7 +40,7 @@ sub init {
     my $full_url = join( '', $base_url, $cgi->path_info );
     $log->is_debug &&
         $log->debug( "Full OI URL [$full_url]" );
-    $self->_set_url( $full_url );
+    $self->assign_request_url( $full_url );
 
     # Then the various headers, properties, etc.
 
