@@ -1,6 +1,6 @@
 package OpenInteract2::Request::LWP;
 
-# $Id: LWP.pm,v 1.14 2003/06/25 16:47:53 lachoy Exp $
+# $Id: LWP.pm,v 1.15 2003/08/27 15:03:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -13,7 +13,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Upload;
 
-$OpenInteract2::Request::LWP::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::LWP::VERSION = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( lwp );
 OpenInteract2::Request::LWP->mk_accessors( @FIELDS );
@@ -30,7 +30,7 @@ sub init {
     my $lwp_request = $params->{request};
     $self->lwp( $lwp_request );
 
-    $self->_set_url( $lwp_request->uri );
+    $self->assign_request_url( $lwp_request->uri );
 
     # Then the various headers, properties, etc.
 
