@@ -1,6 +1,6 @@
 package OpenInteract2::Request::Standalone;
 
-# $Id: Standalone.pm,v 1.6 2003/06/25 16:47:53 lachoy Exp $
+# $Id: Standalone.pm,v 1.7 2003/08/27 15:03:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -12,7 +12,7 @@ use OpenInteract2::Upload;
 use OpenInteract2::URL;
 use Sys::Hostname;
 
-$OpenInteract2::Request::Standalone::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::Standalone::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 my ( $CURRENT );
 
@@ -29,7 +29,7 @@ sub init {
 
     $log->is_debug &&
         $log->debug( "Full OI URL [$props->{url}]" );
-    $self->_set_url( $props->{url} );
+    $self->assign_request_url( $props->{url} );
 
     # Then the various headers, properties, etc.
 
@@ -138,6 +138,10 @@ OpenInteract2::Request::Standalone - Manually create a request object
 
 =head1 SYNOPSIS
 
+ # Set the request implementation to use
+ 
+ OpenInteract2::Request->set_implementation_type( 'standalone' );
+ 
  # Create all the request infomration offline...
  
  my %req_params = (
@@ -156,13 +160,12 @@ OpenInteract2::Request::Standalone - Manually create a request object
  
  # ...and create a new object with it
  
- my $req = OpenInteract2::Request->new( 'standalone', \%req_params );
-
+ my $req = OpenInteract2::Request->new( \%req_params );
+ 
  # ...or just create an empty object with the bare minimum of
  # infomration and set properties as needed
  
- my $req = OpenInteract2::Request->new( 'standalone',
-                                        { url => '/path/to/my/doc.html' } );
+ my $req = OpenInteract2::Request->new( { url => '/path/to/my/doc.html' } );
  $req->referer( 'http://www.foo.bar/path/to/my/index.html' );
  $req->param( eyes => 'two' );
  $req->param( soda => [ 'rc', 'mr. pibb' ] );
@@ -188,9 +191,10 @@ straightforward. There are a few more complicated ones:
 
 =item *
 
-B<url> - Required. This is the URL path (without the protocol, host
-and port information) and will get parsed into the B<url_absolute>,
-B<url_relative> and B<url_initial> request properties.
+B<url> - Required. This is the full URL path (without the protocol,
+host and port information) and will get parsed into the
+B<url_absolute>, B<url_relative> and B<url_initial> request
+properties.
 
 Default: none
 
@@ -208,8 +212,8 @@ Default: none
 
 B<cookie> - You can pass in one or more cookie strings (what the
 browser passes in its C<Cookie> header) and/or one or more
-L<OpenInteract2::Cookie|OpenInteract2::Cookie> objects. If the values
-set aren't simple scalars or cookie objects an exception is thrown.
+L<CGI::Cookie|CGI::Cookie> objects. If the values set aren't simple
+scalars or cookie objects an exception is thrown.
 
 Default: none
 
