@@ -1,6 +1,6 @@
 package OpenInteract2::Response;
 
-# $Id: Response.pm,v 1.11 2003/06/24 03:35:38 lachoy Exp $
+# $Id: Response.pm,v 1.16 2003/08/30 15:47:15 lachoy Exp $
 
 use strict;
 use base qw( Class::Factory Class::Accessor );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Response::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Response::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 ########################################
 # ACCESSORS
@@ -31,6 +31,10 @@ sub set_implementation_type {
     return $impl_class;
 }
 
+sub get_implementation_type {
+    return $RESPONSE_TYPE;
+}
+
 # Retrieve the current object
 
 # XXX: This has the potential of an endless loop if 'get_current()'
@@ -82,11 +86,11 @@ sub header {
     }
     my $log = get_logger( LOG_RESPONSE );
     if ( $value ) {
-        $self->{_header}{$name} = $value;
+        $self->{_header}{ $name } = $value;
         $log->is_debug &&
             $log->debug( "Setting header [$name] to [$value]" );
     }
-    return $self->{_header}{$name};
+    return $self->{_header}{ $name };
 }
 
 sub remove_header {
@@ -141,7 +145,7 @@ sub remove_cookie {
 
 sub save_session {
     my ( $self ) = @_;
-    OpenInteract2::Session->save( CTX->request->session );
+    OpenInteract2::SessionManager->save( CTX->request->session );
 }
 
 
@@ -182,6 +186,17 @@ sub return_url {
 ########################################
 # FACTORY
 
+sub factory_log {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_RESPONSE )->info( @msg );
+}
+
+sub factory_error {
+    my ( $self, @msg ) = @_;
+    get_logger( LOG_RESPONSE )->error( @msg );
+    die @msg, "\n";
+}
+
 __PACKAGE__->register_factory_type(
                     apache     => 'OpenInteract2::Response::Apache' );
 __PACKAGE__->register_factory_type(
@@ -244,6 +259,8 @@ B<get_current()>
 
 B<set_implementation_type( $type )>
 
+B<get_implementation_type()>
+
 B<new()>
 
 =head2 Object Methods
