@@ -1,8 +1,9 @@
 package OpenInteract2::ResultsManage;
 
-# $Id: ResultsManage.pm,v 1.4 2003/06/25 14:11:57 lachoy Exp $
+# $Id: ResultsManage.pm,v 1.5 2003/09/03 13:41:57 lachoy Exp $
 
 use strict;
+use base qw( Class::Accessor );
 use Data::Dumper  qw( Dumper );
 use IO::File;
 use Log::Log4perl            qw( get_logger );
@@ -12,7 +13,7 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::ResultsIterator;
 use SPOPS::Utility;
 
-$OpenInteract2::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 use constant FILENAME_WIDTH => 20;
 
@@ -21,18 +22,53 @@ my $RECORD_SEP       = '-->';
 my $EXTRA_NAME_SEP   = ',';
 my $MIXED_IDENTIFIER = 'MIXED';
 
-my @VALID_INIT_KEYS  = qw( search_id min max );
+my @FIELDS  = qw(
+    search_id min max results_dir keywords
+    num_records time date extra_name num_extra record_class result_list
+);
+__PACKAGE__->mk_accessors( @FIELDS );
 
-# Constructor
+########################################
+# CLASS METHODS
 
 sub new {
     my ( $pkg, $p ) = @_;
     my $class = ref $pkg || $pkg;
-    my %data = map { $_ => $p->{ $_ } } @VALID_INIT_KEYS;
+    my %data = map { $_ => $p->{ $_ } } @FIELDS;
     $data{results_dir} ||= $class->get_results_dir;
     return bless( \%data, $class );
 }
 
+sub get_results_dir {
+    my ( $class ) = @_;
+    return CTX->lookup_directory( 'overflow' );
+}
+
+sub find_page_boundaries {
+    my ( $class, $page_num, $per_page ) = @_;
+    return ( 0, 0 ) unless ( $page_num and $per_page );
+    my $max = $page_num * $per_page;
+    my $min = $max - $per_page;
+    return ( $min, $max );
+}
+
+# Note that $item can be a class or an object -- if object, we'll take
+# the number of records from it.
+
+sub find_total_page_count {
+    my ( $item, $per_page, $p_num_records ) = @_;
+    my $num_records = ( ref $item and $item->{num_records} )
+                        ? $item->{num_records} : $p_num_records;
+    return 0 unless ( $per_page and $num_records );
+    my $num_pages = $num_records / $per_page;
+    return ( int $num_pages != $num_pages ) ? int( $num_pages ) + 1 : int $num_pages;
+}
+
+
+
+
+########################################
+# OBJECT METHODS
 
 # Clear out all information in an object
 
@@ -78,7 +114,8 @@ sub save {
     # Generate a search ID and get the filename, then lock the
     # filename from further use while we're working
 
-    $params{search_id}= $self->generate_search_id;
+    $params{search_id} = $self->generate_search_id;
+    $log->debug( "Generated search ID '$params{search_id}'" );
     $self->results_lock( $params{search_id} );
     my ( $num_records );
     my $out      = IO::File->new();
@@ -89,13 +126,13 @@ sub save {
     eval {
         my $results_file = $self->build_results_filename( $params{search_id} );
         $out->open( "> $results_file" )
-                    || die "Cannot open for writing ($results_file): $!\n";
+                    || die "Cannot open '$results_file' for writing: $!\n";
         my $results_info = $self->persist( $out, $to_save, \%params );
         $out->close();
 
         my $meta_file = $self->build_meta_filename( $params{search_id} );
         $meta_out->open( "> $meta_file" )
-                         || die "Cannot open for writing ($meta_file): $!\n";
+                         || die "Cannot open '$meta_file' for writing: $!\n";
         $self->persist_meta( $meta_out, $results_info, \%params );
         $meta_out->close();
         $num_records = $results_info->{num_records};
@@ -120,9 +157,9 @@ sub save {
     # Set various information into the object
 
     $log->is_debug &&
-        $log->debug( "($num_records) results saved ok." );
-    $self->{num_records}      = $num_records;
-    return $self->{search_id} = $params{search_id};
+        $log->debug( "Results saved ok: $num_records" );
+    $self->num_records( $num_records );
+    return $self->search_id( $params{search_id} );
 }
 
 
@@ -204,7 +241,7 @@ sub persist_iterator {
 # global $MIXED_IDENTIFIER which tells us it's heterogeneous
 
 sub review_results_class {
-    my ( $class, $result_list ) = @_;
+    my ( $self, $result_list ) = @_;
     my ( $main_class );
     foreach my $result ( @{ $result_list } ) {
         my $result_class = ref $result;
@@ -232,7 +269,7 @@ sub persist_meta {
          num_extra    => ( ref $info->{extra_name} eq 'ARRAY' )
                            ? scalar $info->{extra_name} : 0,
          filename     => $params->{filename},
-         results_dir  => $self->{results_dir},
+         results_dir  => $self->results_dir,
          search_id    => $params->{search_id},
     );
     $out->print( Dumper( \%meta_info ) );
@@ -270,7 +307,7 @@ sub retrieve {
     my ( $self, $p ) = @_;
     my $log = get_logger( LOG_APP );
 
-    unless ( $self->{search_id} ) {
+    unless ( $self->search_id ) {
         die "Cannot retrieve results without a search_id! Please ",
             "set at object initialization or as a property of the ",
             "object before running retrieve().\n";
@@ -278,23 +315,25 @@ sub retrieve {
 
     # 'min' and 'max' can be properties or passed in
 
-    $self->{min} ||= $p->{min};
-    $self->{max} ||= $p->{max};
+    $self->min( $p->{min} ) unless ( defined $self->min );
+    $self->max( $p->{max} ) unless ( defined $self->max );
 
     # Clear out the number of records
 
-    $self->{num_records} = 0;
+    $self->num_records(0);
 
     $log->is_debug &&
         $log->debug( "Retrieving raw search results for ",
-                     "ID ($self->{search_id})" );
+                     "ID '", $self->search_id, "'" );
     $self->assign_results_to_object( $self->retrieve_raw_results( $p ) );
 
     # If they asked for an iterator return it, but first clear out any
     # min/max values since they've already been preselected
 
     if ( $p->{return} eq 'iterator' ) {
-        $self->{min} = $self->{max} = $p->{min} = $p->{max} = 0;
+        $self->min(0);
+        $self->max(0);
+        $p->{min} = $p->{max} = 0;
         return $self->retrieve_iterator( $p );
     }
     return $self;
@@ -309,31 +348,32 @@ sub retrieve_iterator {
 
     # 'min' and 'max' can be properties or passed in
 
-    $self->{min}         ||= $p->{min};
-    $self->{max}         ||= $p->{max};
+    $self->min( $p->{min} ) unless ( defined $self->min );
+    $self->max( $p->{max} ) unless ( defined $self->max );
 
     $log->is_debug &&
         $log->debug( "Retrieving search iterator for ID",
-                  "($self->{search_id})" );
+                     "'", $self->search_id, "'" );
 
-    unless ( $self->{result_list} ) {
+    unless ( $self->result_list ) {
         $self->assign_results_to_object( $self->retrieve_raw_results( $p ) );
     }
-    if ( $self->{num_records} <= 0 ) {
+    if ( $self->num_records <= 0 ) {
         return OpenInteract2::ResultsIterator->new({ results => $self });
     }
 
-    unless ( $self->{record_class} ) {
-        die "Cannot create iterator! Search results were not saved with a classname.",
-            "(Search ID: $self->{search_id})\n";
+    unless ( $self->record_class ) {
+        die "Cannot create iterator! Search results were not saved with ",
+            "a classname. [Search ID: ", $self->search_id, "]\n";
     }
-    if ( $self->{record_class} eq $MIXED_IDENTIFIER ) {
-        $self->{min} = $self->{max} = 0;
+    if ( $self->record_class eq $MIXED_IDENTIFIER ) {
+        $self->min(0);
+        $self->max(0);
         return OpenInteract2::ResultsIterator->new({
                      results       => $self,
                      skip_security => $p->{skip_security} });
     }
-    return $self->{record_class}->fetch_iterator({ id_list => $self->get_id_list });
+    return $self->record_class->fetch_iterator({ id_list => $self->get_id_list });
 }
 
 
@@ -341,10 +381,10 @@ sub retrieve_iterator {
 
 sub get_id_list {
     my ( $self ) = @_;
-    unless ( $self->{result_list} ) {
+    unless ( $self->result_list ) {
         die "Results not yet saved for this object!\n"
     }
-    return [ map { $_->{id} } @{ $self->{result_list} } ];
+    return [ map { $_->{id} } @{ $self->result_list } ];
 }
 
 
@@ -357,34 +397,35 @@ sub retrieve_raw_results {
     my ( $self, $p ) = @_;
     my $log = get_logger( LOG_APP );
 
-    unless ( $self->{search_id} ) {
+    unless ( $self->search_id ) {
         oi_error "No search_id defined in object!";
     }
 
-    my $meta_info = $self->get_meta({ search_id => $self->{search_id} });
+    my $meta_info = $self->get_meta({ search_id => $self->search_id });
     $log->is_debug &&
-        $log->debug( "Run on: ($meta_info->{date})",
-                     "Saved: ($meta_info->{num_records})",
-                     "Type: ($meta_info->{record_class})" );
+        $log->debug( "[Run on: $meta_info->{date}] ",
+                     "[Saved: $meta_info->{num_records}] ",
+                     "[Type: $meta_info->{record_class}]" );
     if ( $meta_info->{num_records} <= 0 ) {
         return $meta_info;
     }
 
     my $filename = $self->build_results_filename;
-    eval { open( RESULTS, $filename ) || die "Cannot open ($filename): $!\n" };
+    eval { open( RESULTS, $filename ) || die "Cannot open '$filename' for reading: $!\n" };
     if ( $@ ) {
         $log->error( "Search result retrieval failure. $@" );
         return undef;
     }
 
     my $count = 1;
-    my $min = $self->{min} || $p->{min};
-    my $max = $self->{max} || $p->{max};
+    my $min = ( defined $self->min ) ? $self->min : $p->{min};
+    my $max = ( defined $self->max ) ? $self->max : $p->{max};
     while ( <RESULTS> ) {
         if ( $min and $count < $min ) { $count++; next; }
         if ( $max and $count > $max ) { last; }
         chomp;
-        my ( $item_class, $item_value, @extra ) = split /$RECORD_SEP/, $_, 2 + $meta_info->{num_extra};
+        my ( $item_class, $item_value, @extra ) =
+            split /$RECORD_SEP/, $_, 2 + $meta_info->{num_extra};
         my $result_info = { id => $item_value };
         if ( $meta_info->{record_class} eq $MIXED_IDENTIFIER ) {
             $result_info->{class} = $item_class;
@@ -404,92 +445,66 @@ sub retrieve_raw_results {
 
 sub assign_results_to_object {
     my ( $self, $result_info ) = @_;
-    for ( qw( num_records time date extra_name num_extra record_class result_list ) ) {
-        $self->{ $_ } = $result_info->{ $_ };
+    for ( @FIELDS ) {
+        $self->$_( $result_info->{ $_ } );
     }
     return $self;
 }
 
 
-########################################
-# PAGING METHODS
-########################################
-
-
-# Note that $item can be a class or an object -- if object, we'll take
-# the number of records from it.
-
-sub find_total_page_count {
-    my ( $item, $per_page, $p_num_records ) = @_;
-    my $num_records = ( ref $item and $item->{num_records} )
-                        ? $item->{num_records} : $p_num_records;
-    return 0 unless ( $per_page and $num_records );
-    my $num_pages = $num_records / $per_page;
-    return ( int $num_pages != $num_pages ) ? int( $num_pages ) + 1 : int $num_pages;
-}
-
-
-sub find_page_boundaries {
-    my ( $class, $page_num, $per_page ) = @_;
-    return ( 0, 0 ) unless ( $page_num and $per_page );
-    my $max = $page_num * $per_page;
-    my $min = $max - $per_page;
-    return ( $min, $max );
-}
-
-
-
-########################################
+#######################################
 # FILENAME/DIRECTORY METHODS
 ########################################
 
-sub get_results_dir {
-    my ( $class ) = @_;
-    return CTX->server_config->{dir}{overflow};
-}
-
-
 sub build_results_filename {
     my ( $self, $p_search_id ) = @_;
-    my $search_id = $self->{search_id} || $p_search_id;
+    my $search_id = $self->search_id || $p_search_id;
     unless ( $search_id ) {
         die "Cannot build a results filename without a search_id ",
             "as property or parameter!\n";
     }
-    $self->{results_dir} ||= $self->get_results_dir;
-    return join( '/', $self->{results_dir}, $search_id );
+    unless ( $self->results_dir ) {
+        $self->results_dir( $self->get_results_dir );
+    }
+    return File::Spec->catfile( $self->results_dir, $search_id );
 }
 
 
 sub build_meta_filename {
     my ( $self, $p_search_id ) = @_;
-    my $search_id = $self->{search_id} || $p_search_id;
+    my $search_id = $self->search_id || $p_search_id;
     unless ( $search_id ) {
         die "Cannot build a results filename without a search_id ",
             "as property or parameter!\n";
     }
-    $self->{results_dir} ||= $self->get_results_dir;
-    return join( '/', $self->{results_dir}, "$search_id.meta" );
+    unless ( $self->results_dir ) {
+        $self->results_dir( $self->get_results_dir );
+    }
+    return File::Spec->catfile( $self->results_dir, "$search_id.meta" );
 }
 
 
 sub build_lock_filename {
     my ( $self, $p_search_id ) = @_;
-    my $search_id = $self->{search_id} || $p_search_id;
+    my $search_id = $self->search_id || $p_search_id;
     unless ( $search_id ) {
         die "Cannot build a lock filename without a search_id ",
             "as property or parameter!\n";
     }
-    $self->{results_dir} ||= $self->get_results_dir;
-    return join( '/', $self->{results_dir}, "$search_id.$LOCK_EXT" );
+    unless ( $self->results_dir ) {
+        $self->results_dir( $self->get_results_dir );
+    }
+    return File::Spec->catfile( $self->results_dir, "$search_id.$LOCK_EXT" );
 }
 
 
 sub get_all_result_filenames {
     my ( $self ) = @_;
-    $self->{results_dir} ||= $self->get_results_dir;
-    opendir( RESULTS, $self->{results_dir} )
-             || die "Cannot open results directory ($self->{results_dir}): $!";
+    unless ( $self->results_dir ) {
+        $self->results_dir( $self->get_results_dir );
+    }
+    opendir( RESULTS, $self->results_dir )
+             || die "Cannot open results directory '", $self->results_dir, "': $!";
     my @results_files = grep ! /\./, grep { length $_ == FILENAME_WIDTH } readdir( RESULTS );
     closedir( RESULTS );
     return \@results_files;
@@ -521,18 +536,20 @@ sub generate_search_id {
     my ( $self ) = @_;
     my $log = get_logger( LOG_APP );
 
-    $self->{results_dir} ||= $self->get_results_dir;
+    unless ( $self->results_dir ) {
+        $self->results_dir( $self->get_results_dir );
+    }
 
-    unless ( -d $self->{results_dir} ) {
-        $log->error( "Search results directory ($self->{results_dir})",
+    unless ( -d $self->results_dir ) {
+        $log->error( "Search results directory '", $self->results_dir, "'",
                       "is not a directory" );
         die "Configuration option for writing search results ",
-            "($self->{results_dir}) is not a directory";
+            "'", $self->results_dir, "' is not a directory";
     }
-    unless ( -w $self->{results_dir} ) {
-        $log->error( "Search results dir ($self->{results_dir}) is not writeable" );
+    unless ( -w $self->results_dir ) {
+        $log->error( "Search results dir '", $self->results_dir, "' is not writeable" );
         die "Configuration option for writing search results ",
-            "($self->{results_dir}) exists but is not writeable";
+            "'", $self->results_dir, "' exists but is not writeable";
     }
     while ( 1 ) {
         my $search_id = SPOPS::Utility->generate_random_code( FILENAME_WIDTH );
@@ -541,7 +558,7 @@ sub generate_search_id {
         next if ( -f $filename || -f $lockfile );
         $log->is_debug &&
             $log->debug( "Found non-existent search info for ",
-                      "($search_id) in ($self->{results_dir})" );
+                         "'$search_id' in '", $self->results_dir, "'" );
         return $search_id;
     }
 }
@@ -557,7 +574,7 @@ sub results_lock {
     my ( $self, $search_id ) = @_;
     my $lock_file = $self->build_lock_filename( $search_id );
     open( LOCK, "> $lock_file" )
-        || die "Cannot open lockfile ($lock_file): $!";
+        || die "Cannot open lockfile '$lock_file' for writing: $!";
     print LOCK scalar localtime;
     close( LOCK );
 }
@@ -570,10 +587,9 @@ sub results_unlock {
     my $lock_file = $self->build_lock_filename( $search_id );
     return unless ( -f $lock_file );
     unlink( $lock_file )
-          || die "Cannot remove lockfile ($lock_file): $!";
+          || die "Cannot remove lockfile '$lock_file': $!";
 }
 
-
 1;
 
 __END__
@@ -775,17 +791,19 @@ Parameters: same as C<retrieve()>
 
 B<find_total_page_count( $records_per_page, [ $num_records ] )>
 
-If 'num_records' is not in the object, then you can pass it as a
-second parameter. In this manner the method is a class method.
+If called as an object then use 'num_records' property of object. If
+'num_records' is not in the object, or if you call this as a class
+method, then we use the second parameter for the total number of
+records.
 
-Returns: Number of pages required to display $num_records at
-$records_per_page.
+Returns: Number of pages required to display C<$num_records> at
+C<$records_per_page>.
 
 Example:
 
  my $page_count = $class->find_total_page_count( 289, 25 );
  # $page_count = 11
-
+ 
  my $page_count = $class->find_total_page_count( 289, 75 );
  # $page_count = 4
 
