@@ -1,6 +1,6 @@
 package OpenInteract2::SPOPS;
 
-# $Id: SPOPS.pm,v 1.15 2003/07/03 05:03:07 lachoy Exp $
+# $Id: SPOPS.pm,v 1.20 2003/09/05 02:20:31 lachoy Exp $
 
 use strict;
 use Digest::MD5              qw( md5_hex );
@@ -11,183 +11,13 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Util;
 use SPOPS::ClassFactory      qw( OK NOTIFY );
 
-$OpenInteract2::SPOPS::VERSION = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SPOPS::VERSION = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 # TODO:
 #   - move object key stuff to a separate class
 
 use constant OBJECT_KEY_TABLE => 'object_keys';
 
-########################################
-# STARTUP MODIFY CONFIGURATION
-
-# This should be called BEFORE the children make their modifications,
-# so each child should call a SUPER::modify_spops_config( $config )...
-
-sub modify_spops_config {
-    my ( $class, $config ) = @_;
-
-    # Ensure 'isa' and 'rules_from' are arrayrefs...
-
-    $config->{isa} ||= [];
-    unless ( ref $config->{isa} eq 'ARRAY' ) {
-        $config->{isa} = ( defined $config->{isa} )
-                           ? [ $config->{isa} ] : [];
-    }
-
-    $config->{rules_from} ||= [];
-    unless ( ref $config->{rules_from} eq 'ARRAY' ) {
-        $config->{rules_from} = ( defined $config->{rules_from} )
-                                  ? [ $config->{rules_from} ] : [];
-    }
-
-    _config_security( $config );
-    _config_creation_security( $config );
-    _config_date_conversion( $config );
-    _config_fulltext( $config );
-    _config_display_info( $config );
-}
-
-sub _config_security {
-    my ( $config ) = @_;
-    my $log = get_logger( LOG_SPOPS );
-    if ( defined $config->{is_secure} and $config->{is_secure} eq 'yes' ) {
-        $log->is_debug &&
-            $log->debug( "Adding security to ",
-                         "[$config->{key}: $config->{class}]" );
-        unshift @{ $config->{isa} }, 'SPOPS::Secure';
-    }
-    return;
-}
-
-sub _config_creation_security {
-    my ( $config ) = @_;
-    my $log = get_logger( LOG_SPOPS );
-
-    unless ( ref $config->{creation_security} eq 'HASH' ) {
-        return;
-    }
-    $log->is_debug &&
-        $log->debug( "Checking 'creation_security' rules for ",
-                     "[[$config->{key}: $config->{class}]" );
-    my %create = ( u => $config->{creation_security}{user},
-                   w => $config->{creation_security}{world} );
-
-    my $default_objects = CTX->server_config->{default_objects};
-    my %groups = ();
-    if ( my $group_levels = $config->{creation_security}{group} ) {
-        my @all_group_levels = ( ref $group_levels eq 'ARRAY' ) 
-                                 ? @{ $group_levels } : ( $group_levels );
-        foreach my $group_pair ( @all_group_levels ) {
-            my ( $gid, $gl ) = split /\s*:\s*/, $group_pair, 2;
-            if ( $gid =~ /\D/ ) {
-                $log->is_debug &&
-                    $log->debug( "Group ID [$gid] not a #, changing" );
-                $gid = $default_objects->{ $gid };
-            }
-            $groups{ $gid } = $gl;
-        }
-    }
-    $create{g} = \%groups;
-    $config->{creation_security} = \%create;
-    $log->is_debug &&
-        $log->debug( "Final security: ",
-                     CTX->dump( $config->{creation_security} ) );
-    return;
-}
-
-sub _config_date_conversion {
-    my ( $config ) = @_;
-    my $log = get_logger( LOG_SPOPS );
-
-    my $DFK = 'convert_date_field';
-    $config->{ $DFK } ||= [];
-    unless ( ref $config->{ $DFK } eq 'ARRAY' ) {
-        $config->{ $DFK } = [ $config->{ $DFK } ];
-    }
-
-    # First check to see if we have any date fields
-
-    unless ( scalar @{ $config->{ $DFK } } > 0 ) {
-        $log->is_debug &&
-            $log->debug( "No date fields in [$config->{class}]" );
-        return;
-    }
-
-    $log->is_info &&
-        $log->info( "Setting up [$config->{class}] to autoconvert ",
-                    "its date fields: ", join( ', ', @{ $config->{ $DFK } } ) );
-
-    $config->{convert_date_class} = 'DateTime';
-    my %existing_rules = map { $_ => 1 } @{ $config->{rules_from} };
-    unless ( $existing_rules{ 'SPOPS::Tool::DateConvert' } ) {
-        $log->is_debug &&
-            $log->debug( "Adding date conversion tool to rules" );
-        push @{ $config->{rules_from} }, 'SPOPS::Tool::DateConvert';
-    }
-
-    # TODO: Be able to set a default format for all databases
-
-    unless ( $config->{convert_date_format} ) {
-        my $default_format = '%Y-%m-%d %H:%M:%S';
-        $log->warn( "SPOPS object [$config->{key}: $config->{class}] does ",
-                    "not have a conversion date format set. This is ",
-                    "STRONGLY encouraged -- please look at ",
-                    "'OpenInteract2::Manual::SPOPS' under 'DATE ",
-                    "CONVERSION' for more information. (Using default ",
-                    "'$default_format')" );
-        $config->{convert_date_format} = $default_format;
-    }
-    return;
-}
-
-sub _config_fulltext {
-    my ( $config ) = @_;
-    my $log = get_logger( LOG_SPOPS );
-    if ( defined $config->{is_searchable} and $config->{is_searchable} eq 'yes' ) {
-        if ( defined $config->{fulltext_field} ) {
-            $log->is_debug &&
-                $log->debug( "Adding fulltext indexing for ",
-                             "[$config->{key}: $config->{class}]" );
-            unshift @{ $config->{isa} }, 'OpenInteract2::FullText';
-        }
-        else {
-            $log->warn( "You set 'is_searchable' for [$config->{key}: ",
-                        "$config->{class}] but you didn't list any ",
-                        "fields in 'fulltext_field' so nothing will ",
-                        "be indexed." );
-        }
-    }
-    return;
-}
-
-# NOTE: This requires that the action table is already read in. The
-# process defined in OI2::Context/Setup ensures this, but if you're
-# doing initialization some other way: YOU'VE BEEN WARNED.
-
-sub _config_display_info {
-    my ( $config ) = @_;
-    my $display_info = $config->{display};
-    unless ( ref $display_info eq 'HASH' ) {
-        return;
-    }
-    if ( $display_info->{url} ) {
-        $display_info->{url} =
-            OpenInteract2::URL->create( $display_info->{url} );
-    }
-    elsif ( $display_info->{ACTION} ) {
-        $display_info->{url} =
-            OpenInteract2::URL->create_from_action( $display_info->{ACTION},
-                                                    $display_info->{TASK} );
-        delete $display_info->{ACTION};
-        delete $display_info->{TASK};
-    }
-    return;
-}
-
-
-
-
 ########################################
 # RULESET FACTORY BEHAVIOR
 ########################################
@@ -214,9 +44,16 @@ sub save_object_key {
     my $obj_key = $self->fetch_object_key;
     unless ( $obj_key ) {
         $obj_key = $self->generate_object_key;
-        eval { $self->db_insert({ %{ $p }, table => OBJECT_KEY_TABLE,
-                                  field => [ qw/ object_key class object_id / ],
-                                  value => [ $obj_key, ref( $self ), $self->id ] }) };
+        my $id = $self->id;
+        my $db = CTX->datasource( CTX->lookup_system_datasource_name );
+        eval {
+            SPOPS::SQLInterface->db_insert({
+                         %{ $p },
+                         table => OBJECT_KEY_TABLE,
+                         field => [ qw/ object_key class object_id / ],
+                         value => [ $obj_key, ref( $self ), $id ],
+                         db    => $db, })
+        };
         if ( $@ ) {
             $log->error( "Cannot save object key: $@" );
             return undef;
@@ -242,12 +79,15 @@ sub generate_object_key {
 sub fetch_object_key {
     my ( $self, $p ) = @_;
     $p ||= {};
+    my $id = $self->id;
+    my $db = CTX->datasource( CTX->lookup_system_datasource_name );
     my $row = $self->db_select({ %{ $p },
                                  from   => OBJECT_KEY_TABLE,
                                  select => [ 'object_key' ],
                                  where  => 'class = ? AND object_id = ?',
-                                 value  => [ ref $self, $self->id ],
-                                 return => 'single' });
+                                 value  => [ ref $self, scalar $id ],
+                                 return => 'single',
+                                 db     => $db });
     return $row->[0] if ( $row );
     return undef;
 }
@@ -258,7 +98,7 @@ sub fetch_object_key {
 sub fetch_object_info_by_key {
     my ( $class, $key, $p ) = @_;
     $p ||= {};
-    $p->{db} ||= $class->global_datasource_handle;
+    my $db = CTX->datasource( CTX->lookup_system_datasource_name );
     die "Cannot retrieve object info without key!" unless ( $key );
     my $row = SPOPS::SQLInterface->db_select({
                               %{ $p },
@@ -266,7 +106,8 @@ sub fetch_object_info_by_key {
                               select => [ 'class', 'object_id' ],
                               where  => 'object_key = ?',
                               value  => [ $key ],
-                              return => 'single' });
+                              return => 'single',
+                              db     => $db });
     return ( $row->[0], $row->[1] ) if ( $row );
     return undef;
 }
