@@ -1,47 +1,14 @@
 package OpenInteract2::SPOPS::DBI;
 
-# $Id: DBI.pm,v 1.5 2003/06/24 03:35:39 lachoy Exp $
+# $Id: DBI.pm,v 1.6 2003/07/12 21:15:40 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SPOPS );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::SPOPS::DBI::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SPOPS::DBI::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
-########################################
-# SPOPS CONFIGURATION
-########################################
-
-# This gets called by OpenInteract2::Setup when the SPOPS configuration
-# is first read in and allows us to set 'isa' and any other
-# information we want, generally based on the datasource
-
-# $config must already have datasource set
-
-sub modify_spops_config {
-    my ( $class, $config ) = @_;
-
-    # First ask the parent to TCB -- currently this only includes
-    # security handling, but in the future...?
-
-    $class->SUPER::modify_spops_config( $config );
-
-    my $server_config = CTX->server_config;
-    $config->{datasource} ||= $server_config->{datasource_config}{spops};
-    my $ds_info = $server_config->{datasource}{ $config->{datasource} };
-    my $spops_class = $ds_info->{spops};
-    push @{ $config->{isa} }, ( $spops_class, 'SPOPS::DBI' );
-    unshift @{ $config->{isa} }, 'OpenInteract2::SPOPS::DBI';
-
-    if ( $config->{field_discover} eq 'yes' ) {
-        push @{ $config->{rules_from} }, 'SPOPS::Tool::DBI::DiscoverField';
-    }
-}
-
-
-########################################
-# SPOPS::DBI BEHAVIOR
-########################################
+# See SPOPS::Config::Initializer for initialization behavior
 
 sub global_db_handle {
     my ( $pkg, $file, $line ) = caller;
@@ -49,7 +16,6 @@ sub global_db_handle {
         "'global_datasource_handle()'\n";
 }
 
-
 # We can do this since at startup every SPOPS object has 'datasource'
 # defined
 
