@@ -1,33 +1,14 @@
 package OpenInteract2::SPOPS::LDAP;
 
-# $Id: LDAP.pm,v 1.4 2003/06/24 03:35:39 lachoy Exp $
+# $Id: LDAP.pm,v 1.5 2003/07/12 21:15:40 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SPOPS );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::SPOPS::LDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SPOPS::LDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
-########################################
-# SPOPS CONFIGURATION
-########################################
-
-# This gets called by OpenInteract2::Setup when the SPOPS configuration
-# is first read in and allows us to set 'isa' and any other
-# information we want, generally based on the datasource
-
-# $config should already have datasource set
-
-sub modify_spops_config {
-    my ( $class, $config ) = @_;
-
-    # First ask the parent to TCB -- currently this only includes
-    # security handling, but in the future...?
-
-    $class->SUPER::modify_spops_config( $config );
-    unshift @{ $config->{isa} }, 'OpenInteract2::SPOPS::LDAP';
-    push @{ $config->{isa} }, 'SPOPS::LDAP';
-}
+# See OpenInteract2::Config::Initializer for initialization behavior
 
 
 # TODO: Ensure stub is in SPOPS::LDAP for this
