@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall;
 
-# $Id: SQLInstall.pm,v 1.11 2003/06/24 03:35:38 lachoy Exp $
+# $Id: SQLInstall.pm,v 1.12 2003/07/12 21:11:20 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor );
@@ -11,7 +11,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Import;
 
-$OpenInteract2::SQLInstall::VERSION  = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SQLInstall::VERSION  = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( package );
 OpenInteract2::SQLInstall->mk_accessors( @FIELDS );
@@ -178,7 +178,7 @@ STRUCTURE:
         my ( $ds_name, $ds_info, $ds );
         eval {
             if ( $structure_set eq 'system' ) {
-                $ds_name = CTX->server_config->{datasource_config}{system};
+                $ds_name = CTX->lookup_system_datasource_name;
             }
             elsif ( $structure_set =~ /^datasource:\s*(\w+)\s*$/ ) {
                 $ds_name = $1;
@@ -354,7 +354,7 @@ DATAFILE:
         elsif ( $import_type eq 'dbdata' ) {
             my $ds_lookup = $data_struct->[0]->{datasource_pointer};
             if ( $ds_lookup eq 'system' ) {
-                $ds_name = CTX->server_config->{datasource_config}{system};
+                $ds_name = CTX->lookup_system_datasource_name;
             }
             elsif ( $ds_lookup =~ /^datasource:\s*(\w+)\s*$/ ) {
                 $ds_name = $1;
