@@ -1,6 +1,6 @@
 package OpenInteract2::Setup;
 
-# $Id: Setup.pm,v 1.22 2003/07/02 15:47:00 lachoy Exp $
+# $Id: Setup.pm,v 1.33 2003/09/05 02:21:06 lachoy Exp $
 
 use strict;
 use File::Copy               qw( cp );
@@ -8,20 +8,20 @@ use File::Basename           qw();
 use File::Path               qw();
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Config;
+use OpenInteract2::Config::Initializer;
 use OpenInteract2::Config::Base;
 use OpenInteract2::ContentGenerator;
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Filter;
+use OpenInteract2::Manage;
 use OpenInteract2::Package;
 use OpenInteract2::Repository;
 use OpenInteract2::Util;
 use SPOPS::Initialize;
 
-$OpenInteract2::Setup::VERSION = sprintf("%d.%02d", q$Revision: 1.22 $ =~ /(\d+)\.(\d+)/);
-
-use constant DEFAULT_TEMP_LIB_DIR => 'templib';
+$OpenInteract2::Setup::VERSION = sprintf("%d.%02d", q$Revision: 1.33 $ =~ /(\d+)\.(\d+)/);
 
 sub new {
     my ( $class ) = @_;
@@ -90,20 +90,26 @@ sub read_packages {
 sub create_temp_lib {
     my ( $self, $params ) = @_;
     my $log = get_logger( LOG_INIT );
-    my $base_config = CTX->base_config;
-    my $lib_dir = $base_config->temp_lib_dir || DEFAULT_TEMP_LIB_DIR;
 
-    my $full_temp_lib_dir = File::Spec->catdir(
-                                $base_config->website_dir, $lib_dir );
+    my $full_temp_lib_dir = CTX->lookup_temp_lib_directory;
     unshift @INC, $full_temp_lib_dir;
 
-    # TODO: global_attribute???
     my $create_option = $params->{temp_lib_create};
-    if ( -d $full_temp_lib_dir and $create_option ne 'create' ) {
-        $log->is_info &&
-            $log->info( "Temp lib dir [$full_temp_lib_dir] exists; ",
-                        "option is not 'create' so modules not copied" );
-        return [];
+    my $do_create = ( $create_option and $create_option eq 'create' );
+    if ( -d $full_temp_lib_dir and ! $do_create ) {
+        my $refresh_file =
+            File::Spec->catfile( $full_temp_lib_dir,
+                                 CTX->lookup_temp_lib_refresh_filename );
+        unless ( -f $refresh_file ) {
+            $log->is_info &&
+                $log->info( "Temp lib dir '$full_temp_lib_dir' exists; ",
+                            "option is not 'create' and there is no ",
+                            "'refresh' file so modules not copied" );
+
+            # Picks up management tasks from packages (move this to Context?)
+            OpenInteract2::Manage->find_management_tasks( $full_temp_lib_dir );
+            return [];
+        }
     }
 
     if ( -d $full_temp_lib_dir ) {
@@ -146,6 +152,19 @@ sub create_temp_lib {
             push @all_files, $dest_file;
         }
     }
+
+    # Now change permissions so all the files and directories are
+    # world-everything, letting the process's umask kick in
+
+    chmod( 0666, @all_files );
+
+    my %tmp_dirs = map { $_ => 1 }
+                       map { File::Basename::dirname( $_ ) } @all_files;
+    chmod( 0777, ( keys %tmp_dirs, $full_temp_lib_dir ) );
+
+    # Picks up management tasks from packages (move this to Context?)
+    OpenInteract2::Manage->find_management_tasks( $full_temp_lib_dir );
+
     $log->is_debug &&
         $log->debug( "Copied ", scalar @all_files, " modules ",
                      "to [$full_temp_lib_dir]" );
@@ -157,8 +176,11 @@ sub create_temp_lib {
 
 sub require_session_classes {
     my ( $self, $session_config ) = @_;
+    my $log = get_logger( LOG_INIT );
     my @session_classes = ( $session_config->{class},
                             $session_config->{impl_class} );
+    $log->info( "Requiring session classes: ",
+                join( ', ', @session_classes ) );
     return $self->require_module({ class => \@session_classes });
 }
 
@@ -174,16 +196,12 @@ sub read_action_table {
     my ( $self ) = @_;
     my $log = get_logger( LOG_INIT );
 
-    # Grab the default action info from the server config. The local
-    # action default info takes precedence, then this
-
-    my $server_config = CTX->server_config;
-    my $global_defaults = $server_config->{action_info}{default};
-
     # This will become the action table
 
     my %ACTION = ();
 
+    my $initializer = OpenInteract2::Config::Initializer->new;
+
     my $packages = CTX->packages;
     foreach my $package ( @{ $packages } ) {
         my $package_id = join( '-', $package->name, $package->version );
@@ -206,86 +224,47 @@ ACTIONFILE:
             }
             foreach my $action_name ( $action_ini->main_sections ) {
                 if ( $ACTION{ $action_name } ) {
+
                     # TODO: Throw an exception if this happens?
                     $log->error( "WARNING - Multiple actions defined for ",
                                  "the same name [$action_name]. Overwriting ",
                                  "data from [$ACTION{ $action_name }->{package_name}]" );
                     delete $ACTION{ $action_name };
                 }
-                my $action_assign =
-                    $self->_assign_action_info( $action_name,
-                                                $action_ini->{ $action_name },
-                                                $global_defaults );
+
+                my %action_assign = ();
+                $action_assign{name} = $action_name;
+                while ( my ( $action_item, $action_value ) =
+                                            each %{ $action_ini->{ $action_name } } ) {
+                    $action_assign{ $action_item } = $action_value;
+                }
 
                 # Set the package name/version this action came from
-                $action_assign->{package_name}    = $package->name;
-                $action_assign->{package_version} = $package->version;
-                $action_assign->{config_file}     = $full_action_path;
-                $ACTION{ $action_name } = $action_assign;
+                $action_assign{package_name}    = $package->name;
+                $action_assign{package_version} = $package->version;
+                $action_assign{config_file}     = $full_action_path;
+                $ACTION{ $action_name } = \%action_assign;
             }
         }
     }
+
+    my $override_file = File::Spec->catfile( CTX->lookup_directory( 'conf' ),
+                                             CTX->lookup_override_action_filename );
+    if ( -f $override_file ) {
+        my $overrider = OpenInteract2::Config::GlobalOverride->new(
+                                        { filename => $override_file } );
+        $overrider->apply_rules( \%ACTION );
+    }
+
+    foreach my $action_config ( values %ACTION ) {
+        $log->info( "Notifying observers of config for action ",
+                    "'$action_config->{name}'" );
+        $initializer->notify_observers( 'action', $action_config );
+    }
+
     return \%ACTION;
 }
 
-# TODO: Move the consistency checks into OI2::Config:Action or OI2::Action?
-
-sub _assign_action_info {
-    my ( $self, $action_name, $action_info, $global_defaults ) = @_;
-    my %assign = ();
-
-    # First put the action name inside the action definition
-
-    $assign{name} = $action_name;
-
-    # Then copy over all the action info
-
-    while ( my ( $action_item, $action_value ) =
-                              each %{ $action_info } ) {
-        $assign{ $action_item } = $action_value;
-    }
-
-    # Assign default values; note that we only write the value if the
-    # key does not exist -- key existing is a sign the author wanted
-    # to override with a blank value
-
-    while ( my ( $action_item, $action_value ) =
-                              each %{ $global_defaults } ) {
-        next if ( exists $assign{ $action_item } );
-        $assign{ $action_item } = $action_value;
-    }
-
-    # Translate verbose security levels into SPOPS::Secure constants
-
-    if ( ref $action_info->{security} eq 'HASH' ) {
-        foreach my $task ( keys %{ $action_info->{security} } ) {
-            my $task_security = uc $action_info->{security}{ $task };
-            if ( $task_security =~ /^(NONE|SUMMARY|READ|WRITE)$/ ) {
-                $task_security =
-                    OpenInteract2::Util->verbose_to_level( $task_security );
-            }
-            $action_info->{security}{ $task } = int( $task_security );
-        }
-    }
-
-    # Ensure our caching parameters are in a consistent state (always
-    # an arrayref)
-
-    my $cache_params = $action_info->{cache_param};
-    if ( ref $cache_params eq 'HASH' ) {
-        foreach my $task ( keys %{ $cache_params } ) {
-            if ( ref $cache_params->{ $task } ne 'ARRAY' ) {
-                $cache_params->{ $task } = ( $cache_params->{ $task } )
-                                             ? [ $cache_params->{ $task } ] : [];
-            }
-
-            # Task parameters are always in the same order...
-            $cache_params->{ $task } = [ sort @{ $cache_params->{ $task } } ];
-        }
-    }
-
-    return \%assign;
-}
 
 # Requires the action table to have already been built; scan through
 # the classes and build a unique list of all classes referenced in the
@@ -308,6 +287,29 @@ sub require_action_classes {
 }
 
 
+sub initialize_action_classes {
+    my ( $self, $action_classes ) = @_;
+    my $log = get_logger( LOG_INIT );
+    return [] unless ( ref $action_classes eq 'ARRAY' );
+
+    my @success = ();
+    foreach my $action_class ( @{ $action_classes } ) {
+        $log->is_debug &&
+            $log->debug( "Initializing action class '$action_class'" );
+        eval { $action_class->init_at_startup() };
+        if ( $@ ) {
+            $log->error( "Caught error initializing action class ",
+                         "'$action_class': $@" );
+        }
+        else {
+            $log->is_info &&
+                $log->info( "Initialized action class '$action_class' ok" );
+            push @success, $action_class;
+        }
+    }
+    return \@success;
+}
+
 sub register_action_types {
     my ( $self ) = @_;
     my $action_types = CTX->server_config->{action_types};
@@ -321,13 +323,19 @@ sub register_action_types {
 }
 
 ########################################
-# FILTERS
+# INITIALIZE OBSERVERS
 
-# sets the filter registry in CTX
+# sets the filter registry in CTX, adds config watchers to
+# OI2::Config::Initializer
 
-sub initialize_action_filters {
+sub initialize_observers {
     my ( $self ) = @_;
+
+    # Filters
     OpenInteract2::Filter->initialize;
+
+    # Configuration watchers
+    OpenInteract2::Config::Initializer->read_observers;
 }
 
 ########################################
@@ -339,9 +347,13 @@ sub read_spops_config {
     my $server_config = CTX->server_config;
 
     # This will become the full SPOPS config
-
     my %SPOPS = ();
 
+    my $initializer = OpenInteract2::Config::Initializer->new;
+
+    my $default_datasource = CTX->lookup_default_datasource_name;
+    $log->info( "Using default datasource [$default_datasource]" );
+
     my $packages = CTX->packages;
     foreach my $package ( @{ $packages } ) {
         my $package_id = join( '-', $package->name, $package->version );
@@ -364,6 +376,7 @@ SPOPSFILE:
 
             foreach my $spops_key ( $spops_ini->main_sections ) {
                 if ( $SPOPS{ $spops_key } ) {
+
                     # TODO: Throw an exception if this happens?
                     $log->error( "WARNING - Multiple SPOPS objects defined ",
                                  "with the same key [$spops_key]. Overwriting data ",
@@ -382,43 +395,41 @@ SPOPSFILE:
                 }
 
                 # Set the package name/version this object came from
+
                 $spops_assign{package_name}    = $package->name;
                 $spops_assign{package_version} = $package->version;
                 $spops_assign{config_file}     = $full_spops_path;
 
-                $self->_modify_spops_config_by_datasource( \%spops_assign );
+                # Set the default datasource if it's not already
+
+                $spops_assign{datasource} ||= $default_datasource;
+
+
                 $SPOPS{ $spops_key } = \%spops_assign;
                 $log->is_info &&
-                    $log->info( "Read in and modified SPOPS config ",
-                                "for object $spops_key: ",
-                                $spops_ini->{ $spops_key }{class} );
+                    $log->info( "Read in SPOPS config for object ",
+                                "$spops_key: $spops_ini->{ $spops_key }{class}" );
             }
         }
     }
+
+    my $override_file = File::Spec->catfile( CTX->lookup_directory( 'conf' ),
+                                             CTX->lookup_override_spops_filename );
+    if ( -f $override_file ) {
+        my $overrider = OpenInteract2::Config::GlobalOverride->new(
+                                        { filename => $override_file } );
+        $overrider->apply_rules( \%SPOPS );
+    }
+
+    foreach my $spops_config ( values %SPOPS ) {
+        $initializer->notify_observers( 'spops', $spops_config );
+        $log->info( "Notified observers of config for SPOPS ",
+                    "[$spops_config->{key}: $spops_config->{class}]" );
+    }
+
     return \%SPOPS;
 }
 
-
-# TODO: Datasource stuff probably isn't necessary anymore with the
-# global config, but we might want to keep the datasource-only
-# configuration. (Easier for users.)
-
-# Set the @ISA for the class based on the datasource, security,
-# etc. Note that this is done before the normal SPOPS behavior factory
-# stuff kicks in, since we haven't started generating classes yet...
-
-sub _modify_spops_config_by_datasource {
-    my ( $self, $spops_config ) = @_;
-    my $server_config = CTX->server_config;
-    my $ds_name = $spops_config->{datasource}
-                  || $server_config->{datasource_config}{spops};
-    my $ds_info = $server_config->{datasource}{ $ds_name };
-    my $ds_type_info = $server_config->{datasource_type}{ $ds_info->{type} };
-    my $ds_config_handler = $ds_type_info->{spops_config};
-    $ds_config_handler->modify_spops_config( $spops_config );
-}
-
-
 sub activate_spops_classes {
     my ( $self, $spops_config ) = @_;
     my $log = get_logger( LOG_INIT );
@@ -466,32 +477,6 @@ sub check_datasources {
 }
 
 
-########################################
-# ALIASES
-
-# This is different than 1.x -- SPOPS classes don't get automatic
-# aliases. So we're just scanning the contents of the 'system_alias'
-# key in the server config object.
-
-sub read_aliases {
-    my ( $self ) = @_;
-    my $log = get_logger( LOG_INIT );
-
-    my $server_config = CTX->server_config;
-    unless ( ref $server_config->{system_alias} eq 'HASH' ) {
-        $log->error( "There are no system aliases defined. This is ",
-                     "almost certainly a very bad thing." );
-        return {};
-    }
-    my %aliases = ();
-    while ( my ( $alias, $to_class ) =
-                      each %{ $server_config->{system_alias} } ) {
-        $aliases{system}->{ $alias } = $to_class;
-    }
-    return \%aliases;
-}
-
-
 ########################################
 # CONTROLLERS
 
@@ -548,6 +533,15 @@ sub create_cache {
     return $cache;
 }
 
+########################################
+# SYSTEM CLASSES
+
+sub read_system_classes {
+    my ( $self ) = @_;
+    my $system_classes = CTX->lookup_class;
+    return $self->require_module({ class => [ values %{ $system_classes } ] });
+}
+
 
 ########################################
 # REQUIRE MULTIPLE MODULES
@@ -611,14 +605,16 @@ OpenInteract2::Setup - Setup an OpenInteract2::Context object
                               base_config => $base_config });
  
  # Create a temporary library -- a single directory where we copy all
- # Perl modules from the packages used.
+ # Perl modules from the packages used. (The 'create' option clears
+ # out the old directory and replaces it.)
  
- my $copied = $setup->create_temp_lib;
+ my $copied = $setup->create_temp_lib({ temp_lib_create => 'create' });
  print "Files copied to temp library: ", join( ", ", @{ $copied } );
  
  # Same thing, except only copy modules if the temp lib doesn't exist
+ # and if the refresh file (CTX->lookup_temp_lib_refresh_filename)
+ # doesn't exist
  
- CTX->global_attribute( temp_lib_create => 'lazy' );
  my $copied = $setup->create_temp_lib;
  
  # Build the action table and bring in the necessary classes
@@ -626,6 +622,7 @@ OpenInteract2::Setup - Setup an OpenInteract2::Context object
  my $actions = $setup->read_action_table();
  print "Actions in server: ", join( ", ", @{ $actions } );
  my $modules = $setup->require_action_classes( $actions );
+ my $initialized = $setup->initialize_action_classes( $modules );
  
  # Read the SPOPS configuration and build all the SPOPS classes
  
@@ -633,16 +630,10 @@ OpenInteract2::Setup - Setup an OpenInteract2::Context object
  print "SPOPS object aliases: ", join( ", ", @{ $aliases } );
  my $classes = $setup->activate_spops_classes( $spops_config );
  
- # Build system aliases
- 
- my $sys_aliases = $setup->build_aliases;
- 
  # Require a bunch of mdules at once
  
- my $required = $setup->require_modules({
-                                        class => \@class_list });
- my $required = $setup->require_modules({
-                                        filename => 'apache_modules.dat' });
+ my $required = $setup->require_module({ class => \@class_list });
+ my $required = $setup->require_module({ filename => 'apache_modules.dat' });
  
 =head1 DESCRIPTION
 
@@ -680,15 +671,24 @@ exception.
 Returns: an arrayref of L<OpenInteract2::Package|OpenInteract2::Package>
 objects.
 
-B<create_temp_dir()>
+B<create_temp_dir( \%params )>
 
-Copies all .pm files from all packages in a website to a temporary
-library directory. If the 'lazy' global attribute in the context is
-true and the directory exists, the action will not be performed.
+Optionally copies all .pm files from all packages in a website to a
+temporary library directory. Unlike OI 1.x the default is to leave the
+directory as-is if it already exists and only overwrite it on
+demand. So if the directory exists and the refresh file doesn't exist
+(more below), no files will be copied unless the 'temp_lib_create' key
+in C<\%params> is set to 'create'.
 
 The context must have the packages set before this is run, otherwise
 an exception is thrown.
 
+The refresh file is created by certain OI2 management tasks and
+signals that the library directory needs to be refreshed. One such
+task is installing a new package, the assumption being that you'll
+only need to refresh the temporary library directory when the
+libraries actually change.
+
 Returns: Arrayref of all files copied
 
 B<read_action_table()>
@@ -739,12 +739,12 @@ Example:
  ----------------------------------------
  [DEFAULT]
  author       = Chris Winters E<lt>chris@cwinters.comE<gt>
-
+ 
  [user]
  class        = OpenInteract2::Handler::User
  security     = no
  default_task = search_form
-
+ 
  [newuser]
  class        = OpenInteract2::Handler::NewUser
  error        = OpenInteract2::Error::User
@@ -778,17 +778,28 @@ This would result in an action table:
     author       => 'Chris Winters E<lt>chris@cwinters.comE<gt>',
  },
 
-B<require_action_classes()>
+B<require_action_classes( \%action_table )>
 
 Scans through all the actions and performs a 'require' on all
 referenced classes.
 
 Returns: Arrayref of all classes successfully required.
 
-B<initialize_action_filters()>
+B<initialize_action_classes( \@action_classes )>
 
-Reads the C<conf/filter.ini> file and associates the named actions
-with the specified filters.
+Calls C<init_at_startup()> on each class in
+C<\@action_classes>. Catches any exceptions thrown and logs them but
+continues with the process. A class is considered successfully
+initialized if it doesn't throw an exception.
+
+Returns: Arrayref of all classes successfully initialized.
+
+B<initialize_observers()>
+
+Initializes the filter observers from the server and packages (see
+L<OpenInteract2::Filter|OpenInteract2::Filter>), reads the
+configuration observers from the server and packages (see
+L<OpenInteract2::Config::Initializer|OpenInteract2::Config::Initializer>).
 
 Returns: nothing
 
@@ -843,23 +854,6 @@ which does all the work toward creating and initializing SPOPS classes.
 
 Returns: Arrayref of SPOPS classes properly read and initialized.
 
-B<read_aliases()>
-
-Just read in all the aliases from the server configuration and return
-them based on type. Currently this just reads in all aliases under
-'system_aliases' and returns them under the type 'system'.
-
-Returns: hashref of typed aliases.
-
-Example:
-
- my $aliases = $setup->read_aliases;
- foreach my $type ( keys %{ $aliases } ) {
-     while ( my ( $alias, $alias_to ) = each %{ $aliases->{ $type } } ) {
-         CTX->alias( $type, $alias, $alias_to );
-     }
- }
-
 B<initialize_controller()>
 
 Reads in all controllers from server configuration and registers them
