@@ -1,6 +1,6 @@
 package OpenInteract2::Util;
 
-# $Id: Util.pm,v 1.8 2003/06/24 03:35:38 lachoy Exp $
+# $Id: Util.pm,v 1.9 2003/08/20 13:31:22 lachoy Exp $
 
 use strict;
 use DateTime;
@@ -12,7 +12,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Secure            qw( :level :verbose );
 
-$OpenInteract2::Util::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Util::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_SUBJECT        => 'Mail sent from OpenInteract';
 use constant DEFAULT_ATTACH_MESSAGE => 'Emailing attachments';
@@ -44,7 +44,9 @@ sub now {
 #
 # Signature: $date_string = $class->today();
 
-sub today { return $_[0]->now( { format => '%Y-%m-%e' } ); }
+sub today {
+    return $_[0]->now( { format => '%Y-%m-%e' } );
+}
 
 
 
@@ -264,6 +266,32 @@ This class currently implments utilities for sending email. Note: In
 the future the mailing methods may move into a separate class (e.g.,
 C<OpenInteract2::Mailer>)
 
+=head1 DATE METHODS
+
+B<now( \%params )>
+
+Returns a formatted string representing right now.
+
+Parameters:
+
+=over 4
+
+=item *
+
+B<format>: Modifies how the date looks with a C<strftime> format
+string. Defaults is '%Y-%m-%d %T'.
+
+=item *
+
+B<time>: An epoch time. to use for the date. Defaults to right now.
+
+=back
+
+B<today()>
+
+Returns today's date in a string formatted '%Y-%m-%d', e.g.,
+'2003-04-01' for April 1, 2003.
+
 =head1 MAIL METHODS
 
 B<send_email( \% )>
@@ -358,7 +386,7 @@ B<Example usages>
                          subject => "Order Reciept: #$order->{order_number}",
                          message => $myclass->create_invoice( $order ) }) };
 
-=head1 OTHER METHODS
+=head1 SECURITY LEVELS
 
 B<verbose_to_level( $verbose_security_level )>
 
@@ -395,10 +423,6 @@ And have emails with a size E<gt> 'max_size' get rejected (or spooled),
 while all outgoing emails (unless otherwise specified) get the header
 and footer templates around the content.
 
-=head1 BUGS
-
-None known.
-
 =head1 SEE ALSO
 
 L<Mail::Sendmail|Mail::Sendmail>
