@@ -1,9 +1,9 @@
-# $Id: utils.pl,v 1.17 2003/06/26 04:56:16 lachoy Exp $
+# $Id: utils.pl,v 1.23 2003/09/05 14:03:52 lachoy Exp $
 
 use strict;
 use Data::Dumper             qw( Dumper );
 use File::Basename           qw( basename );
-use File::Path;
+use File::Path               qw();
 use File::Spec;
 use IO::File;
 use Log::Log4perl            qw( :levels );
@@ -21,10 +21,6 @@ $Data::Dumper::Indent = 1;
 
 my ( $log );
 
-sub main::LOG {
-     return $log;
-}
-
 BEGIN {
     $log = OpenInteract2::Log->init_file( 'oi2_tests.log', $INFO );
     $log->info( "Starting test run" );
@@ -34,6 +30,10 @@ END {
     $log->info( "Finished test run" );
 }
 
+sub main::LOG {
+     return $log;
+}
+
 # Dump out a reference
 
 sub main::barf {
@@ -41,6 +41,25 @@ sub main::barf {
     warn Dumper( $ref ), "\n";
 }
 
+sub main::get_package_versions {
+    return (
+         base            => '2.05',
+         base_box        => '2.05',
+         base_error      => '2.06',
+         base_group      => '2.05',
+         base_page       => '2.12',
+         base_security   => '2.07',
+         base_template   => '3.05',
+         base_theme      => '2.05',
+         base_user       => '2.08',
+         full_text       => '2.06',
+         lookup          => '2.02',
+         news            => '2.07',
+         object_activity => '2.07',
+         system_doc      => '2.04',
+   );
+}
+
 ########################################
 # CUSTOM COMPARISONS
 
@@ -80,9 +99,7 @@ sub main::get_use_dir {
     return File::Spec->catdir( get_test_dir(), 'use' );
 }
 
-# Not sure if we should 'export' yet...
-
-sub get_tmp_dir {
+sub main::get_tmp_dir {
     return File::Spec->catdir( get_test_dir(), '_tmp' );
 }
 
@@ -116,6 +133,9 @@ sub main::rmtree {
     return File::Path::rmtree( [ @_ ] );
 }
 
+sub main::mkpath {
+    return File::Path::mkpath( [ @_ ] );
+}
 
 ########################################
 # TEST FILE LOCATOR
@@ -143,7 +163,7 @@ sub main::get_test_file {
     }
 
     my $file = IO::File->new( $full_filename )
-                    || die "Failed to read [$filename]: $!";
+                    || die "Failed to read '$filename': $!";
     if ( $type eq 'filehandle' ) {
         return $file;
     }
@@ -164,6 +184,16 @@ sub main::install_website {
     my $source_dir  = get_source_dir();
     my $website_dir = get_test_site_dir();
     my $is_recent = _is_recent_website( $website_dir );
+
+    eval {
+        require SPOPS::DBI::SQLite;
+        require Apache::Session::SQLite;
+        require OpenInteract2::SessionManager::SQLite;
+    };
+    if ( $@ ) {
+        die "Failed to require SQLite files: $@";
+    }
+
     if ( -d $website_dir and $is_recent ) {
         return $website_dir;
     }
@@ -176,15 +206,15 @@ sub main::install_website {
              "This may take a while...\n";
     }
     if ( -d $website_dir ) {
-        LOG()->debug( "Removing existing dir [$website_dir]" );
+        LOG()->debug( "Removing existing dir '$website_dir'" );
         rmtree( $website_dir );
         my $db_file = get_test_site_db_file();
-        LOG()->debug( "Removing existing db file [$db_file]" );
+        LOG()->debug( "Removing existing db file '$db_file'" );
         unlink( $db_file );
     }
     my $tmp_dir = get_tmp_dir();
     unless ( -d $tmp_dir ) {
-        LOG()->debug( "Creating temp dir [$tmp_dir]" );
+        LOG()->debug( "Creating temp dir '$tmp_dir'" );
         mkdir( $tmp_dir, 0777 );
     }
 
@@ -241,7 +271,7 @@ sub _modify_server_config {
     $ini->{datasource}{main}{spops}       = 'SPOPS::DBI::SQLite';
     $ini->{datasource}{main}{driver_name} = 'SQLite';
     $ini->{datasource}{main}{dsn}         = "dbname=$db_file";
-    $ini->{session_info}{class}           = 'OpenInteract2::Session::SQLite';
+    $ini->{session_info}{class}           = 'OpenInteract2::SessionManager::SQLite';
     $ini->{session_info}{impl_class}      = 'Apache::Session::SQLite';
     $ini->{session_info}{datasource}      = 'main';
     $ini->write_file;
@@ -323,7 +353,7 @@ sub _get_files {
 sub _get_entries_in_dir {
     my ( $dir ) = @_;
     opendir( ENTRIES, $dir )
-                    || die "Cannot open directory [$dir]: $!";
+                    || die "Cannot open directory '$dir': $!";
     my @entries = grep ! /^(\.|\.\.)$/, readdir( ENTRIES );
     closedir( ENTRIES );
     return sort @entries;
