@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# $Id: create_new_manage.pl,v 1.5 2003/07/03 03:54:58 lachoy Exp $
+# $Id: create_new_manage.pl,v 1.6 2003/07/14 13:31:27 lachoy Exp $
 
 # create_new_manage.pl
 #   Create skeleton module for new management task.
@@ -57,16 +57,22 @@ sub sample {
     return <<'SAMPLE';
 package OpenInteract2::Manage::%%TYPE%%::%%CLASS%%;
 
-# $Id: create_new_manage.pl,v 1.5 2003/07/03 03:54:58 lachoy Exp $
+# $Id: create_new_manage.pl,v 1.6 2003/07/14 13:31:27 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::%%TYPE%% );
-use OpenInteract2::Context qw( CTX DEBUG LOG );
+use Log::Log4perl            qw( get_logger );
+use OpenInteract2::Constants qw( :log );
+use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Manage::%%TYPE%%::%%CLASS%%::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::%%TYPE%%::%%CLASS%%::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
-sub brief_description {
+sub get_name {
+    return 'mytask';
+}
+
+sub get_brief_description {
     return "Describe your task in a sentence or two.";
 }
 
@@ -80,12 +86,10 @@ sub get_param_description {
     return $self->SUPER::get_param_description( $param_name );
 }
 
-sub list_param_require {
-    return [];
-}
-
-sub list_param_validate {
-    return [];
+sub get_parameters {
+    my ( $self ) = @_;
+    return {
+    };
 }
 
 sub setup_task {
@@ -102,6 +106,8 @@ sub tear_down_task {
     my ( $self ) = @_;
 }
 
+OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
+
 1;
 
 __END__
@@ -113,11 +119,12 @@ OpenInteract2::Manage::%%TYPE%%::%%CLASS%% - Managment task
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
-
+ 
  use strict;
  use OpenInteract2::Manage;
-
+ 
  my $website_dir = '/home/httpd/mysite';
+ my %PARAMS = ( ... );
  my $task = OpenInteract2::Manage->new(
                       'COMMAND', \%PARAMS );
  my @status = $task->execute;
@@ -140,30 +147,16 @@ OpenInteract2::Manage::%%TYPE%%::%%CLASS%% - Managment task
 
 =head1 STATUS INFORMATION
 
-Each status hashref includes:
+In addition to the standard entries Each status hashref includes:
 
 =over 4
 
-=item B<is_ok>
+=item B<entry>
 
-Set to 'yes' if the task succeeded, 'no' if not.
-
-=item B<message>
-
-Success/failure message.
+Description
 
 =back
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
-=head1 SEE ALSO
-
 =head1 COPYRIGHT
 
 Copyright (C) 2003 A. U. Thor. All rights reserved.
